Ext JS Release Notes

Ext JS - JavaScript Framework

# Release Notes for Ext JS 4.1.1

Release Date: July 4, 2012
Version Number: 4.1.1

## Bugs Fixed

- Charts (6)
  - EXTJSIV-6275 Line chart messed up after disabling and enabling lines though legend
  - EXTJSIV-6323 Charts don't render with either constrain, or both maximum and minimum
  - EXTJSIV-6324 Problem using minimum, maximum and majorTicksSteps together
  - EXTJSIV-6359 Chart should display integers on axis
  - EXTJSIV-6583 Chart redraw on store update fails in inactive card
  - EXTJSIV-6585 Rapid clicks on pie chart causes slices to shrink or disappear
- Core (10)
  - EXTJSIV-3932 dom.style.setExpression not implemented in IE8
  - EXTJSIV-5956 Ext.extend does not handle constructor properly using 3-argument form
  - EXTJSIV-6087 Ext.data.TreeStore CRUD regression
  - EXTJSIV-6452 Container's private floatingItems collection should be floatingDescendants
  - EXTJSIV-6453 Container-owned floating items appear at wrong level in the ComponentQuery hierarchy
  - EXTJSIV-6456 ComponentQuery :last selector fails with a single item
  - EXTJSIV-6484 Ext.AbstractManager.onAvailable listener isn't removed properly
  - EXTJSIV-6499 Reusing id's for elements recently removed from the DOM would incorrectly reference old element
  - EXTJSIV-6570 Ext.Element getStyle can throw in IE6/7 reading font styles
  - EXTJSIV-6612 Observable.resumeEvents should tolerate being called when suspendCount is zero
- Data (6)
  - EXTJSIV-5253 Ext.data.writer.Json no longer respects dateFormat
  - EXTJSIV-5995 Model field disappear when using idProperty
  - EXTJSIV-6480 loadData reading an Array uses the wrong field order to read the data items.
  - EXTJSIV-6523 data.Reader will not read data where a model is included
  - EXTJSIV-6545 Can't reload buffered store after filtering
  - EXTJSIV-6627 Model.copy passes its data into the new constructor as raw which gets converted.
- DataView (1)
  - EXTJSIV-6524 AbstractView should not cancel SPACE key event if target is an input element.
- Documentation (3)
  - EXTJSIV-5148 Ext.selection.Model documentation bug
  - EXTJSIV-6187 Grouping and locking features do not work together
  - EXTJSIV-6573 AbstractComponent.render missing in the API docs
- Examples (4)
  - EXTJSIV-6449 Simple Tasks reminder window does not lay out when resized.
  - EXTJSIV-6450 Themes example's layout expands vertical slider's element to 100% width
  - EXTJSIV-6462 Chart rendering is broken by moving its ancestors in the DOM in IE
  - EXTJSIV-6717 Combination Examples - Feed Viewer: Getting error upon clicking on any feed in the preview panel when "Hide" option is selected in the preview drop down menu.
- Forms (15)
  - EXTJSIV-6071 The title of the MultiSelect is not displayed
  - EXTJSIV-6085 "Custom Layout " Alert message borderline is missing under "Radio Groups " in IE6
  - EXTJSIV-6086 labelWidth is ignored with labelAlign top
  - EXTJSIV-6127 TextField emptyText cannot be entered as the value
  - EXTJSIV-6160 Ext.form.field.Time does not initialize value correctly
  - EXTJSIV-6227 Adding a new field to a form layout fails on IE
  - EXTJSIV-6311 Time field clears value on blur.
  - EXTJSIV-6371 Fields with labelAlign top need to not make label its own row - causes too many problems
  - EXTJSIV-6402 DisplayField doesn't update size after a value change
  - EXTJSIV-6416 Calling setText on unrendered TextField does not work
  - EXTJSIV-6445 standardSubmit: true is broken for forms with params
  - EXTJSIV-6478 Ext.form.BasicForm fails to correctly read the response of a file upload
  - EXTJSIV-6568 HtmlEditor leaks memory on window unload in IE6/7
  - EXTJSIV-6579 HtmlEditor contents are cleared by initial Ext.example.msg
  - EXTJSIV-6594 enforceMaxLength with no maxLength in textfield allows only one char
- Grid (18)
  - EXTJSIV-5343 Lockable views do not handle drag between two sides well or dragging of or between group headers.
  - EXTJSIV-6075 Checkbox selection model's header checkbox not in sync if records are added/removed
  - EXTJSIV-6242 Grid row editor does not close when record being edited is removed
  - EXTJSIV-6264 Grid filter range menu iconCls conflicts with Panel iconCls - rename to itemIconCls
  - EXTJSIV-6419 Grid Filters JS error when click on any column header after filtering Date and swap columns
  - EXTJSIV-6420 Grid row heights aren't synced in locked grid on IE9 standards.
  - EXTJSIV-6421 Locking grid headers misplaced after column hide
  - EXTJSIV-6440 BorderLayout: collapsed GridPanel on south looks inconsistent after expand
  - EXTJSIV-6463 Infinite grid alignment is skewed by presence of group headers
  - EXTJSIV-6477 Arrow keys become unresponsive when arrowing through records in a buffered grid
  - EXTJSIV-6481 Firefox 13 new default smooth scrolling leads to very slow grid scrolling
  - EXTJSIV-6482 Grid RowExpander is not reinserted after reconfigure
  - EXTJSIV-6509 Using getEditor on a grid column creates an orphaned component resulting in a memory leak
  - EXTJSIV-6531 Grid reconfigure fails with hideHeaders
  - EXTJSIV-6546 PagingScroller onCacheClear assumes view is rendered
  - EXTJSIV-6584 Cell editing in locked grid causes JS error
  - EXTJSIV-6644 CellSelectionModel selects the wrong cell in a locked grid
  - EXTJSIV-6718 Tab key causes error when cell editing with row selection model
- Layouts (5)
  - EXTJSIV-5131 ShrinkWrap layouts can fail with constrained widths / heights
  - EXTJSIV-6041 In IE8/9 "strict" mode, Box layout's perpendicular overflow does not work
  - EXTJSIV-6049 Auto-width grid in vbox stretches to 10,000px
  - EXTJSIV-6369 Closing floated/collapsed panel in border layout causes JS error
  - EXTJSIV-6528 Ext.layout.container.BoxOverflow.Menu.destroy throws Exception
- Menu (1)
  - EXTJSIV-6386 Picking a date doesn't work when Date field inside Menu
- Misc (2)
  - EXTJSIV-6348 Drag-drop on invalid dropzone leaves no focus
  - EXTJSIV-6510 IE 6 nonsecure items warning when using Ext.History
- Panel (4)
  - EXTJSIV-5149 "mini" collapseMode in border layout doesn't seem to work
  - EXTJSIV-6372 Multiple issues with Panel.setBodyStyle
  - EXTJSIV-6373 Specifying Panel header config and closable: true causes error
  - EXTJSIV-6448 Left and right aligned headers in panel drag are not layed out properly
- Theme (2)
  - EXTJSIV-6163 SplitButton with arrowAlign bottom and Gray theme - CSS issue on mouse over
  - EXTJSIV-6425 Sass function theme-background-image throws exception without a return value and css doesn't compile
- Toolbars (2)
  - EXTJSIV-6251 Toolbar defaults override single item settings
  - EXTJSIV-6451 Form fields clone in overflow menu of toolbar do not sync the original field value
- Tree (9)
  - EXTJSIV-5248 Ext.data.TreeStore setting the root property in the proxy doesn't work
  - EXTJSIV-6005 Ext.data.TreeStore with Ext.data.proxy.Rest does not pass ids correctly
  - EXTJSIV-6302 NodeInterface qtip and qtitle not updated
  - EXTJSIV-6417 tree.selectPath(tree.getRootNode().getPath()) doesn't select
  - EXTJSIV-6418 Folder keeps displaying collapse button after all leaves are dragged away
  - EXTJSIV-6443 expandable: false has no effect in tree grid
  - EXTJSIV-6473 Spacebar not toggling checkbox state in TreePanel
  - EXTJSIV-6554 Tree view refresh event is fired before the render event
  - EXTJSIV-6580 Tree node parentId doesn't respect useNull
- Window (6)
  - EXTJSIV-5889 Dragging a header-constrained window below Viewport bottom scrolls the Viewport
  - EXTJSIV-6033 Ext.window.Window fire incorrect events when maximized/restored
  - EXTJSIV-6234 Constrained window in a border layout is displaying at wrong location.
  - EXTJSIV-6297 Constraining a window to a panel using the "constrain" config does not work when "autoShow" is true
  - EXTJSIV-6397 Form submit with waitMsg:'string' called from Window focuses the Window which hides any MessageBox
  - EXTJSIV-6547 Window is not closed on Esc
Total: 94

## Known Issues

- Animation (1)
  - EXTJSIV-5487 accordion animation doesn't always complete if you click frequently
- Charts (1)
  - EXTJSIV-5108 can't create label for type area series
- Core (1)
  - EXTJSIV-4942 Element#tgetWidth() returns an incorrect result for naturally widthed absolutely positioned elements in some cases.
- Data (4)
  - EXTJSIV-3316 Ext.ux.grid.FiltersFeature cannot restore state
  - EXTJSIV-4319 Use a parameter other than 'id' for server calls
  - EXTJSIV-4335 Duplicate records when calling sync() on a autoSync store
  - EXTJSIV-4372 Grid Filtering Example: Bug with database return packet
- Documentation (2)
  - EXTJSIV-4296 Ext JS 4 and Sencha Touch Docs examples fail on Chromebook, can't use Example viewer, ReferenceError: Ext is not defined
  - EXTJSIV-5156 Update documentation that fields (id,text,leaf) are expected
- Examples (1)
  - EXTJSIV-5997 Tabs: Group Tabs:Form Layout UI get truncated on IE6
- Forms (3)
  - EXTJSIV-2081 Issue with "Bullet list" in the form widget editor
  - EXTJSIV-2425 HTMLEditor corrupted when changing background color of selection
  - EXTJSIV-5484 Ext.form.field.File buttons don't get the mouse over effect that buttons do
- Grid (6)
  - EXTJSIV-4091 Grid filters: initial value can be set, but it is not applied
  - EXTJSIV-4954 Store Grouping Not Cleared Properly
  - EXTJSIV-5125 FiltersFeature - Updating column header class when using a column group
  - EXTJSIV-5595 Last selected row maintains selection after unchecked on column sort
  - EXTJSIV-5607 Grid: getEditorParent is ignored - nested cell editing is not possible
  - EXTJSIV-5922 Infinite grid and grouping feature do not work together
- Layouts (3)
  - EXTJSIV-3704 Ext.layout.container.Box: wrong children margins if using CSS rules
  - EXTJSIV-4768 Border Layout : regions overlap when size (or size constraint) won't allow all regions to fit container
  - EXTJSIV-6006 Desktop example: Layout problem using Safari / Chrome
- Misc (5)
  - EXTJSIV-4545 Kitchen Sink - Basic Tabs : By default tab headers are not displaying in Basic tabs.
  - EXTJSIV-4937 Combination Examples : Web Desktop : Notepad :Displaying errors in error console upon double clicking on empty space in the note pad.
  - EXTJSIV-5130 Neptune theme missing resources
  - EXTJSIV-5254 HTMLEditor.insertAtCursor issues in "Source Edit"; mode
  - EXTJSIV-6106 [4.1.0] Localizing issues
- Panel (3)
  - EXTJSIV-5488 Panel collapse/expand behavior not as expected when called on hidden panel
  - EXTJSIV-5489 preventHeader not honored when panel is programmatically collapsed.
  - EXTJSIV-5544 Intermittent issue with collapseOnDblClick set to true on IE
- Tabs (2)
  - EXTJSIV-3625 TabPanel: defaults: closable true not configurable
  - EXTJSIV-4421 x-tab-top-over never inserted into any element
- Tree (2)
  - EXTJSIV-4243 Synchronous loading fails if async loading of same class is on going
  - EXTJSIV-5075 NodeInterface "deep" copy only copies a single level
Total: 34

# Release Notes for Ext JS 4.1.1 RC 2

Release Date: June 13, 2012
Version Number: 4.1.1 RC 2

## Bugs Fixed

- Button (2)
  - EXTJSIV-6139 Button retains the focused state after disabling and enabling
  - EXTJSIV-6329 Config html of Button not working
- Charts (2)
  - EXTJSIV-6077 Layouts cause Charts to (re)animate
  - EXTJSIV-6224 Chart export hard codes sencha.io
- Core (11)
  - EXTJSIV-5767 return false from beforerender throws exception
  - EXTJSIV-5944 Ext.onReady with delay option hangs up a browser
  - EXTJSIV-6055 onReady does not work in an iframe in IE8 when parent is a different domain
  - EXTJSIV-6056 Problems with Component previousNode
  - EXTJSIV-6124 Loader calls Ext globalEval with code that breaks when IE cc_on
  - EXTJSIV-6137 Element slideIn tr anchor doesn't work as expected.
  - EXTJSIV-6185 getPosition on floating Components with parent Container always returns container-relative position
  - EXTJSIV-6196 calling showAt on a component does not fire the 'show' event.
  - EXTJSIV-6199 DomQuery fails with dots in the element id
  - EXTJSIV-6273 EventManager does not return listener response
  - EXTJSIV-6319 Ext.onReady sometimes fails in an iframe in IE when parent is in a different domain
- Data (3)
  - EXTJSIV-6298 Ext.data.Tree.flatten duplicates Ext.Object.getValues
  - EXTJSIV-6305 Model instance shared if proxy subclass specifies a reader config object
  - EXTJSIV-6306 Model's Id field not defined after sync in TreeStore
- DataView (1)
  - EXTJSIV-6019 When deferInitialRefresh is false, the arrival of the data still causes a second layout run
- Documentation (2)
  - EXTJSIV-5558 refs config not in API documentation
  - EXTJSIV-6179 pruneRemoved on Ext.selection.Model should not be private
- Events (1)
  - EXTJSIV-6320 Listener tracking is broken when removing non-existent listener
- Examples (1)
  - EXTJSIV-6413 Tabs : Basic Tabs: Clicking on ñEvent Tabî for first time, displaying the tab's content with border line
- Forms (17)
  - EXTJSIV-5298 Ext.form.Panel does not respect inherited properties when creating the BasicForm
  - EXTJSIV-5962 Dragging mouse off the right over a form scrolls content out of view in WebKit
  - EXTJSIV-6121 TimeField submit format not using 24 hour format
  - EXTJSIV-6142 Form field with incorrect width on validation, if msgTarget: 'side'
  - EXTJSIV-6143 Ext.form.field.Number: Spinner field sometimes fires 2 spin events
  - EXTJSIV-6173 Field not destroyed after form is closed
  - EXTJSIV-6176 Forms : File uploads : "File upload" window is not opening upon clicking on "photo" text field.
  - EXTJSIV-6184 Labelable: getFieldLabel should implement same logic as the setter as regards label separator
  - EXTJSIV-6198 Fields within Field Container don't resize properly
  - EXTJSIV-6255 TextAarea ignores "cols" attribute
  - EXTJSIV-6258 Combobox forceSelection clears the value if there is no match
  - EXTJSIV-6277 MsgBox header components are not placed properly in IE
  - EXTJSIV-6278 Trigger button does not look disabled on a disabled ComboBox
  - EXTJSIV-6281 Store filter from combobox remains after combo is destroyed and store is reused
  - EXTJSIV-6303 HtmlEditor destroy generates errors
  - EXTJSIV-6340 Measurement of triggerWidth does not work correctly with scopedResetCSS
  - EXTJSIV-6361 File upload field browse button does not properly re-enable after the field has been disabled in Internet Explorer
- Grid (29)
  - EXTJSIV-5934 Infinite Grid does not clear page cache when grouping changes
  - EXTJSIV-6001 Error in Ext.grid.plugin.Editing if no cell is active
  - EXTJSIV-6025 CellEditing plugin does not refocus edited cell when completing an edit
  - EXTJSIV-6037 When groups are rendered initially collapsed using startCollapsed, they cannot be expanded.
  - EXTJSIV-6050 Grid Group's groupHeaderTpl does not have parent param
  - EXTJSIV-6070 Row positions issue on vertical scroll and sorting
  - EXTJSIV-6107 Grid Column Sort Indicator Problem
  - EXTJSIV-6115 RowEditing uses wrong record if startEdit is called while already editing a record
  - EXTJSIV-6117 Locked column in infinite grid causes rows to disappear on page refresh
  - EXTJSIV-6122 Editing a Grid and then reloading its Data causes error
  - EXTJSIV-6123 Wrong grid panel height on layout change
  - EXTJSIV-6135 Scrolling and Rendering Bug in Grid Grouping with Summary example
  - EXTJSIV-6157 Grid Row Editor's Update button is not always enabled/disabled properly
  - EXTJSIV-6164 ProgressBar Pager fails when clicking on left edge of the progress bar.
  - EXTJSIV-6171 RowEditor in tab panel does not show editors properly when tab is hidden
  - EXTJSIV-6186 ActionColumn icon not updating in Grid or TreeGrid
  - EXTJSIV-6194 removeAll on buffered grid causes error in cancelAllPrefetches
  - EXTJSIV-6197 ActionColumn appearance does not change when disabled
  - EXTJSIV-6228 Column Group uses wrong config "restrictColumnReorder" - should be "sealedColumns"
  - EXTJSIV-6232 Grid column resizers are not aligned correctly
  - EXTJSIV-6259 Infinite Grid with Grouping. Groups should not be collapsible.
  - EXTJSIV-6313 Large jumps in infinite grid sometimes prune a required page from the buffered store
  - EXTJSIV-6337 Gridview fails to render properly if initial refresh occurs before view is rendered
  - EXTJSIV-6347 Grid Column Tooltip not supported as it was in v3
  - EXTJSIV-6364 Cell editing with RowSelection model causes JS error on endEdit
  - EXTJSIV-6414 Grid / Infinite Scrolling with remote filtering / Load masking is displaying and not able to search for the second time
  - EXTJSIV-6422 Row Editor throws an error when the grid has a checkbox selection model
  - EXTJSIV-6436 RowEditor does not sync when grid columns dragged to reorder.
  - EXTJSIV-6461 Sort is broken on Remote Summary Grid
- Layouts (9)
  - EXTJSIV-5167 Box layout (toolbar) overflow button does not work twice
  - EXTJSIV-5562 Horizontal scrollbar not visible when set to overflow in hbox layout
  - EXTJSIV-5806 Box layout fails to respect width and height percentages
  - EXTJSIV-5935 Error removing item afterRender: ownerContext.target.ownerLayout not defined
  - EXTJSIV-5939 Adding a new Checkbox to a CheckboxGroup fails on IE
  - EXTJSIV-5990 Layout failure with fieldset in vbox
  - EXTJSIV-6129 Collapsed fieldset does not resize parent when opened
  - EXTJSIV-6158 Percentage size does not work for floating components like Window
  - EXTJSIV-6428 Accordion with single item throws JS error in onComponentCollapse
- MVC (1)
  - EXTJSIV-6162 Ext.application.init() is never invoked
- Menu (2)
  - EXTJSIV-6254 Can't edit textfields properly when placed in a Menu
  - EXTJSIV-6321 Menu subclass doesn't inherit scrolling functionality
- Misc (11)
  - EXTJSIV-6100 .sass-cache included in extjs pachage
  - EXTJSIV-6170 Ext.DomHelper's 'confRe' matches substrings while it shouldn't
  - EXTJSIV-6193 DragDropManager.fireEvents - wrong parameters calling onInvalidDrop
  - EXTJSIV-6208 Traditional Chinese localization does not display properly for days of the week in IE
  - EXTJSIV-6226 Draw component does not auto-size correctly with no content
  - EXTJSIV-6253 Scoped css doesn't work well for filtering and date picker
  - EXTJSIV-6287 Flash Component disregards WMODE transparent
  - EXTJSIV-6304 Ext.menu.DatePicker select triggered twice
  - EXTJSIV-6335 DatePicker's native tip occludes "Today" button's QuickTip
  - EXTJSIV-6407 AbstractContainer overrides enable/disable without returning this
  - EXTJSIV-6412 Grids :Grouping Grid:The ñNameî column check box is not displaying
- Panel (6)
  - EXTJSIV-4144 Collapsible FormPanel collapsible direction [right] issue
  - EXTJSIV-4268 Panel does not respect animCollapse: false in placeholder collapseMode (border layout)
  - EXTJSIV-5351 Inconsistency on closing tabpanel items
  - EXTJSIV-5456 Layout changes inside a collapsed panel in a border layout creates extra panel header
  - EXTJSIV-6148 Calling removeDocked on a panel with no border throws exception
  - EXTJSIV-6178 Expanding a panel restores wrong size if size changed while collapsed
- Tabs (2)
  - EXTJSIV-6237 When labelAlign='top' and errorAlign='side', invalidation causes incorrect field width
  - EXTJSIV-6272 Tab text centering stops working in IE8 after dynamically adding tab
- Theme (2)
  - EXTJSIV-6188 Toolbar margin variables don't have !default flags
  - EXTJSIV-6282 Sass bug in _frame.scss when $radius === 10
- ToolTips (1)
  - EXTJSIV-6221 Canceling tooltip in beforeshow causes subsequent problems
- Toolbars (4)
  - EXTJSIV-5933 Toolbar reorderer stops during drag on IE
  - EXTJSIV-6251 Toolbar defaults override single item settings
  - EXTJSIV-6271 Programmatically set label in bbar is not visible until browser is resized
  - EXTJSIV-6279 tbseparator incorrectly inherits border from toolbar
- Tree (9)
  - EXTJSIV-3571 Two TreePanel behave wrongly when sharing a store
  - EXTJSIV-4918 Tree expand all / collapse all buggy behavior
  - EXTJSIV-5992 Tree expandAll/collapseAll does not always descend fully
  - EXTJSIV-6136 TreePanel loadMask cannot be rebound to a different mask
  - EXTJSIV-6286 Ext.ux.CheckColum does not work with a Tree
  - EXTJSIV-6302 NodeInterface qtip and qtitle not updated
  - EXTJSIV-6330 TreeStore root node does not always have an id
  - EXTJSIV-6344 Uncaught TypeError: Cannot read property 'dom' of null
  - EXTJSIV-6357 TreeStore listeners are not cleaned up
- Window (2)
  - EXTJSIV-3779 Message Box Dialog - Page is grayed out and not allowed to update the page when quickly double-clicking on Icon Show button.
  - EXTJSIV-5905 JS error when creating LoadMask bound to a Window
Total: 118

# Release Notes for Ext JS 4.1.1 RC 1

Release Date: May 15, 2012
Version Number: 4.1.1 RC 1

## Bugs Fixed

- Button (3)
  - EXTJSIV-5964 Buttons do not show 'pressing' animation when clickEvent is 'mousedown'
  - EXTJSIV-5989 Changing text in some buttons does not layout properly in Chrome 16+
  - EXTJSIV-6109 Button contents are cut off when using scoped CSS
- Charts (3)
  - EXTJSIV-5981 Bound of Area Series incorrectly calculated.
  - EXTJSIV-6074 Column chart with all zero data renders poorly and throws css warnings
  - EXTJSIV-6088 Pie chart is broken after resize
- Core (1)
  - EXTJSIV-6052 DragZone determines wrong target el causing subsequent JS error
- Data (4)
  - EXTJSIV-5988 Falsy Ext.data.Operation id property lost during Ext.data.Request creation.
  - EXTJSIV-5993 Ext 4.1 RC3 HasOne Assocation Bug
  - EXTJSIV-6024 Problem in extending from a model with associations
  - EXTJSIV-6063 Ext.data.Store.add() behave inconsistently when groupField is used
- DataView (2)
  - EXTJSIV-6082 Hidden data view breaks when updating
  - EXTJSIV-6110 Ext.view.AbstractView indexOf throws error if argument is invalid or null
- Documentation (1)
  - EXTJSIV-6112 Errors and omissions in the MVC Application Architecture guide
- Events (1)
  - EXTJSIV-5983 beforerender event not fired for Viewport (or component with configured 'el')
- Examples (1)
  - EXTJSIV-6045 GroupTabPanel ux bug - Missing lower rounded corner
- Forms (10)
  - EXTJSIV-5389 TextArea marks form as dirty
  - EXTJSIV-5458 Delete key does not work for textfield (email vtype) in Opera 11
  - EXTJSIV-5965 TextField placeholder text shifts up by 1 pixel on focus
  - EXTJSIV-5994 FieldSet label component is not available before render
  - EXTJSIV-6016 MultiSelect / ItemSelector : "Clear" and "Reset" Buttons are not working when all items are dragged to right panel in Item Selector Table.
  - EXTJSIV-6054 Spinner setReadOnly does not hide triggers
  - EXTJSIV-6065 TextArea special keys stop working at maxLength with enfornceMaxLength on
  - EXTJSIV-6081 A HiddenField occupies visible space in the form
  - EXTJSIV-6104 Slider readOnly has no effect
  - EXTJSIV-6134 Labelable insertion templates do not have access to component id
- Grid (5)
  - EXTJSIV-5984 [4.1 RC3] Grouping expand() not working
  - EXTJSIV-6057 Calling Ext.grid.Panel.reconfigure before rendering causes error
  - EXTJSIV-6066 Grid does not always show its loadmask properly
  - EXTJSIV-6083 scope has no effect on actioncolumn
  - EXTJSIV-6092 Grid header Container getVisibleHeaderClosestToIndex does not check previous only next
- Layouts (5)
  - EXTJSIV-5797 Autosized tooltips are not layed out correctly
  - EXTJSIV-5806 Box layout fails to respect width and height percentages
  - EXTJSIV-5861 Fit layout does not adjust sizes based on autoScroll triggered by minHeight
  - EXTJSIV-6026 Splitters in HBox layouts have no height
  - EXTJSIV-6042 getPosition method doesn't return page coordinate
- Menu (1)
  - EXTJSIV-6035 Menu destroy method can cause JS error on keyNav
- Misc (1)
  - EXTJSIV-5982 Stacked bar/column chart leave a ghost shadow when all items are hidden
- Panel (2)
  - EXTJSIV-5716 Panels with min/max constraints misbehave in a box layout with stretchmax
  - EXTJSIV-5916 Problem with Panel.setTitle without header
- Tree (3)
  - EXTJSIV-6051 4.1 Grid to Tree DnD not working any more
  - EXTJSIV-6076 Changing TreeStore's defaultRootProperty breaks the tree
  - EXTJSIV-6113 TreeGrid is not repainted after the vertical scroll bar disappears
- Window (1)
  - EXTJSIV-6048 Frame: true should not cause a window to display badly
Total: 44

# Release Notes for Ext JS 4.1.0

Release Date: April 20, 2012
Version Number: 4.1.0

## Bugs Fixed

- Charts (2)
  - EXTJSIV-5657 Charts : Grouped Bar :Displaying Js error upon clicking on "Legends" in the "grouped bar" chart on IE9
  - EXTJSIV-5954 Simple Area Chart Not Working in 4.1RCx
- Core (4)
  - EXTJSIV-5811 Elements can't fadeIn() after fadeOut()
  - EXTJSIV-5846 Component id's starting with non-word characters cause JS errors
  - EXTJSIV-5902 Draggable and resizable images leave resize handlers at start point when moved
  - EXTJSIV-5958 Ext.Error toString not including the method name
- Data (5)
  - EXTJSIV-4957 Inconsistent signature for the Store 'datachanged' event
  - EXTJSIV-5809 Model fields are set to undefined or defaultValue when they should not be updated
  - EXTJSIV-5862 Dependency on Writer from Proxy causes JS error
  - EXTJSIV-5877 Store modifies the value of inline data config option
  - EXTJSIV-5945 Ext.data.Model getFields returns undefined
- DataView (1)
  - EXTJSIV-5831 Floatable TreePanel in West Border of Viewport has two left hand borders
- Draw (1)
  - EXTJSIV-5904 Surface.removeAll - fails to remove items from groups
- Events (3)
  - EXTJSIV-5193 Resize event is not fired for custom form field
  - EXTJSIV-5815 Error using a mixin that itself has Ext.util.Observable as a mixin
  - EXTJSIV-5844 Events: option.target has been removed from 4.x
- Examples (2)
  - EXTJSIV-5948 Ext.ux.form.ItemSelector does not work with asynchronous loading (proxy) in ItemSelector example
  - EXTJSIV-5949 RC3: Ext.ux.form.ItemSelector.bindStore() method non-functioning
- Forms (8)
  - EXTJSIV-4978 Forms - Dynamic Forms : Unable to access Form 1, Form 2 & Form 5 when clicked on expand/collapse button and and pressed the tab key
  - EXTJSIV-5242 DisplayField does not respect fieldStyle
  - EXTJSIV-5826 Validation of timefield is not correct in Chinese.
  - EXTJSIV-5827 Work day is corrupt in Spanish date input
  - EXTJSIV-5832 Recreating an HtmlEditor makes it unable to be focused until ENTER is pressed
  - EXTJSIV-5906 Can't create trigger field outside of onReady
  - EXTJSIV-5937 CheckboxGroup has incorrect column loop
  - EXTJSIV-5955 Ext.form.Labelable uses a CSS class without baseCSSPrefix
- Grid (4)
  - EXTJSIV-5457 Grid infinite scroll: no last elements, no return to first elements
  - EXTJSIV-5847 Ext.ux.grid.FiltersFeature removes dynamically added filters
  - EXTJSIV-5894 GroupingSummary returns '\u00a0' when sum is equal 0
  - EXTJSIV-5953 TemplateColumn not updated dynamically
- Layouts (2)
  - EXTJSIV-5562 Horizontal scrollbar not visible when set to overflow in hbox layout
  - EXTJSIV-5941 Resizable Components in Absolute layouts get misplaced.
- MVC (1)
  - EXTJSIV-4202 Problem with building when MVC app has a custom directory structure
- Menu (1)
  - EXTJSIV-5804 Menu onClick does not fire in all cases
- Misc (4)
  - EXTJSIV-5134 Miscellaneous - Panels : "Masked Panel with a really long title" panel's UI is disturbed when clicked more than twice on expand/ collapse button
  - EXTJSIV-5501 Ext.Date.format breaks on wrong input
  - EXTJSIV-5899 Combination Examples:Ext JS Calendar:Displaying js error while creating the new event with empty date field.
  - EXTJSIV-5967 ElementLoader - inconsistent API (?)
- Panel (1)
  - EXTJSIV-5959 Panel with collapseFirst: false and closable does not display collapse tool button
- Tabs (2)
  - EXTJSIV-5099 Tabs - Advanced Tabs : Tabs are added without close button when clicked on "Add Closable Tab" button
  - EXTJSIV-5857 TabPanel children don't fire the close event
- Theme (1)
  - EXTJSIV-3712 TabBar background is blue in the gray theme
- Tree (2)
  - EXTJSIV-5908 Fast clicks in Tree can lead to duplication of entries
  - EXTJSIV-5952 Allow NodeInterface.decorate to expect a record instance for backward compatibility
- Window (1)
  - EXTJSIV-5897 Window's title will not display in IE6/7/8 when it was dragging
Total: 45

# Release Notes for Ext JS 4.1.0 RC 3

Release Date: April 10, 2012
Version Number: 4.1.0 RC 3

## Bugs Fixed

- Button (1)
  - EXTJSIV-5802 setIconCls() does not update the icon from within a beforerender listener
- Charts (2)
  - EXTJSIV-5816 Missing requires in Ext.chart.axis.Numeric
  - EXTJSIV-5852 Stacked Bar Chart shadow/border ghosts on redraw
- Core (4)
  - EXTJSIV-5819 syncRequire callback scope broken
  - EXTJSIV-5858 Ext.LoadMask destroy() method not hiding the mask
  - EXTJSIV-5873 frameSize property undefined when CSS3 framing is used.
  - EXTJSIV-5886 htmlEncode returns apos which is incompatible with IE
- Data (2)
  - EXTJSIV-5798 Reader should use current fields if metadata does not include a fields array
  - EXTJSIV-5823 Remote sort from a buffered store fails on small data sets.
- Examples (3)
  - EXTJSIV-5788 Simple tasks : Two "Dismiss" buttons are displaying in reminder popup.
  - EXTJSIV-5789 Simple tasks : "OK" button is not working in the "Set Default Reminder Time" pop-up.
  - EXTJSIV-5791 Simple Tasks : Not able to unhide the columns once all possible columns are hidden
- Forms (5)
  - EXTJSIV-5554 Issue with date format in Spanish locale.
  - EXTJSIV-5774 Bug in set focus on IE
  - EXTJSIV-5782 htmleditor in tab panel breaks layout when tab is destroyed
  - EXTJSIV-5850 Ext.Editor, startEdit event does not pass editor instance as first argument
  - EXTJSIV-5885 Forms - Advanced Validation - Months in the month selection menu are not properly aligned
- Grid (5)
  - EXTJSIV-5761 RowEditing plugin breaks Grid scrolling
  - EXTJSIV-5779 Tabbing on the last cell in a cell editing grid recurses infinitely.
  - EXTJSIV-5780 CellSelectionModel does not cope well with deletions of rows.
  - EXTJSIV-5814 Not possible to specify a column component on a locked grid (only a config)
  - EXTJSIV-5841 Key navigation in grid with no selection throws JS errors
- Layouts (2)
  - EXTJSIV-5793 Chrome 18 - broken layouts due to V8 NaN bug
  - EXTJSIV-5812 Specifying a placeholder for a region in a border layout fails if given as a config object
- Menu (2)
  - EXTJSIV-5828 Ext.menu.Menu.show - missing return this
  - EXTJSIV-5870 menuExpandDelay of Ext.menu.Item not working
- Misc (2)
  - EXTJSIV-5759 Ext 4.1 - What happened to hideMode: 'asclass'?
  - EXTJSIV-5843 Korean locale file is throwing an exception
- Tabs (1)
  - EXTJSIV-5231 GroupTabPanel UX doesn't work as expected
Total: 29

# Release Notes for Ext JS 4.1.0 RC 2

Release Date: March 30, 2012
Version Number: 4.1.0 RC 2

## Bugs Fixed

- Animation (1)
  - EXTJSIV-5523 Animation Incorrectly Positions Windows
- Button (3)
  - EXTJSIV-5429 Button with an icon can not be properly resized.
  - EXTJSIV-5432 Button icons are clipped at times (varying between browsers)
  - EXTJSIV-5600 Feed Viewer- Button names are left aligned in Add feed popup
- Charts (20)
  - EXTJSIV-3617 Rendering issue with stacked column chart without animation
  - EXTJSIV-3783 Area Chart - Farthest right tick not firing mouse events, showing tooltip, etc.
  - EXTJSIV-4459 If you try to render a chart in internet explorer 8 and you have animate=true, the markers will render, but lines themselves will never render
  - EXTJSIV-4544 Charts : Rich Tips - No tool tips are displayed upon mouse hovering on graph nodes for the second time.
  - EXTJSIV-4730 Combination Examples - Ext JS 3&4 on one page : Issue reloading legends inside Charts
  - EXTJSIV-4779 Bar Chart does not render correctly when all yField data points are equal
  - EXTJSIV-5007 Save button in chart examples should display popup panel to confirm save and then save image.
  - EXTJSIV-5024 Charts: Themed Line Charts: Wrong information shown on mouse hover in simple styling chart
  - EXTJSIV-5360 Stacked column with two series values incorrect
  - EXTJSIV-5462 Custom Pie Charts: Browser is forcibly closed when clicked multiple times on Reload Data button
  - EXTJSIV-5474 Chart - left axis not showing the max value
  - EXTJSIV-5499 Set width of column charts not working correctly
  - EXTJSIV-5571 Chart problems with decimals on bottom axis
  - EXTJSIV-5575 Grouped Bar charts: Incorrect values shown in series labels
  - EXTJSIV-5580 Charts : Area Charts: Chart "Legends " are not displaying properly in the downloaded files.
  - EXTJSIV-5623 Column charts displays wrong values/tips when disabling series
  - EXTJSIV-5633 Charts - Filled Radar charts - Chart is not displaying in Filled Radar chart example
  - EXTJSIV-5655 Charts- Column Custom Back ground - Save Chart button is not working.
  - EXTJSIV-5670 Charts - Stacked Bar Charts - Chart is not displaying upon hiding and unhiding the legends in the chart.
  - EXTJSIV-5706 Line series offset one sample to the left
- Coding Style (1)
  - EXTJSIV-5682 Remove extra comma in Ext.view.TableChunker
- Core (11)
  - EXTJSIV-4966 Global var in Renderable
  - EXTJSIV-5000 Problems with DOM Id containing colon and DomeQuery.jsSelect with CSS escape notation
  - EXTJSIV-5350 ItemSelector returns [undefined] when empty
  - EXTJSIV-5444 onReady Firing Twice
  - EXTJSIV-5460 FF 3.6's Number.toJSON violates standards. We must programatically encode Numbers.
  - EXTJSIV-5538 Themes examples has large memory leak when switching themes in IE
  - EXTJSIV-5552 Thousand separator and decimal separator are wrong for Chinese languages
  - EXTJSIV-5630 Observable broken for class observation
  - EXTJSIV-5641 CompositeElementLite: filter method is broken
  - EXTJSIV-5705 Document Element Mistakenly Garbage Collected
  - EXTJSIV-5765 Error when loading Ext later than initial page load
- Data (4)
  - EXTJSIV-5224 Store.removeAll does not remove any prefetched data
  - EXTJSIV-5415 Store load not triggered when opening ListMenu in FilterFeature
  - EXTJSIV-5508 Issue with Ext.data.reader.Reader onMetaChange listener and idProperty
  - EXTJSIV-5585 Sorters are not applied after using FilterBy() method
- DataView (2)
  - EXTJSIV-4854 LoadMask does not manage its z-index correctly WRT its client Component's z-index.
  - EXTJSIV-5667 Nested data is unavailable to templates in DataView
- Documentation (4)
  - EXTJSIV-5069 Ext.grid.feature.Grouping docs need to be clearer
  - EXTJSIV-5553 Miscellaneous: History - Page is redirecting to Home page when click on "History" Example
  - EXTJSIV-5584 Ext.Array.toArray end parameter incorrectly documented
  - EXTJSIV-5745 Grid Grouping collapse() is private, when it should be public
- Draw (2)
  - EXTJSIV-2097 viewbox: true ignores padding
  - EXTJSIV-5078 Missing scale/scaling support in Ext.fx.target.Sprite.setAttr
- Events (2)
  - EXTJSIV-5194 Card layout does not fire activate on initial view
  - EXTJSIV-5271 ComponentQuery "is" method fails if selector contains a comma
- Examples (9)
  - EXTJSIV-1146 Editor Grid Example: Clicking from Common Name in an editor to Light doesn't invoke an editor
  - EXTJSIV-4136 Portal demo :Unable to close the portlets in a specific scenario.
  - EXTJSIV-4533 Combination Examples : Kitchen Sink : Tabs : Titled Tab Panels: Not displaying complete text in Ext.tab.Panel with frame:true Panel
  - EXTJSIV-5529 Combination Examples : Image Viewer : Tool tip is stretched while trying to drag more than one image
  - EXTJSIV-5614 Combination Examples : Theme viewer : By default Slider values are displaying behind the resizable handles.
  - EXTJSIV-5617 Combination Examples : Image Viewer: By default Albums should display with expand and collapse ("+", "-") buttons when user drag and drop the files in to the albums.
  - EXTJSIV-5650 Example - Nested Loading shows a blank page
  - EXTJSIV-5666 PageAnalyzer hangs when loading pages (busy-spin)
  - EXTJSIV-5769 Combinatiion Examples - Ext JS Calender Sample- "Delete Button " is Missing on Edit Event dialog
- Forms (15)
  - EXTJSIV-4911 Resizers on TextFields do not always work properly
  - EXTJSIV-4940 Ext.form.TimeField class contained typeAhead, later releases the Ext.form.field.Time class this functionality is missing
  - EXTJSIV-5433 ChekboxGroup with all fixed width columns does not width the columns correctly.
  - EXTJSIV-5439 Hover icon changes to select when combo editor is disabled.
  - EXTJSIV-5530 Forms- Dynamic forms- Field headers and borders are not displaying properly.
  - EXTJSIV-5557 trackResetOnLoad has no affect on radiogroup after loadrecord()
  - EXTJSIV-5567 allowBlank not part of the default labelableRenderProps
  - EXTJSIV-5570 HtmlEditor: Tab and Enter presses aren't being correctly handled in readOnly state
  - EXTJSIV-5578 Forms File Upload Field Button names are truncated in IE 7
  - EXTJSIV-5618 Forms Custom Form Field: Search text is not deleting upon clicking on cross button(X)
  - EXTJSIV-5634 Forms - Shopping Chart Checkout- Text boxes and label captions are disappearing after uncheck and check Same as Mailing Address checkbox
  - EXTJSIV-5643 Forms : Checkbox/ Radio Groups : Contents under the Radio groups are not aligned properly.
  - EXTJSIV-5651 Checkbox Focus Class Malformed
  - EXTJSIV-5703 Selected form component/editor loses focus if grid in edit mode
  - EXTJSIV-5712 Forms Checkout Form Text alignment is disturbed for payment radio buttons
- Grid (31)
  - EXTJSIV-1679 Extra padding seen in grid for IE 6 & 7 versus all other browsers
  - EXTJSIV-3766 Not possible to set 'cursor' attribute on a Column chart series
  - EXTJSIV-3998 Vertical scrollbar doesn't appear when it should when using Row Expander plugin
  - EXTJSIV-4189 Field used as an editor in a Grid will fire change event when the field's value is initially set
  - EXTJSIV-4371 Grid Plugin Example: Bug in RowWrap. Hidden columns are not being hidden in data.
  - EXTJSIV-4564 Lockable grid does not register features
  - EXTJSIV-5003 Cell editor does not always work correctly with locked grid
  - EXTJSIV-5151 Unwanted sortchange and resize events on gridcolumns
  - EXTJSIV-5169 hide/show causes error when using a table layout
  - EXTJSIV-5251 Can't theme height of grid rows
  - EXTJSIV-5303 Remote filtering doesn't work quite right with infinite scrolling.
  - EXTJSIV-5313 injectCheckbox:false prevents check rendering in data rows
  - EXTJSIV-5323 grid.RowEditing plugin: error tooltip's arrow is misplaced on 1st show
  - EXTJSIV-5324 Missing grid loadMask on first load
  - EXTJSIV-5348 Error when using buffered grid + locking columns
  - EXTJSIV-5349 Can not control the style emptyText displayed in the grid. Need x-grid-empty support
  - EXTJSIV-5397 Problem setting grid column filters programmatically.
  - EXTJSIV-5398 CellEditing plugin+textfield editor doesn't completeEdit on header click.
  - EXTJSIV-5404 Grids : RESTful Store with GridPanel and RowEditor : Not able to add rows with data to the grid in a particular scenario
  - EXTJSIV-5510 Scrollbar in a grid defined with no header overlaps the grid row
  - EXTJSIV-5531 Grids: Grid with Locking Capability -The browser session is get killed once all the unlock columns are changed as lock columns
  - EXTJSIV-5573 Using loadingHeight keeps grid at loading height, doesn't recalculate after load complete.
  - EXTJSIV-5576 groupgrid is not showing properly in beta3
  - EXTJSIV-5581 Grid Live Search Grid : Find Previous Row [<] button is truncated
  - EXTJSIV-5586 Store remote filtering doesn't work with infinite scrolling.
  - EXTJSIV-5598 Grid Row Editing- Displaying Js Error when click on add Employee button or double click on any row in the grid
  - EXTJSIV-5599 Grids- Infinite Scroll Grid- All the topic links are changing to visited state if single topic link is visited / clicked
  - EXTJSIV-5616 Grid- Infinite Scrolling Grid - Sort Ascending / Sort Descending is not working for Author field
  - EXTJSIV-5707 CellEditing plugin needs to be more robust in case intervening listeners delete the targeted record.
  - EXTJSIV-5717 Grids Custom Grid Filters Displaying JS error while mouse hovering on filters option from Size column header drop down
  - EXTJSIV-5739 Grids : Grid Plugins : Collapse button '-' is moving to middle of the row, while the row is expanded
- Layouts (15)
  - EXTJSIV-4751 Layout issues in application upon clicking on one of the results in the grid.
  - EXTJSIV-5182 Toolbar layout is unexpected after first render
  - EXTJSIV-5270 Problem using table layout in center panel of a border layout
  - EXTJSIV-5274 Margin with fit layout and shrink wrap
  - EXTJSIV-5318 Layout Managers : Border Layout : "South Eastern" panel's UI is disturbed when collapsed and expanded the "South" panel
  - EXTJSIV-5320 Anchor Layout on a window, the title bar is rolled up into a circular header.
  - EXTJSIV-5435 Box layout interferes with layout of shrinkwrap items
  - EXTJSIV-5455 Configured placeholder for border region not respected
  - EXTJSIV-5551 Hbox layout doesn't recalculate height when align:stretchmax is set
  - EXTJSIV-5589 Container with vbox layout with minHeight set will not grow past minHeight when auto sized children added to this container
  - EXTJSIV-5665 Wrong priority of 'flex' vs fixed size in h/vbox layouts
  - EXTJSIV-5679 Hbox does not stretch vertically in a specific configuration
  - EXTJSIV-5711 Layout Browser Custom layouts. Center incorrect to the specification defined for Inner centered Panel width
  - EXTJSIV-5724 Layout Failure for Collapsed Fieldsets
  - EXTJSIV-5753 Layout Managers: Table Layout : Blank page when resizing the browser in IE Quirks
- MVC (2)
  - EXTJSIV-2311 Verify the focus on the tabs when user click on open all button
  - EXTJSIV-2312 Verify the tabs display when user click's on open all button.
- Menu (1)
  - EXTJSIV-5689 Large menus don't constrain to viewport
- Misc (65)
  - EXTJSIV-3782 MVC Feed Viewer - Load mask appears when switching feeds even if not viewing the feed tab
  - EXTJSIV-3943 Keyboard Feed Viewer - Highlighted color is not displaying correctly in IE 6
  - EXTJSIV-3990 Editor - Label captions are overlapping on the text fields when long label caption is entered without any space.
  - EXTJSIV-4022 Add "refresh" event to Store to match "datachanged" in v3
  - EXTJSIV-4123 Ext.Array.from() with function gives empty array
  - EXTJSIV-4125 getNode return wrong record after add new record
  - EXTJSIV-4171 User details - Drop down items are displaying at the top of the page when double-click on the Editor panel
  - EXTJSIV-4175 Button doesn't have proper markup or styling in IE in sandbox mode
  - EXTJSIV-4288 Grid row selection is cleared after store sync.
  - EXTJSIV-4397 Drag Drop Manager doesn't select correct drop target
  - EXTJSIV-4419 MessageBox doesn't fire callback when top-right close button clicked
  - EXTJSIV-4426 Problem with column header grouping at level 3. Columns can not be hidden.
  - EXTJSIV-4455 App freezes when an incorrect query is passed to Ext.app.Controller.control()
  - EXTJSIV-4555 Loading the Finnish locale file will crash an application using Ext.util.Format.date
  - EXTJSIV-4594 Transform of combo does not use configured store
  - EXTJSIV-4602 Syntax errors when compiling SASS themes
  - EXTJSIV-4845 Vml Draw/Sprite images not using X/Y offset in Vml
  - EXTJSIV-4847 Ext.Loader doesn't recognize files that are not under /app
  - EXTJSIV-4953 Localization(dynamic) : Displaying JS error upon selecting "Hebrew" from the Language selector.
  - EXTJSIV-4955 Checkboxgroups W/ More Columns Than Checkboxes Throws JS Error
  - EXTJSIV-4956 Creating A Checkbox Group /w Hidden Field Throws JS Error
  - EXTJSIV-5103 Bug with Implicit Model / Store / MixedCollection / Proxy
  - EXTJSIV-5138 Reader needs to read records even when success:false
  - EXTJSIV-5233 Combination Examples : Ext JS Calendar : Displaying JS error while upon click and hold the mouse on day event matrix.
  - EXTJSIV-5247 Border of child hidden if border of container is hidden
  - EXTJSIV-5383 Using two panels for both drag and drop fails
  - EXTJSIV-5441 Viewport with a configured height width sets the height and width on the document body causing the viewport to not fit the browser window in firefox quirks mode
  - EXTJSIV-5468 Loading indicator still visible with panel collapsed
  - EXTJSIV-5490 Possible bug when grouping by a template column in a grid
  - EXTJSIV-5497 Bug when centering components in vbox/hbox layouts
  - EXTJSIV-5506 Datepicker displays Invalid date format when chinese or japanese localization applied
  - EXTJSIV-5513 Miscellaneous : Editor : Displaying JS error upon double clicking on text labels
  - EXTJSIV-5522 Ext.String.htmlDecode / Ext.String.htmlEncode should operate on a larger set of characters/entities
  - EXTJSIV-5537 Ext.form.DateField returns incorrect value when localized
  - EXTJSIV-5546 dirtyCls style not applied to slider field
  - EXTJSIV-5559 Ghost image while dragging a panel
  - EXTJSIV-5564 All Date pickers: Not able to select date from date picker by using key board navigation keys, in all examples
  - EXTJSIV-5566 ComponentLoader should suspend layouts when adding/removing items
  - EXTJSIV-5568 ToolbarDroppable.calculateEntryIndex gets wrong index
  - EXTJSIV-5572 Issue with listeners for the store.load() event
  - EXTJSIV-5583 Accessibility : Binding Grid to a form : Month and Today button names are truncated in IE 7
  - EXTJSIV-5610 Web Desktop - Displaying Js Error upon double clicking close button of Accordion Window.
  - EXTJSIV-5631 Combination Examples - Portal Demo - Graph is not displaying in Stock Portlet
  - EXTJSIV-5635 Grids:Column swapping disturb the data in the Grid
  - EXTJSIV-5645 Bug when collapsing the only panel in an accordion layout.
  - EXTJSIV-5652 Toolbar that contains the error in datefield
  - EXTJSIV-5661 Syntax errors when compiling SASS themes
  - EXTJSIV-5663 Global leak in injectLockable
  - EXTJSIV-5669 Grids :Grouping with Remote Summary -The data in the grid get disturb while checking the Project column
  - EXTJSIV-5671 Combination examples: Kitchensink: Locking grid: lock/unlock options in the drop-down menu seen only first time.
  - EXTJSIV-5685 Grouping Feature error after remote data update.
  - EXTJSIV-5687 Ext.core.DomHelper overwrite only accepts DOM elements not Ext.Element instances
  - EXTJSIV-5693 Setting initially active tab using a string ID caused JS error.
  - EXTJSIV-5696 Return false on Tab beforeactivate not handled properly
  - EXTJSIV-5698 Drag/Drop Information Box hides in Ext.Window
  - EXTJSIV-5710 Grids :All Grids :The data under the columns get disturb while checking and un-checking the columns.
  - EXTJSIV-5714 Strange behaviour of DatePicker placing in Panel with vbox layout.
  - EXTJSIV-5718 Toolbars and Menus:Basic Toolbar: The page UI get disturb while mouse over on Choose a Date.
  - EXTJSIV-5730 Charts dont fire click/dblclick events
  - EXTJSIV-5732 Simple Tasks : Text Editor is displaying in the task list panel.
  - EXTJSIV-5737 Simple Task - Creation of New Folder/New List is displaying in wrong location
  - EXTJSIV-5740 Validation error message tool tip has truncated height
  - EXTJSIV-5751 Layout problems in PortalPanel with an anchor layout
  - EXTJSIV-5768 Combo Box - ComboBox Templates - Search results are disappearing on double clicking page next icon on pagination panel.
  - EXTJSIV-5773 Misc- Quick tips - Displaying JS error upon click on Rich Content Tooltip link after mouse hover on Anchor right, rich content button under callout Tip
- Panel (4)
  - EXTJSIV-5149 "mini" collapseMode in border layout doesn't seem to work
  - EXTJSIV-5312 Ext.form.Panel.getValues() does not respect isDirty argument
  - EXTJSIV-5445 Panels with html are 2px too high in IE quirks
  - EXTJSIV-5505 Corners of framed headers don't display correctly in old IE
- Tabs (4)
  - EXTJSIV-4178 Positioning problem when using TabPanel and a custom stylesheet
  - EXTJSIV-5315 Closing a tab moves to the first tab rather than going to the previous tab
  - EXTJSIV-5448 Tab icon is cut off in IE8 strict and IE9 strict
  - EXTJSIV-5613 Tabs - Advance Tab - All tabs are closing when closable check box is selected from submenu
- Theme (3)
  - EXTJSIV-5542 Hard coded value in variables/_grid.scss
  - EXTJSIV-5547 Some values are hard-coded values in the SASS files
  - EXTJSIV-5590 Opacity is compounding for components in a deeply nested disabled container
- ToolTips (1)
  - EXTJSIV-5408 Show delay not always working for qtips in tree grid
- Toolbars (1)
  - EXTJSIV-5742 Toolbars and Menus : Basic Toolbar : Top and Bottom arrows are not displaying when click on the scrolling menu button for the second time.
- Tree (7)
  - EXTJSIV-1887 Tree does not allow horizontal scrolling
  - EXTJSIV-3935 TreeStore doesn't allow root property to be an object path
  - EXTJSIV-4437 BorderLayout accordion region has buggy expand/collapse behavior when floated
  - EXTJSIV-4476 NodeInterface can lose dirty state and fail to send batched updates
  - EXTJSIV-4815 Trees : Drag and Drop reordering : After clicking on 'Expand All' and 'Collapse All' tree is not behaving as expected.
  - EXTJSIV-5219 Problem whith TreeGrid node (greater than 600 leafs)
  - EXTJSIV-5387 Trees : Drag and Drop Reordering: Expand All button is not responding for the second time.
- Window (4)
  - EXTJSIV-1732 Hiding the progress dialog window while it is being dragged breaks draggability
  - EXTJSIV-5310 Window position changes when resized
  - EXTJSIV-5507 Drag and drop on overlapped windows fires events in both windows
  - EXTJSIV-5608 zIndex is wrong for floated windows
Total: 212

# Release Notes for Ext JS 4.1.0 RC 1

Release Date: March 13, 2012
Version Number: 4.1.0 RC 1

## Bugs Fixed

- Button
  - EXTJSIV-5129 Button does not adhere to width setting in IE9
- Charts
  - EXTJSIV-4416 Chart label misaligned on numeric x axis
  - EXTJSIV-5459 Setting markers to be hidden in renderer has no effect when chart isn't animated
- Core
  - EXTJSIV-3710 LoadMask is broken in sandbox build
  - EXTJSIV-4920 setSize should cancel panel collapse animation
  - EXTJSIV-5179 XTemplate breaks in IE when trying to innerHTML on a TR and other table elements
  - EXTJSIV-5352 Bug with Ext.msg.Confirm and Translation/Localisation
  - EXTJSIV-5380 DomQuery fails to return nodes when searching XML document by "contains" pseudo-class
  - EXTJSIV-5416 Component ancestor searching inconsistent
  - EXTJSIV-5417 Observable.fireEvent does not return true when there are no listeners.
  - EXTJSIV-5443 Wrong Arguments Passed to onReady in Firefox
  - EXTJSIV-5502 DomHelper append causing javascript error
- Data
  - EXTJSIV-5035 Store.rejectChanges fails to remove all new records
  - EXTJSIV-5278 Store.rejectChanges should restore original record index
  - EXTJSIV-5337 A read exception should be fired on the reader rather than halting execution when bad data is returned from the server
- DataView
  - EXTJSIV-5526 DataView ? Multi-sort DataView: Not displaying any icons upon clicking on Type button
- Documentation
  - EXTJSIV-4054 Docs Landing Page Mentions Chrome 11
  - EXTJSIV-5314 Column layout from "Layouts and Containers" guide is incorrect
- Draw
  - EXTJSIV-5239 getBBox() does not work on text sprites
  - EXTJSIV-5246 Ext.draw.Sprite image x and y do not become effective
  - EXTJSIV-5356 Regression in Draw (only quirks mode) tests for IEs.
  - EXTJSIV-5368 CompositeSprite incomplete destroy
  - EXTJSIV-5492 Draw.rectPath unit test failure
- Examples
  - EXTJSIV-4533 Combination Examples -> Kitchen Sink -> Tabs -> Titled Tab Panels: Not displaying complete text in Ext.tab.Panel with frame:true Panel
  - EXTJSIV-5281 Combination Examples : Calender : Displaying JS error upon clicking on "Save" button in Add event form.
  - EXTJSIV-5287 Combination Examples: Portal Demo: UI of Portal Demo is disturbed when double clicked multiple times on expand/collapse button of "Options" panel
  - EXTJSIV-5411 Combination Examples ? Web Desktop: Panel headers of Accordion Window are not minimizing to the task bar
  - EXTJSIV-5532 Combination Examples - Portal Demo - Displaying JS Error while Accessing portal demo example.
- Forms
  - EXTJSIV-4940 Ext.form.TimeField class contained typeAhead, later releases the Ext.form.field.Time class this functionality is missing
  - EXTJSIV-5286 Forms: Checkbox /Radio Groups: Validation icon is wrongly displayed at "Alignment Test:" field when clicked on "Save" button
  - EXTJSIV-5322 Triggers are the wrong height in the checkout form example in IE6
  - EXTJSIV-5354 Changing slider on form does not trigger dirtychange
  - EXTJSIV-5359 Forms : File upload: Unable to upload files using Browse button.(Browse button is not working)
  - EXTJSIV-5389 Form gets dirty if a textarea field contains a leading line break
  - EXTJSIV-5396 Forms: Vbox Layout : Email id's are not displaying in the "Send to:" field In a specific scenario.
  - EXTJSIV-5401 Ext.form.field.File fields are not clickable
  - EXTJSIV-5426 Empty Combo inserts blank value
  - EXTJSIV-5428 After adding Ext.FocusManager.enable() to beginning of code unable to enter a blank space in a text field
  - EXTJSIV-5439 Icon changes in trigger even if disabled
  - EXTJSIV-5463 Forms - Shopping cart checkout form Alert message tool tips are displayed as shadows.
  - EXTJSIV-5494 When dragging a Slider Thumb, and the mouse moves outside the range, tracking ceases.
  - EXTJSIV-5519 ExtDirect Form Post (File Upload) doesn't work properly with hidden fields
- Grid
  - EXTJSIV-2061 Grid vertical scrollbar is reset when when the grid panel is collapsed and then expanded
  - EXTJSIV-3619 Column header misaligned after column resize until view scrolled horizontally
  - EXTJSIV-3770 Bug Tree/Grid Scroller Stops Working
  - EXTJSIV-4291 Spinner does not work when added to grid
  - EXTJSIV-4876 Horizontal Scrollbar with hideHeaders
  - EXTJSIV-5206 Issues with buffered grid and loading mask in ExtJS 4.1
  - EXTJSIV-5218 Localisation of "Loading..." grid message
  - EXTJSIV-5334 When loading Ext on demand and creating a Grid it fails
  - EXTJSIV-5361 ComboBox used as a grid column editor in cell editing does not save its value if the user selects an item in the drop down list and tabs to the next column
  - EXTJSIV-5382 Grids:Grouping - The "Show in Groups" check box is not working
  - EXTJSIV-5466 Grid column header heights and vertical text alignment are inconsistently implemented accross browsers
  - EXTJSIV-5467 Property grid rows are the wrong height
  - EXTJSIV-5518 Grid mask is shown above Window when grid panel and window overlap
- Layouts
  - EXTJSIV-2426 createChild bug in FF 3.6 with label element.
  - EXTJSIV-5347 Layout Managers - Complex Layout: "South" panel's expand/collapse button is displayed in expand mode even after panel is expanded
  - EXTJSIV-5476 Checkboxgroup layout doesn't calculate natural size properly
- MVC
  - EXTJSIV-4202 Problem with building when MVC app has a custom directory structure
  - EXTJSIV-4464 prepareAssociatedData method doesn't handle nested asssociations [Parature Inc]
  - EXTJSIV-5414 A standard combination of treeview, with an autoload store that has a direct proxy cause the load mask to hang
- Menu
  - EXTJSIV-4867 Ext.menu.Menu -> inside a container
- Misc
  - EXTJSIV-4175 Button doesn't have proper markup or styling in IE in sandbox mode
  - EXTJSIV-4326 Buffered scrolling is not working properly when using mouse wheel.
  - EXTJSIV-4525 Child panels with padding in border layout do not minimise correctly
  - EXTJSIV-4553 Combobox loses value once you reselect the same value
  - EXTJSIV-4563 Row Editing throwing error when used with locked columns in grid
  - EXTJSIV-4642 Chaining CompositeElement calls doesn't work as in Ext 3
  - EXTJSIV-4747 pagingscoller does not work with small page size
  - EXTJSIV-4844 Ext.data.Store -> autoDestroy config is missing
  - EXTJSIV-4857 [4.0.7] Combobox selectOnTab does not work in Webkit Browsers
  - EXTJSIV-4935 bulleted lists wrap around floating icon in MessageBox
  - EXTJSIV-5118 Tab scrolling doesn't work on IE9 standards
  - EXTJSIV-5136 Model#set([Object]) calls endEdit() with empty modifiedFieldNames arg
  - EXTJSIV-5195 [4.1 B1] Array methods should wrap native methods instead of delegating
  - EXTJSIV-5215 Floating component and its shadow may get out of sync
  - EXTJSIV-5226 [4.1 B2] Focus on OK button in MessageBox
  - EXTJSIV-5234 Combination Examples -Ext JS Calendar: First created event is shifting over second created event upon mouse click and hold for a while
  - EXTJSIV-5240 updateRecord requires record even though it stores the current record
  - EXTJSIV-5268 Infinite Grid example: sort by date "Last Post" and only 50 records remains in the grid
  - EXTJSIV-5289 Miscellaneous - Browser State Management: UI of "Browser State Management" is disturbed when double clicked multiple times on splitter collapse/ expand button of "Collapse /Width Panel"(only when window is in re-sized mode)
  - EXTJSIV-5325 Hbox and collapsing panels broken
  - EXTJSIV-5326 Inconsistent animate behavior for TreePanel
  - EXTJSIV-5363 Month picker OK button is incorrectly localized in ext-lang-es.js file
  - EXTJSIV-5390 An error is thrown when the portal is put inside a form panel
  - EXTJSIV-5392 Locked grid rows are out of sync when vertical scrolling
  - EXTJSIV-5410 The validation error message is rendered improperly in a certain case, causing it to align middle with the text field, instead of left aligned like it is supposed to.
  - EXTJSIV-5430 Portal example, dropping portals is much slower compared
  - EXTJSIV-5434 TaskRunner - initial run of task is delayed
  - EXTJSIV-5440 me.stretcher in pagingscroller is undefined when destroying a non rendered view
  - EXTJSIV-5442 Observable hasListeners optimization does not work with MVC EventBus
  - EXTJSIV-5446 Problem with radiogroup setValue
  - EXTJSIV-5451 Unable to borrow() more than one function
  - EXTJSIV-5453 Attempting to show a load mask on a panel results in an exception
  - EXTJSIV-5454 Space for scrollers reserved in various layouts
  - EXTJSIV-5479 FF10 specific function: Ext.view.Table.forceReflow. The 'table' el does not exist when this function is called.
  - EXTJSIV-5496 TaskManager doesn't break on runtime errors, but causes infinite loop
  - EXTJSIV-5513 Miscellaneous ? Editor: Displaying JS error upon double clicking on text labels
  - EXTJSIV-5517 Keyboard Feed Viewer Displaying JS error when click on Add feed button for the second time
  - EXTJSIV-5520 Ext.widget reports config is undefined
  - EXTJSIV-5534 Cleanup few remaining autoHeight and autoWidth configs (dead code)
  - EXTJSIV-5543 focus is lost on an active cell editor in an editable grid
- Panel
  - EXTJSIV-3371 Panel collapsibe behavior does not animate on Expand
  - EXTJSIV-4081 Framed Panel's header background position is incorrect in IE9
  - EXTJSIV-5376 Animated Border Layout Collapse Flicker
  - EXTJSIV-5493 Resizer stops working when panel is collapsed
- Performance
  - EXTJSIV-5269 Remove Image-Based Element Shadows
- Tabs
  - EXTJSIV-5511 MVC ? Feed Viewer: Clicking on "Open all" button not displaying all tabs for the first time
  - EXTJSIV-5512 Tabs: Tab Overflow Menu - Forward arrow and header menu buttons are not displaying
- Theme
  - EXTJSIV-5336 Theming: ButtonGroup Doesn't Respect $base-color
- Toolbars
  - EXTJSIV-5516 Toolbars and Menus - Basic Toolbar - Bottom arrow is missing in scrolling menu
- Tree
  - EXTJSIV-5166 TreeStore fails to load properly when config clearOnLoad is false [TJX]
  - EXTJSIV-5395 Drag n Drop for nodes within a tree is broken
- Window
  - EXTJSIV-2353 maximize doesn't account for where it's constrained
  - EXTJSIV-3365 Window with id retains settings across instances

# Release Notes for Ext JS 4.1.0 Beta 3

Release Date: Feb 17, 2012
Version Number: 4.1.0 Beta 3

## Bugs Fixed

- Animation
  - EXTJSIV-5358 Data view : Multisort Data View - Unpleasant flickering effect while sorting the items by click upon "Name" or "Type" buttons
- Button
  - EXTJSIV-5294 Disabled Link Button Renders Incorrectly
  - EXTJSIV-5295 Link Buttons Without Text Render Incorrectly
- Charts
  - EXTJSIV-5143 Axis isn't rendered when data points are undefined
  - EXTJSIV-5290 [4.1 beta 2] BUG Chart restoreZoom() function fails
- Core
  - EXTJSIV-5244 Ext.layout.container.Container configureItem function needs fixed.
- Data
  - EXTJSIV-4568 ComboBox clears filters on store when queryMode = 'local'
- Documentation
  - EXTJSIV-5207 remove release notes link from doc index.html
  - EXTJSIV-5209 broken link in our main index.html "Learn more on sencha.com"
- Examples
  - EXTJSIV-1635 The mask does not disappear completely in SpotLight example IE Quirks only
  - EXTJSIV-5192 Combination Examples : Kitchen sink :Displaying JS error upon clicking on "Grouped Grid" for the second time
- Forms
  - EXTJSIV-4831 Text fields with natural width are sometimes too narrow.
  - EXTJSIV-5286 Forms: Checkbox /Radio Groups: Validation icon is wrongly displayed at "Alignment Test:" field when clicked on "Save" button
- Grid
  - EXTJSIV-3632 Grid performance in IE with large number of columns
  - EXTJSIV-4828 Editing cell, the edit mask or the drop down shows up hidden and wrongly located
  - EXTJSIV-5184 Buffered Store's attempts to load prefetch buffer even if initial priming returned the full dataset.
  - EXTJSIV-5222 Grid items shift left in IE
  - EXTJSIV-5345 Grids (All Grids): Tool tip is displayed on top of the grid for the first time while swapping the columns
  - EXTJSIV-5346 Grids: Remote Summary Grid Example :Displaying JS error click upon "Due Date" Column header for the first time
- Layouts
  - EXTJSIV-4483 Invalidating a layout must restore original size models for children
  - EXTJSIV-5198 Nested auto-sized containers do not resize properly 4.1 Beta 1
  - EXTJSIV-5265 Margin and Padding Settings with Shrink Wrapping
  - EXTJSIV-5329 Direct - Direct Form: "Direct form's" UI is disturbed, by default "Phone Numbers" and "Location Information" tab sections are not properly displaying
- Menu
  - EXTJSIV-4867 Ext.menu.Menu -> inside a container
- Misc
  - EXTJSIV-4902 Text fields sometimes appear too narrow.
  - EXTJSIV-5115 Grid doesn't update cells with renderers
  - EXTJSIV-5128 Sandbox Desktop throws js error on load
  - EXTJSIV-5139 4.1 Ext.Element.fly is undefined
  - EXTJSIV-5160 Combination Examples : Ext JS Calendar : Displaying js error while clicking on date on the left panel calendar when the "Add Event" screen is open on the right panel.
  - EXTJSIV-5161 Combination Examples : Ext JS Calendar : Add/Edit Event pop up box is not displaying properly up on click on any event matrix.
  - EXTJSIV-5164 Bug in commitRecords of Ext.data.Operation
  - EXTJSIV-5168 Form not responding to dirtychange events
  - EXTJSIV-5170 Unexpected layout on hide then show of auto layout
  - EXTJSIV-5172 Ext.button.Button - publishInnerHeight issue
  - EXTJSIV-5183 textfield width is not correct in 4.1.0 beta 1
  - EXTJSIV-5196 readOnlyCls do not work for any field
  - EXTJSIV-5197 Ext.getBody().dom is undefined after a viewport is destroyed
  - EXTJSIV-5200 Possible bug: Show tooltip at given position
  - EXTJSIV-5201 Encoding issue on textfiel
  - EXTJSIV-5211 Collapsing panel in vbox layout form doesn't fully collapse
  - EXTJSIV-5216 c is not a constructor message at the very first example
  - EXTJSIV-5225 4.1Beta2: getting the ProgressBar text is wrong the 1st time
  - EXTJSIV-5227 Performing operations on background window brings that window to front
  - EXTJSIV-5229 Inconsistent line endings
  - EXTJSIV-5241 Minor bug in Direct Proxy 4.1 Beta 2 w/fix
  - EXTJSIV-5252 "Show in Groups" checkbox is checked when the grid is not grouped
  - EXTJSIV-5255 IE JS error (Regression) in getXY
  - EXTJSIV-5256 grid autoHeight
  - EXTJSIV-5260 Ext.slider.Multi/Single increments don't stop at arbitrary points
  - EXTJSIV-5262 Ext.MessageBox.confirm close button not firing callback
  - EXTJSIV-5267 Cannot create hidden &amp; disabled filefield
  - EXTJSIV-5275 Opacity not passed on to Ext.Layer shadow
  - EXTJSIV-5276 Ext.view.Table.collectData with rowexpander
  - EXTJSIV-5293 Unable to mix flex/width configs for grid columns in Firefox
  - EXTJSIV-5296 Infinite scrolling grid makes server call when bottom is reached
  - EXTJSIV-5297 PagingScrollbar doesn't ignore horizontal scrolling
  - EXTJSIV-5300 TextArea with grow sizes incorrectly based on the value of the TextArea
  - EXTJSIV-5328 Displaying JS error while accessing couple of ExtJs examples.
  - EXTJSIV-5333 Global varibable leak
  - EXTJSIV-5338 Load mask cannot be removed when animateTarget is set
  - EXTJSIV-5340 Ext.XTemplate no longer handles nested {parent} references
  - EXTJSIV-5388 Ext.FocusManager.enable() causes error in nightly builds from 2/14 and 2/15
  - EXTJSIV-5393 ComboBox needs 2 clicks to trigger
- Panel
  - EXTJSIV-5264 Issues with collapsing and expanding panels - similar issue found in Ext JS border layout example
  - EXTJSIV-5330 Accordion & Border Layout Collapsed Size
- Performance
  - EXTJSIV-5221 Frame Info Caching
- Tabs
  - EXTJSIV-5304 Styling of Disabled Tabs
- ToolTips
  - EXTJSIV-5210 QuickTips with fixed width "lock" to that width
- Window
  - EXTJSIV-5122 Window header heights are sometimes incorrect

# Release Notes for Ext JS 4.1.0 Beta 2a

Release Date: Feb 2, 2012
Version Number: 4.1.0 Beta 2a

## Bugs Fixed

- Misc
  - EXTJSIV-5217 [4.1-20120123] Unable to use 'class' model fields
- Performance
  - EXTJSIV-5142 Anchor layout can cause performance issues if overflow occurs.

## Summary

This beta 2 refresh introduces the Ext JS Page Analyzer which just didn't quite make it in Beta 2. The Page Analyzer helps you understand the performance characteristics of your application as it relates to Ext JS.

More information will follow regarding how to use the Page Analyzer, but to get started today, you'll need to copy the "/examples/page-analyzer" folder to the same server that you want to test (ensuring relative paths to ext-all.js and the resources/css folder).

Open the page-analyzer.html file from that folder and then enter the URL to the page you want to test and hit Load. Once the page loads, there is a breakdown of the layouts executed as well as a simple performance chart.

Look for more details to follow.

# Release Notes for Ext JS 4.1.0 Beta 2

Release Date: January 26, 2012
Version Number: 4.1.0 Beta 2

## Bugs Fixed

- Button
  - EXTJSIV-5066 Miscellaneous: Buttons: Disable buttons are click able
- Charts
  - EXTJSIV-5015 Issue in FormDashboard, default color is wrong for radar chart points
  - EXTJSIV-5113 Regression in Draw strict and quirks tests for almost all browsers.
- Core
  - EXTJSIV-4882 Invalid DOM id's can cause exceptions
  - EXTJSIV-5018 Ext.Number.snap does not take minValue into account
  - EXTJSIV-5084 Not allowed access to stylesheets when using file:// protocol
- DataView
  - EXTJSIV-5045 Data View :Animated Data View : Sliders and panel headers are disappearing after moving the sliders couple of times
- Documentation
  - EXTJSIV-3046 Field setValue() firing change event
  - EXTJSIV-4889 Overview guide is missing from 4.1 Beta 1
- Draw
  - EXTJSIV-5044 Drawing - Rotate Text : Displaying JS error upon clicking on slider bar
- Examples
  - EXTJSIV-4861 Need to create Upgrade Overview off of examples/index.html
  - EXTJSIV-4916 Combination Examples:Web desktop: Masking on the page is not removed after clicking on yes/No button in the pop-up dialog.
  - EXTJSIV-4925 Combination Examples : Web desktop :Displaying errors in error console upon clicking on "Accordion window" on the desktop.
  - EXTJSIV-4982 We need to link calendar to our main examples page
  - EXTJSIV-5026 Combination Examples : Ext JS Calendar : UI issues in "Ext JS Calendar" example
  - EXTJSIV-5094 Feed viewer - Combination examples : Displaying JS error upon clicking on tabs.
  - EXTJSIV-5095 Combination Examples : Web desktop : Features in the note pad are not applying for the selected text.
- Forms
  - EXTJSIV-4241 The behavior of the stripCharsRe attribute in fields is wrongly documented (or is wrong)
  - EXTJSIV-4879 Forms - Contact Us Form : UI is disturbed for "Contact Us" form
  - EXTJSIV-4948 Forms - MultiSelect and ItemSelector : UI of "ItemSelector Test" form is disturbed when clicked on "Clear" button
  - EXTJSIV-4970 Field CSS position change can break customized fields
  - EXTJSIV-5116 Forms: Checkbox/Radio Groups: Displaying js error on loading
- Grid
  - EXTJSIV-4647 Cell Editing with Summary Feature error on View refresh
  - EXTJSIV-4837 Grids: Grouped Header Grid - Extra space is created while drag and drop nested columns within the category header
  - EXTJSIV-4881 Grids - Basic Array Grid - Displaying JS error when refreshing the page after swapping the columns
  - EXTJSIV-4929 Grids - Grouping with Remote Summary : "Sponsored Projects" window is keep on loading and not displaying the data
  - EXTJSIV-4939 Grids - Grouped Header Grid : "Last Updated" column is not displayed when drag and dropped under the "Stock Price" group
  - EXTJSIV-4995 Grids - Infinite Grid : Data inside the grid is not displayed when vertical scroll bar is pull down
  - EXTJSIV-5022 Grid headerCt border-bottom-color should be #c5c5c5
  - EXTJSIV-5038 RowNumberer column header has no right border
  - EXTJSIV-5065 GridCellEditing: Hide 'Common Name' column and tapping on 'Add Plant' button shows text field as expanded
  - EXTJSIV-5091 TableView should not update its layout upon refresh if infinite scrolling is being used.
  - EXTJSIV-5141 Buffered scrolling omits last row in prefetch buffer
- Layouts
  - EXTJSIV-3697 Failed test: Verify Center Layout Page
  - EXTJSIV-4665 For an accordion layout in IE, the Tab key will hide the next sibling's header
  - EXTJSIV-4830 Cannot select radio button
  - EXTJSIV-4851 Layout Managers - Border Layout : Displaying js error when clicked on "North 2" layout header
  - EXTJSIV-4996 Layout Managers - Layout Browser : "Navigation" and "Footer" layouts are overlapping when clicked on "Footer" layout title bar
  - EXTJSIV-5089 Docked right components are incorrectly sized in IE6
- Menu
  - EXTJSIV-4867 Ext.menu.Menu -> inside a container
- Misc
  - EXTJSIV-4407 [4.0.7] Tab font variable never honoured
  - EXTJSIV-4685 Combination Example-Theme Viewer :Displaying JS error upon clicking on "Toggle Enabled" button in the Form Widget.
  - EXTJSIV-4749 [4.0.7] not possible to hide a column series in a chart with the hideAll()-method
  - EXTJSIV-4801 Row Editor breaking in 4.1 with a grouped header, and a store not initially populated
  - EXTJSIV-4862 We need to remove jira.html from our knightly zip
  - EXTJSIV-4871 Error with Ext.util.Animate
  - EXTJSIV-4874 Ext.draw (Ext.create) ExtJS 4.0.7/ 4.1(Win7)
  - EXTJSIV-4885 [4.1B1] Unused variable
  - EXTJSIV-4886 [4.1 B1] Button broken when handleMouseEvents is false
  - EXTJSIV-4887 Ext.Date and Ext.Number undefined on code passed to functionFactory() (sandbox)
  - EXTJSIV-4888 CSS doesn't get minified in 4.1 beta 1
  - EXTJSIV-4891 Visual Diff: Panel padding-top appears to be ignored
  - EXTJSIV-4894 Visual Diff: Buttons too wide
  - EXTJSIV-4895 Visual Diff: Window Shadows completely missing
  - EXTJSIV-4898 Visual Diff: Windows mis-sized, broken headers
  - EXTJSIV-4899 Visual Diff: Accordion borders all wrong
  - EXTJSIV-4900 Visual Diff: Themes example has a big border all around it
  - EXTJSIV-4901 Visual Diff: Header too tall, tools mispositioned
  - EXTJSIV-4905 Visual Diff: Missing grid top border
  - EXTJSIV-4907 Visual Diff: Panel header icon mispositioned
  - EXTJSIV-4908 Visual Diff: Missing group header text background color
  - EXTJSIV-4910 On Beta 1: JS error "el is null" when ACTUAL_BU is set to "K"
  - EXTJSIV-4911 Resizers on TextFields do not work in 4.1 Beta
  - EXTJSIV-4912 panel body size must not add borders twice
  - EXTJSIV-4915 Drawing : Browser Logs - The Logos(Safari,Sencha,Tiger) are not displaying as expected.
  - EXTJSIV-4919 Toolbar overflow scroller not working on a defined component
  - EXTJSIV-4924 examples/calendar -- TypeError: 'undefined' is not an object
  - EXTJSIV-4934 If paramsAsHash is true, but an Ext.direct load function takes no arguments, fail
  - EXTJSIV-4946 4.1: Form/Field isDirty() shows false if field has no original value
  - EXTJSIV-4949 Multiple Grid Instances with dockedItems
  - EXTJSIV-4950 slideOut Callback Called Too Soon
  - EXTJSIV-4960 [4.1 B1] Accordion layout - bad inline example
  - EXTJSIV-4964 [4.1 B1] CSS.createStyleSheet() error
  - EXTJSIV-4965 Grids: Grid Filters - The filter symbols(<,> ,=) are not properly displayed
  - EXTJSIV-4967 Is there a quick way to fasten tooltip on the top of floating window
  - EXTJSIV-4973 Component isVisible does not work if the component is not rendered.
  - EXTJSIV-4974 Ext.data.treeStore.removeAll is an unsafe method
  - EXTJSIV-4977 Miscellaneous : Resizable - The re-size handler is not displaying properly.
  - EXTJSIV-4984 Panel headers height in spotlight example is 2px off
  - EXTJSIV-4988 The Save button in charts should download an image (and show a popup for this)
  - EXTJSIV-4998 Chart: Pie slices does not show when values are small
  - EXTJSIV-5020 Panel height calculated too tall
  - EXTJSIV-5021 Property grid row height too small
  - EXTJSIV-5036 Fidelity: error when trying to save and update values on a form
  - EXTJSIV-5037 [4.1] Opened windows disappear when switching between tab panels
  - EXTJSIV-5050 Typo in src/data/Store.js
  - EXTJSIV-5052 rsync: link_stat "extjs/overview/." failed: No such file or directory
  - EXTJSIV-5070 TextField height Property Change
  - EXTJSIV-5073 disabled menuitem invoke menu - click-event
  - EXTJSIV-5077 [4.1-B1] Combo Box disappearing incorrectly
  - EXTJSIV-5107 [4.1] Nested fieldset not submitting it's checkbox
  - EXTJSIV-5145 Combination Examples : Ext JS Calendar - Displaying js error while drag and drop the event from header of the hour matrix to hour matrix.
- Panel
  - EXTJSIV-4701 Panel headers are disconnected from panel body
  - EXTJSIV-4868 Cannot setTitle on collapsed panel in border layout
  - EXTJSIV-4938 Panel collapse/expand animations break natural auto sizing
  - EXTJSIV-4997 Panel header dimensions are way off
  - EXTJSIV-5001 Window header is incorrectly bordered
  - EXTJSIV-5086 Vertical Panel headers have visual problems
  - EXTJSIV-5087 Panel headers on framed panels instantiated with collapsed: true are truncated in old IE
  - EXTJSIV-5114 Initially placeholder-collapsed Panels have z-index:5
  - EXTJSIV-5120 Collapsed vertical panel headers have tools inserted at the wrong positiong
- Selection Model
  - EXTJSIV-5040 [Wells Fargo TechnologyKeyboard navigation issue: the down arrow key regardless of whether you are holding down the ctrl key or not triggers a select on the next row
- Tabs
  - EXTJSIV-4462 Not Verified: loadmask showing on hidden components
  - EXTJSIV-5019 Tab position off when using plain
- Theme
  - EXTJSIV-5135 Fieldset padding is wrong on IE
- Toolbars
  - EXTJSIV-4880 Toolbars and Menus - Status Bar : Status bar of "Ext Word Processor" is not shown as browser's vertical scroll bar is moving up while typing any text in text area.
  - EXTJSIV-5147 Toolbars and Menus - Basic Toolbar - Top and Bottom arrows are missing in scrolling menu
- Window
  - EXTJSIV-5023 Windows: Window Variations: JS error on dragging constrained window

# Release Notes for Ext JS 4.1.0 Beta 1

Release Date: December 22, 2011
Version Number: 4.1.0 Beta 1

## Summary

We are very excited to get Ext JS 4.1.0 Beta 1 out to the community! Contained in this release are literally hundreds of bug fixes. As a first beta, there are several issues that we wanted to fix but decided that they were not critical enough to hold up the release any longer. These are documented in the known issues section of the ReadMe file in the distribution.

I wanted to take a moment to cover some of the internals that have changed. Some of these are new since 4.1 PR1, while other changes were introduced in 4.1 PR1 but have not been previously covered.

### Layout

#### Failures

As result of the design for the layout engine in 4.1, it is possible for improper configuration (or a bug) to cause a layout run to fail to complete all of its calculations. When this occurs, the layout simply stops and the partial results that have been flushed to the DOM are all that is visible. In some cases, the layout may be 99% complete and the failure may go undetected or appear as a minor visual anomaly. In other cases, the layout may fail early and leave the UI in a clearly broken state (much like a JS error during layout would do in previous versions).

#### Diagnostics

The first step if you suspect you are seeing a layout failure is to enable the layout diagnostics. This is done by replacing the normal "ext-all.js" file with "ext-all-dev.js" and adding a couple additional scripts. Like so:

                        <script type="text/javascript" src="/extjs41/ext-all-dev.js"></script>
                        <script type="text/javascript" src="/extjs41/src/diag/layout/Context.js"></script>
                        <script type="text/javascript" src="/extjs41/src/diag/layout/ContextItem.js"></script>

Obviously, the path to Ext JS 4.1 will vary for your environment. With the above modifications, the diagnostic log can be viewed in Firebug's or Web Inspector's console. For IE, the logs are stored in memory and can be displayed by typing the following in the address bar once the page has loaded:

                        javascript:void(Ext.log.show())

This can be bookmarked to create a "bookmarklet". The log is limited to 750 lines which can be changed like so:

                        <script type="text/javascript" src="/extjs41/ext-all-dev.js"></script>
                        <script type="text/javascript">
                            Ext.log.max = 1500;
                        </script>

### Model and idProperty

A common mis-configuration of Model is to not specify a proper "idProperty". This config property identifies the primary key of the model. This is easy to forget because "idProperty" defaults to "id". In 4.0, if there was no actual field in the Model by this name, you could encounter JS errors under some circumstances. In 4.1, this has been fixed by automatically defining the field by this name as a "string" property if there is no definition given.

This fix can, however, have unexpected side-effects. If you notice that your models have gained an "id" property this is most likely why. The solution is to configure your models with the correct "idProperty" value.

### Fields and Their Layouts

In Ext JS 4.1 PR1 and then again in Beta 1, fields and field layouts have undergone several internal changes. Before I dive into them, however, I wanted to cover several new configuration properties related to field rendering. We have talked to several customers who needed to replace the rendering logic of fields (things like the "renderTpl", "fieldSubTpl" or "labelableRenderTpl") to accomplish some basic tweaks for their applications. While this works, the properties being overridden are internal and have changed several times since 4.0. Rather than continue this cycle, we wanted to provide a more stable way to augment fields.

In Beta 1, we have added several "micro" render templates to decorate fields. Typically these will be just strings of simple markup, but they can be full XTemplates. These decorators are as follows:

- *Fields*: inputAttrTpl
- *Labelable*: beforeLabelTpl, afterLabelTpl, beforeSubTpl, afterSubTpl, beforeLabelTextTpl, afterLabelTextTpl and labelAttrTpl
- *Checkbox*: beforeBoxLabelTpl, afterBoxLabelTpl, beforeBoxLabelTextTpl, afterBoxLabelTextTpl, boxLabelAttrTpl
- *HtmlEditor*: beforeTextAreaTpl, afterTextAreaTpl, beforeIFrameTpl, afterIFrameTpl, iframeAttrTpl

The use of "afterLabelTextTpl" is demonstrated in two of the examples: /examples/form/dynamic.html and /examples/form/contact-form.html to render a simple "required field" indicator. Their role in rendering is probably obvious from their name. For further details, refer to the docs or the source for the various fieldSubTpl's or labelableRenderTpl. If there are other decorators that might be helpful, just let us know.

In 4.0 and 4.1 PR1 field layouts were a rather complex balance of positioning, floating and measurement with subtle timing dependencies. In Beta 1, field layouts have been modified extensively to allow the browser to do much more of this work. To support IE6 this required the use of tables. There are still some calculations required, typically around height, but this approach eliminated lots of calculation and measurement that we previously had to perform on each field, the cost of which added up quickly.

### Panel collapse

In 4.1 PR1, panel collapse was consolidated entirely into Panel. In 4.0, panel collapse was handled by Panel in many cases, but when contained in an Accordion or Border layout, these layouts would get very involved in the collapse/expand process. This change is unlikely to have impact on most applications, but could be important if the animation or other properties of collapsing have been customized.

### LoadMasks

Masking is now only shared for modal windows. Non-floating and non-modal components will now create their own masks. While support for using Ext.LoadMask on elements has been deprecated in favor of the Ext.dom.Element mask() and unmask() methods, the ability to mask elements is still supported.

Mask management has been improved to handle re-sizing and hiding of the owning component.

### Drag/Drop

In 4.1 Beta 1, the DragDropManager now consults the z-index to identify the top-most target of a drop. While this will fix many use cases of overlapping drop targets, it could also impact customized drag/drop processing.

### Store refresh event

In 4.1 Beta 1, stores now fire a 'refresh' event if their content is changed in a significant way. This event has the semantics of the 'datachange' event from Ext JS 3.x and was added because 'datachange' in 4.0 fires for any change to the store (including adding one item).

## Bugs Fixed

- Button
  - [EXTJSIV-3558] Button title doesn't display properly when only a few characters are used in webkit-based browsers.
  - [EXTJSIV-4184] Cascading child menu initial location is incorrect when near edge of viewport
  - [EXTJSIV-4438] Button Group layout is broken (breaks Themes example)
  - [EXTJSIV-4621] Combination Examples - Feed Viewer: Raises java script error when clicked on "Go to post" button
  - [EXTJSIV-4623] Combination Examples - Theme Viewer:Raising js error when clicked on expand/ collapse button of Masked Panel for Theme Viewer
  - [EXTJSIV-4677] Miscellaneous - Buttons : Not properly displaying buttons with text and icons
- Charts
  - [EXTJSIV-2514] Rich tooltips do not render correctly in 4.02 examples, and don't clear correctly
  - [EXTJSIV-3493] [4.0.4] Pie Chart should display blank canvas when store load empty dataset
  - [EXTJSIV-3626] Radar Chart Line Connectors do not Appear With Default Theme
  - [EXTJSIV-3630] groupBy throws an exception when changing from 'year,month,day' to 'year,month'
  - [EXTJSIV-3765] [4.0.0] Ext.chart.series.Column: if you mouseOut the column, it will get a black border permanently.
  - [EXTJSIV-3783] Area Chart - Farthest right tick not firing mouse events, showing tooltip, etc.
  - [EXTJSIV-4040] [4.0.6] Gauge Chart Does not Support Tooltips or Mouse Listeners
  - [EXTJSIV-4133] Portal Demo : "Graphs" In the "Stock portlet" are not displaying.
  - [EXTJSIV-4252] Styling attributes defined in the highlight attribute of the Ext.chart.series.Series class are not considered.
  - [EXTJSIV-4270] Stacked Bar Chart - Long digit number is displaying in the X-Axis when disabling all the legend items (except "Thriller")
  - [EXTJSIV-4280] Charts - Rich Tips - Legend window is truncated on the right side when hovered on corner points in the chart.
  - [EXTJSIV-4303] [4.0.7] [4.0.6] VML - broken text rotation
  - [EXTJSIV-4337] Series, radar graph, tips not passing argument
  - [EXTJSIV-4366] CPU load graphs are not displaying upon clicking on graph legends.
  - [EXTJSIV-4429] [4.0.7] Pie chart series draws incorrectly
  - [EXTJSIV-4459] If you try to render a chart in internet explorer 8 and you have animate=true, the markers will render, but lines themselves will never render
  - [EXTJSIV-4502] [4.0.7] Pie chart with two data items, where the first is zero draws oddly
  - [EXTJSIV-4505] Charts -> Filled Radar Charts : JS Error is displayed when clicked on any legend item.
  - [EXTJSIV-4536] Chart with gradients turns black when displayed on more than one tab page.
  - [EXTJSIV-4544] Charts : Rich Tips - No tool tips are displayed upon mouse hovering on graph nodes for the second time.
  - [EXTJSIV-4589] Charts -> Line chart: Tapping on 'Reload Data' button multiple times shows blank chart
  - [EXTJSIV-4603] When hiding then showing an item from Pie Chart Legend, the Chart dose not display the field label.
  - [EXTJSIV-4604] Chart doesn't show labels, background, X axis, and Y axis in case data model is empty. Chart should be displayed empty.
  - [EXTJSIV-4614] Charts -> Area chart: Chart not rendered completely and Reload Data button not functional
  - [EXTJSIV-4622] Combination Examples - Web Desktop(Updated): Raising js error when mouse hovered on pie chart under System Status window
  - [EXTJSIV-4671] Combination Examples - Portal demo -Only "djia" graph is displayed in the stock portlet.
  - [EXTJSIV-4732] Charts - Area charts - Displaying Js error upon clicking on legend items In the chart
- Core
  - [EXTJSIV-1755] Examples: Resizer custom resizable handles indicates drag without enabling it
  - [EXTJSIV-1996] Container findX method consistency and missing functionality
  - [EXTJSIV-2545] LoadMask's mask el is behind any Window
  - [EXTJSIV-3379] ClassManager - define()'ing the same class multiple times will corrupt the namespace cache
  - [EXTJSIV-3621] In Ext.core.Element.unclip method at core/src/dom/Element.style.js, variable "o" is used before assigned
  - [EXTJSIV-3709] LoadMask doesn't entirely cover document.body
  - [EXTJSIV-3721] Async Loading of Ext in an IFrame in IE: loading Ext in an iframe and the onReady call has no effect
  - [EXTJSIV-3743] isUpload params behave differently to form
  - [EXTJSIV-4156] itemadd does not fire when adding to an empty view
  - [EXTJSIV-4186] XTemplate does'nt handle single quote properly in some case.
  - [EXTJSIV-4482] Style names in style and bodyStyle must be proper CSS names
  - [EXTJSIV-4540] Class system blows up with stack overflow on IE
  - [EXTJSIV-4580] Memory leaks in the framework - (e.g. on the theme example)
- Data
  - [EXTJSIV-2528] setRootNode doesn't allow model instance
  - [EXTJSIV-3295] layout fit grid scrollbar does not scroll content
  - [EXTJSIV-3304] Wrong height of the north and south panels in the border layout in a window
  - [EXTJSIV-3315] Wrong file in gray theme - [4.0.2a]
  - [EXTJSIV-3317] [4.0.2a] Remotefilter on buffered store and prefetch.
  - [EXTJSIV-3318] Using checkbox selection model in the editable grid produces an error
  - [EXTJSIV-3319] [extjs 4.x] How to use &quot;showInInlineEditor&quot; in ExtJS 4?
  - [EXTJSIV-3320] EXTJS4 Tab iconCls height bug
  - [EXTJSIV-3339] Grid plugin example not working [4.0.2a]
  - [EXTJSIV-3340] Empty Column List when there are many columns
  - [EXTJSIV-3344] Wrong example code in Object#merge()
  - [EXTJSIV-3352] Resetting the editable combobox to non empty original value results in empty val
  - [EXTJSIV-3546] [4.0.4] autoSync not working in TreeStore
  - [EXTJSIV-3657] hasOne association isn't retrieved in getAssociatedData
  - [EXTJSIV-3836] Field mapping on idProperty can cause incorrect internalId
  - [EXTJSIV-4039] [4.0.6] Store.clearData() does not clear records from &quot;removed&quot; cache
  - [EXTJSIV-4124] [4.0.6] Ext.data.TreeStore.load - Async Concurrency Problem
  - [EXTJSIV-4125] getNode return wrong record after add new record
  - [EXTJSIV-4188] Ext.data.proxy.Direct and Ext.form.Panel#api are not compatible with ExtJS 4 MVC
  - [EXTJSIV-4211] Loading a store from controller using Ext.Direct: hen the paramOrder config is specified as a string, it's split into an array but it's not correctly passed up to its parent as an array
  - [EXTJSIV-4227] Where did rejectChanges() go?
  - [EXTJSIV-4238] Store's "write" and "datachanged" events do not fire after saving a record if the proxy is defined on the record
  - [EXTJSIV-4240] After calling Model#save(), the model instance that is passed to the success callback is not the same instance that was saved.
  - [EXTJSIV-4242] Newly created records in TreeStore can't be accessed using TreeStore#getNodeById()
  - [EXTJSIV-4278] [Infor Global Solutions] Ext.data.proxy.JsonP.destroy does not pass arguments in callParent
  - [EXTJSIV-4309] Ext.data.Store.loadRawData does not set total property
  - [EXTJSIV-4333] [4.0] Bug in the Ext.data.Store constructor
  - [EXTJSIV-4415] All samples are showing as "undefined" in the right column side-box of examples page
  - [EXTJSIV-4433] Too much recursion in Ext.data.JsonP.abort
  - [EXTJSIV-4446] Ext.ModelManager.getCount() returns always 0
  - [EXTJSIV-4594] Ext 4.0.7 - Transform of combo does not use configured store
  - [EXTJSIV-4597] Ext.data.Store.filter does not reset page number?
- Direct
  - [EXTJSIV-3949] Direct : Displaying JS error while accessing Direct Tree loader example
  - [EXTJSIV-4659] Direct - Direct Named Arguments-: Age field is not displaying in the Example
- Documentation
  - [EXTJSIV-4219] [4.0.2] panel Tool types documented AND in CSS, but not in sprite.
  - [EXTJSIV-4349] API docs on() method signature
  - [EXTJSIV-4609] Absolute, Accordion, Border and Table layouts have the deprecated layoutConfig
  - [EXTJSIV-4662] Documentation: Ext.Loader -> setConfig(): the example code contains a <script> tag instead of </script>:
- Draw
  - [EXTJSIV-2097] viewbox: true ignores padding
  - [EXTJSIV-3950] Drawing : Displaying blank page while accessing Rotate Text (New) example
  - [EXTJSIV-4247] [Ext 4][B3] Ext.draw.Component - click event fires twice
  - [EXTJSIV-4382] Browser Logo Example: Bug with drawing bounds. Images are clipped at top
  - [EXTJSIV-4572] [4.0.7] Error when making Ext.Img resizable
  - [EXTJSIV-4753] Drawing : Resizable Sencha Logo - Unable to resize the Sencha logo
- Events
  - [EXTJSIV-3590] keypress event catch and handling at check tree
  - [EXTJSIV-4132] CheckboxModel select event is not being triggered when you select from select all
  - [EXTJSIV-4160] Mouse events on Sprites not usable
  - [EXTJSIV-4264] Bug in relayEvents together with prefix
  - [EXTJSIV-4275] Ext.view.View itemadd event fired too early
  - [EXTJSIV-4466] [4.0.7] RadioGroup. Active value - error in the newValue param of the change event.
  - [EXTJSIV-4478] Column headerclick Event Not Working
  - [EXTJSIV-4627] [4.1.0PR] LoadMask listeners not removed when component is destroyed
  - [EXTJSIV-4778] SplitButton not passing the event object on click
- Examples
  - [EXTJSIV-1134] Grid: Right aligned headers need additional padding on the right
  - [EXTJSIV-1135] Paging grid example - show preview is missing an icon
  - [EXTJSIV-1151] MessegeBox - cannot press escape on confirm
  - [EXTJSIV-1692] Hard Error: New desktop example. Click on About Ext JS in start menu in IE 8 and then close the video window
  - [EXTJSIV-2011] Failed test: Verify correct Buttons / icons are displayed for Sell Stock, Buy Stock and Hold Stock and check tool tips
  - [EXTJSIV-2029] Failed test: Verify Default view of Grouping with Remote Summary .
  - [EXTJSIV-2163] Failed test: Verify the User is able see the Google Map
  - [EXTJSIV-2254] Failed test: Verify page alignment while resizing the browser
  - [EXTJSIV-2276] Collapsing a tree panel w/collapsed nodes throws JS error
  - [EXTJSIV-2280] Failed test: Verify the Scroll bars in the note pad
  - [EXTJSIV-2283] Failed test: Verify the memory usage pie chart when user click's on legends continuously
  - [EXTJSIV-2286] Failed test: Verify the charts display when user resize the system status window
  - [EXTJSIV-2287] Failed test: Verify the "About Ext Jst" item in statrt menu .
  - [EXTJSIV-3756] Combination Examples : Feed Viewer - Throwing Error message upon adding a valid feed in a specific scenario.
  - [EXTJSIV-3955] Displaying JS error while accessing Theme viewer and "Ext JS 3 & 4 on one page" examples
  - [EXTJSIV-3959] Portal Demo - Displaying JS error when click on expand/collapse button
  - [EXTJSIV-3961] Key Feed Viewer - Displaying JS error while accessing Key Feed Viewer example
  - [EXTJSIV-4008] Quick Tips Example - No space between buttons under Easiest Tip & Callout Tip
  - [EXTJSIV-4085] Combination Examples : Feed viewer - "Summary" button is not working in preview pane.
  - [EXTJSIV-4136] Portal demo :Unable to close the portlets in a specific scenario.
  - [EXTJSIV-4346] Center custom layout example is broken
  - [EXTJSIV-4365] Kitchen Sink: a) Store defined with no model. b) GET http://localhost/ext-4.1-pr1/resources/themes/images/neptune/dd/drop-no.gif 404 (Not Found)
  - [EXTJSIV-4367] Web Desktop sample: Displaying following error 84Error: Problem parsing d=""
  - [EXTJSIV-4368] ExtJS 3 & 4 on one page sample: JS error: 'colors' is null or not an object
  - [EXTJSIV-4370] Theme Viewer Example: Mouse is stick to Resizable handle and not able to navigate away.
  - [EXTJSIV-4393] Drag and Drop Example: JS error is displayed
  - [EXTJSIV-4447] Webdesktop: Displaying blank page while accessing webdesktop example
  - [EXTJSIV-4548] Combination Examples - Feed viewer : Unable to scroll the data in feed preview panel after selecting the Hide option in the preview drop down menu.
  - [EXTJSIV-4559] Feed Viewer & MVC - Feed Viewer - Created empty row/ space with a bullet upon clicking on open all button
  - [EXTJSIV-4658] Combination Examples - EXT JS 3 & 4 on one page - Showing JS Error while accessing the page
  - [EXTJSIV-4676] Combination Examples - Portal demo :Displaying Js error upon reordering portelts in a specific scenario
  - [EXTJSIV-4680] Combination examples : Theme viewer - Horizontal & Vertical scrollbars are disappearing upon changing the themes in the theme viewer example
  - [EXTJSIV-4686] Combination Examples:Unable to expand/collapse north & east panels upon clicking on panels collapse button continuously.
  - [EXTJSIV-4707] Combination examples : Web desktop - Displaying blank page upon accessing webdesktop example.
  - [EXTJSIV-4713] Combination examples:Theme viewer-Unable to expand the "Tree panel" window once after collapse
  - [EXTJSIV-4758] Combination Examples:Web desktop - Desktop covered with mask after opening the examples in the taks bar.
  - [EXTJSIV-4772] Combination Examples : Web desktop: Unable to minimize the windows upon clicking on title headers in the taskbar.
- Forms
  - [EXTJSIV-2218] Failed test: Verify the time field in the Form fields type form
  - [EXTJSIV-2229] Failed test: Verify whether live search functionality is displaying correct results and topics by giving invalid data
  - [EXTJSIV-2240] Failed test: Verify the user is able to enter details manually in the Company details table
  - [EXTJSIV-2242] Failed test: Verify the error message when user click on save button without filling mandatory fields.
  - [EXTJSIV-2360] Failed test: Verify whether live search functionality is displaying correct results and topics by giving valid data
  - [EXTJSIV-3341] adding checkbox in checkbox group (4.0.1)
  - [EXTJSIV-3445] getFieldValues deprecation needs to be removed from the compat layer
  - [EXTJSIV-3624] Bugs with Ext.form.field.Combo and Editor Grids
  - [EXTJSIV-3690] Model background (gray color) is not completely stretched in the page & Confirmation message pop-up window is allowed to click on the other controls in the page
  - [EXTJSIV-3701] Time field's "setValue()" method does select the value on the picker dropdown.
  - [EXTJSIV-3939] Bulk-rendering: Trigger field: Trigger needs to have its afterRender logic transplanted or at least we need to suspend layouts during render
  - [EXTJSIV-3948] Forms : Displaying JS error while accessing MultiSelect ItemSelector & Custom Form Fields examples
  - [EXTJSIV-3999] Forms : Registration Form - Registration form is not properly loaded in registration example page on FF3.6,Google Chrome 10
  - [EXTJSIV-4012] RadioGroups broken in 4.0.2
  - [EXTJSIV-4196] Validation error not shown when user types 15/18/2001 in a date field: value is changed into 15/06/2002 when leaving the field.
  - [EXTJSIV-4233] Forms don't remember field state
  - [EXTJSIV-4329] Fieldset body div is sized to be too tall
  - [EXTJSIV-4387] Forms Example: JS error: 'length' is null or not an object
  - [EXTJSIV-4388] Form Example, Registration Form: JS error is displayed
  - [EXTJSIV-4497] MultiSelect & ItemSelector - Displaying JS error when uncheck Toggle enabled check box
  - [EXTJSIV-4506] Forms - Binding a Grid to a Form - Rating label caption alignment in not proper. Label caption should align next to radio button
  - [EXTJSIV-4535] "Form" : "Custom form field"- Displaying wrong page numbers in the pagination
  - [EXTJSIV-4648] Ext.form.FieldSet: beforecollapse and beforeexpand events aren't implemented
  - [EXTJSIV-4667] Trigger field disabling is broken
  - [EXTJSIV-4684] Checkbox / Radio Groups:The validation message for "Custom Layout" in Check box Group field set is not properly aligned.
  - [EXTJSIV-4695] Forms: Displaying JS error while accessing the "File Upload Field" and "Custom form Field" examples
  - [EXTJSIV-4734] Shopping cart checkout : Fields are missing in the payment field set
  - [EXTJSIV-4754] Forms : File Upload Field - File browse window is getting displayed upon clicking on "Name"field
  - [EXTJSIV-4755] Forms : File Upload Field - Uploaded file name is not displaying in file upload form "Success" dialog box.
  - [EXTJSIV-4769] Forms - File Upload Field : Displaying js error while accessing the File Upload Field example
- Grid
  - [EXTJSIV-1158] Paging Grid: No default text for topics
  - [EXTJSIV-1171] Grid: Dead Corner when Scrolling Horizontally
  - [EXTJSIV-2005] Failed test: Verify Sort Ascending for the column in the Cell Editing Grid
  - [EXTJSIV-2014] Failed test: Verify the tab scrollers if there are no tabs to display
  - [EXTJSIV-2015] Failed test: Verify the tabs display when user click's on open all button for more than once
  - [EXTJSIV-2019] Failed test: Verify Index column in the Grid with Numbered Rows grid.
  - [EXTJSIV-2053] Failed test: Verify the Search functionality for the Regular Expression check box.
  - [EXTJSIV-2078] Failed test: Verify the Time filed in the form widget
  - [EXTJSIV-2329] Failed test: Verify the user is able to Reset the grids
  - [EXTJSIV-2375] Grids scrollbars has 1px off
  - [EXTJSIV-2401] Failed test: Verify Add columns in the Grid plugin
  - [EXTJSIV-2418] Failed test: Verify whether selected Cell is allow to Edit in the Cell Editing Grid
  - [EXTJSIV-2444] Failed test: Verify scroll bar appears when size of the columns are increased or vice-versa
  - [EXTJSIV-2458] Failed test: Verify the lock functionality in the grid
  - [EXTJSIV-2543] Cell Editing, intra-row change of focus.
  - [EXTJSIV-3309] Grid reconfigure breaks columns layout
  - [EXTJSIV-3378] Filtered result set does not change size of scrollbar, result set repeated when scrolling beyond bounds of actual result set
  - [EXTJSIV-3395] Columns headers are missing upon increase the column size.
  - [EXTJSIV-3402] 4.0.2 Grid vertical lines of the header and those of the rows don't correspond in IE9
  - [EXTJSIV-3419] RowEditing can't change back to the original loaded value
  - [EXTJSIV-3628] 4.0.2 Cell not editing correct value when data in cell is updated..
  - [EXTJSIV-3636] Setting the iconCls config on Ext.grid.column.Action results in the css class being added to the acual <img> element twice
  - [EXTJSIV-3643] Grouped Grid - Adding new record in a list retrieves incorrect data
  - [EXTJSIV-3763] [4.0.5] Hard crash in IE when rendering locking grid to a table cell
  - [EXTJSIV-3775] [4.0.5] 'itemclick' event doesn't bubble when using locking grid
  - [EXTJSIV-3797] Ext.grid.column.Column 'id' config gets put directly into the DOM, allowing ID duplication and random issues
  - [EXTJSIV-3899] Event sequence grid/view/selectionmodel not correct
  - [EXTJSIV-3921] RowEditor Update/Cancel buttons outside of grid viewport
  - [EXTJSIV-3951] Grid from Markup - Column header is displaying at the top of the page when click on "Create Gird" button.
  - [EXTJSIV-3953] Cell Editing Grid - Not able to add/edit a record in the grid when Add plant button is selected in IE 6 & 7.
  - [EXTJSIV-3962] Setting width to negative value throws a JS error in IE
  - [EXTJSIV-3994] How to prevent extjs grid from scrolling when clicking on a cell ?
  - [EXTJSIV-3998] Vertical scrollbar doesn't appear when it should when using Row Expander plugin
  - [EXTJSIV-4000] Resizing columns while row-editing a grid messes up column headers
  - [EXTJSIV-4011] Grid filter extension: filters menu item appearance bug
  - [EXTJSIV-4019] Drag and drop : Grid to Grid DnD - Displaying JS error upon placing the cursor on a specific area in "Record Name" column header
  - [EXTJSIV-4021] Problem with stateful grouped header grid
  - [EXTJSIV-4024] XML Grid - By default horizontal scroll bar is appearing in IE 8 and disappearing after click on any column header
  - [EXTJSIV-4052] Rows get out of sync only when grid is scrolled to the very bottom - All browsers
  - [EXTJSIV-4086] Grouping with Remote Summary - Show summary button is not working.
  - [EXTJSIV-4092] Grids Columns are 1px off with IE9 in quirk mode
  - [EXTJSIV-4094] Scroll bar in grid panel stops responding
  - [EXTJSIV-4127] Grid ColumnLayout forceFit "calculate" method update
  - [EXTJSIV-4152] Ext4: How to do grid grouping groupHeader with dynamic grouping field header text?
  - [EXTJSIV-4161] [4.0.0] RowEditor ignores errorSummary
  - [EXTJSIV-4168] Grid bug when using reconfigure() and locked column
  - [EXTJSIV-4185] Stateful grid with remoteSort true does not restore column sorting
  - [EXTJSIV-4228] Style information attached to the metadata parameter of the renderer function is overridden by global style column attributes
  - [EXTJSIV-4248] [4.0.2a] Grid sorter damaged when using a stateful grid
  - [EXTJSIV-4249] examples/grid/group-header-grid.html allows sub group to become primary
  - [EXTJSIV-4258] Ext.grid.plugin.CellEditing + Ext.selection.CheckboxModel = TypeError
  - [EXTJSIV-4281] Infinite Scrolling - Blue lines are displaying when uncheck all other columns and decreasing the topics column size in IE 8
  - [EXTJSIV-4282] Row Editor fields are not aligned to the grid cells properly when used on a grid with a checkbox selection model
  - [EXTJSIV-4310] [4.0.7] Ext.Application and result of fireEvent: fireing event beforeedit do not return a boolean when grid is initialise with Ext.application
  - [EXTJSIV-4314] grid-row-over class gets removed if the data in the record underlying a hovered row is changed
  - [EXTJSIV-4317] When using cell editing with row selection model, editor dies when moving to column that does not have an editor defined.
  - [EXTJSIV-4323] grid sort - missing icon from grid header after reconfigure
  - [EXTJSIV-4347] Modifying of saveBtnText, cancelBtnText in Ext.grid.plugin.RowEditing - don't get passed into Ext.grid.Roweditor
  - [EXTJSIV-4371] Grid Plugin Example: Bug in RowWrap. Hidden columns are not being hidden in data.
  - [EXTJSIV-4398] [4.1PR][ALL BROWSERS] Grid View Update problems when moving &amp; resizing columns
  - [EXTJSIV-4420] Initial LoadMask on GridPanel not shown
  - [EXTJSIV-4424] Calling reconfigure on a grid with CheckBox model causes additional checkbox columns
  - [EXTJSIV-4430] Ext.grid.property.Property sortableColumns Ignored
  - [EXTJSIV-4454] Displaying JS errors while accessing Grid Cell editing,RESTful Store with GridPanel and RowEditor,Editable Grid with Writable Store,Toolbar Button Groups Vertical Toolbars examples
  - [EXTJSIV-4470] Grids : Grid Filtering (Updated) :Displaying JS error upon clicking on "All filter data" in grid filters example.
  - [EXTJSIV-4484] Grids:Grouping Grid Clear grouping button is not working
  - [EXTJSIV-4493] Scrollbar gets out of sync when new records are added to the grid
  - [EXTJSIV-4496] Grids: "RESTful Store with GridPanel and RowEditor" and "Editable Grid with Writable Store" examples throw JS error while accessing in IE6 browser
  - [EXTJSIV-4501] [4.1PR][IE7,IE9] Space between Grid View and scrollbars are off.
  - [EXTJSIV-4504] Dragging a group column does not move all columns in the group.
  - [EXTJSIV-4507] Grids -> Grids with locking capability: JS error is displayed while trying to unlock 'Company Name' column.
  - [EXTJSIV-4508] Grids -> Grouping Grid: JS error is displayed when clicked on 'Group by this field' or when tried to uncheck 'Name' column.
  - [EXTJSIV-4515] CellEditor doesn't work with RowBody and RowWrap grid features [Deer Valley Unified School District]
  - [EXTJSIV-4546] Grids : Buffered grid - Data In the salary column is not displayed in sorted order after moving the data by using scroll pointer.
  - [EXTJSIV-4551] Localization - GroupingFeature: Ext.grid.GroupingFeature is wrong
  - [EXTJSIV-4560] Drag and Drop - Field To Grid DnD : Cell that is dragged and placed the text "test" is not sorting properly under company column
  - [EXTJSIV-4567] Using paging grid within a form makes page input a form field
  - [EXTJSIV-4579] Grids editing visual test throws js error in IE8
  - [EXTJSIV-4617] Grid -Grouped Header Grid (Updated): Horizontal scroll bar is not displaying to view the company column.
  - [EXTJSIV-4634] Drag and Drop - Grid to Grid DnD: Dragged records are not shown in Second Grid
  - [EXTJSIV-4643] Grouping grid causes JS errors in visual test
  - [EXTJSIV-4645] Column header menu trigger el is not deactivated upon Menu hide.
  - [EXTJSIV-4660] Grouped Header Grid : Even one sub item is selected ,all the sub items are get selected and displayed in the grid
  - [EXTJSIV-4705] Grids - Basic Array Grid : Column header drop down menu items list is misplaced
  - [EXTJSIV-4725] Checkbox header is not centered
  - [EXTJSIV-4735] Grid Filter :Text on the "OK" button is left aligned
  - [EXTJSIV-4737] Toolbars and Menus - Ext Grid Actions: Column headers are disturbed when columns size is expanded
  - [EXTJSIV-4740] Cell Editors created outside grid code are not activated when selecting cell
  - [EXTJSIV-4811] Grids : Basic Array Grid : Grid is not displaying sort values when refresh the page and no field selection option for "buy/sell" field.
  - [EXTJSIV-4813] Grids: Grouping : No data (blank) is displayed in grouping gird example in a specific
  - [EXTJSIV-4833 ] Combination Examples - Feed Viewer : Displaying js when clicked on "Sci/Tech - Google News" item under the Feeds panel
  - [EXTJSIV-4836] MVC -> Feed Viewer : Displaying error message while accessing the example on Safari5 and Chrome browsers only.
  - [EXTJSIV-4838] Grids: Grid with Live Search Capability - Displaying JS error while click on "<" or ">" button for searching the data in the grid.
  - [EXTJSIV-4839] Grid - Displaying JS error when clicked on last row / last row above the Horizontal scroll bar in the grid. This issue observed across all examples having grid.
- Layouts
  - [EXTJSIV-1544] A gray line appears after clicking on subsequent accordion headers and coming back to the first header
  - [EXTJSIV-2074] Failed test: Verify that East panel expands when clicked on the expand button at left side of the center panel
  - [EXTJSIV-2263] Failed test: Verify whether East Side panel collapses when clicked on collapse button
  - [EXTJSIV-2266] Failed test: Verify the user is able to click on drop down list and able to see the options
  - [EXTJSIV-2301] Failed test: Verify Border layout page alignment while resizing the browser
  - [EXTJSIV-2390] Failed test: Verify whether Accordion panel width can be increased / decreased
  - [EXTJSIV-2405] Docked items added after render don't render correctly
  - [EXTJSIV-3409] CardLayout deferredRender config ignored when component is added to a container
  - [EXTJSIV-3977] [4.0.6] Container in hbox height issue: When there is an hbox with a container in it, the height of the container's (and other siblings) surrounding div (class: x-box-inner) gets set to the height of the largest child
  - [EXTJSIV-3990] Editor - Label captions are overlapping on the text fields when long label caption is entered without any space.
  - [EXTJSIV-4076] Draggable Sprite Doesn't Follow Cursor
  - [EXTJSIV-4088] Layout Browser - Custom Layouts - Center - Page is not center aligned and extra empty space is created next to Sample layout panel in IE 7
  - [EXTJSIV-4134] [4.0.6] Load mask problem: create new window (modal: true) and make setLoading(true) for it. Than I click to header of window, mask (with text "Loading") moves into the background of the window
  - [EXTJSIV-4150] Grouping don't update panel height
  - [EXTJSIV-4170] FileUploadField label does not collapse
  - [EXTJSIV-4171] User details - Drop down items are displaying at the top of the page when double-click on the Editor panel
  - [EXTJSIV-4182] Splitter-usage breaks Layouts
  - [EXTJSIV-4197] Button menu misaligned on first appear, correct on second appear
  - [EXTJSIV-4216] Submenu disappears by going to its item obliquely
  - [EXTJSIV-4223] Hidden floated element positioning bug
  - [EXTJSIV-4253] Stateful implementation broken for panels in Accordion layout
  - [EXTJSIV-4342] Layout autoWidth/Height only supports "shrink wrap" mode
  - [EXTJSIV-4343] Themes Example has JS error on IE6 only
  - [EXTJSIV-4344] Need to constrain width/height to >= 0 in IE
  - [EXTJSIV-4352] The "layout bubble" algorithm does not always climb high enough
  - [EXTJSIV-4353] Adding components to a running layout fails
  - [EXTJSIV-4361] Message-Box sample: Buttons on the pop-up dialog are truncated on the right end and also text boxes are not aligned properly for some pop-up dialogs.
  - [EXTJSIV-4363] Forum-search sample: No search results displayed
  - [EXTJSIV-4364] Combo Box sample: The "States" drop down box content is overlapping with selected value
  - [EXTJSIV-4369] Feed-viewer sample: Nothing is displaying (Blank) after clicking on feed "collapse" button.
  - [EXTJSIV-4374] tab overflow menu example: JS error: 'targetSize' is null or not an object. UX needs updating to accommodate new layout system.
  - [EXTJSIV-4377] Layout Browser Example: JS error and missing collapse tool on footer panel
  - [EXTJSIV-4380] Complex Layout example: JS error is displayed
  - [EXTJSIV-4381] Accordion Layout Example: JS error is displayed
  - [EXTJSIV-4386] [4.1PR] - layout fails: lastComponentSize is undefined
  - [EXTJSIV-4391] BoxReorderer needs refactoring to work with new layout system.
  - [EXTJSIV-4395] Table Layout Example: Blank page is displayed
  - [EXTJSIV-4401] Problem with panel initially collapsed in a border layout
  - [EXTJSIV-4404] Error: ext-all-debug.js:51144 Uncaught TypeError: Cannot read property 'isDetachedBody' of undefined
  - [EXTJSIV-4405] no onRender: function (ct, position) for Fields
  - [EXTJSIV-4406] Error on tab creation: ext-all-debug.js:78809 Uncaught TypeError: Cannot call method 'scrollIntoView' of undefined.
  - [EXTJSIV-4409] growMax and growMin aren't honored for Text.js and TextArea.js [Rally]
  - [EXTJSIV-4439] [4.1.0PR] Error with collapsed region in border layout: "me.placeholder is undefined"
  - [EXTJSIV-4449] Field layout measures its height before acquiring its width resulting in incorrect height.
  - [EXTJSIV-4489] Box layout's menu overflow handler does not work.
  - [EXTJSIV-4534] Picker "Loading..." mask stuck on: loading mask on combo's with property queryMode='local' sometimes remains active and don't disappear when you click on picker.
  - [EXTJSIV-4570] BorderLayout expand/collapse regression
  - [EXTJSIV-4610] Ext-layout-container-Accordion -> animate: false not working
  - [EXTJSIV-4619] Combination Examples -Theme Viewer example :The loader icon is over lapping the calendar component.
  - [EXTJSIV-4624] Layout Managers - Complex Layout (Updated): Raises js error when clicked on expand/ collapse button for South Panel
  - [EXTJSIV-4632] Unexplained load mask in upper left corner of browser again
  - [EXTJSIV-4633] Progressbar is going beyond the boundries when click on Show button of any field
  - [EXTJSIV-4637] Field layouts allow triggers to wrap.
  - [EXTJSIV-4691] Layout Manager - Anchor Layout (form) : The Text Area is truncated
  - [EXTJSIV-4698] Ext.window.Window height not being calculated correctly
- Menu
  - [EXTJSIV-3354] Ext.menu.Menu positioning problem while scopeResetCSS:true
  - [EXTJSIV-3653] Grid menu filter loses focus when mouse leaves the component
- MVC
  - [EXTJSIV-2308] Failed test: Verify Pane resize on Feedviewer page using resize bar
  - [EXTJSIV-2311] Failed test: Verify the focus on the tabs when user click on open all button
  - [EXTJSIV-2312] Failed test: Verify the tabs display when user click's on open all button.
- Others
  - [EXTJSIV-3555] autoEl does not support the string version
  - [EXTJSIV-3928] Ext.Direct - Callback not invoked after a request is aborted/timesout
  - [EXTJSIV-3966] Miscellaneous :Browser State Management -Showing JS error upon clicking on "Collapse/Expand" button of Collapse/expand width panel
  - [EXTJSIV-4123] Ext.Array.from() with function gives empty array
  - [EXTJSIV-4142] [4.06] readOnly with xtype: 'filefield': A field "filefield" can be charged even if readOnly
  - [EXTJSIV-4149] [4.0.2] Ext.Element fadeOut not respecting useDisplay:true
  - [EXTJSIV-4159] Add & remove menuitems and "me.dom is undefined"
  - [EXTJSIV-4162] Appending Nodes to an Async Tree: when append the node and call store.sync(), the proxy is using the update url instead of the create url
  - [EXTJSIV-4173] [4.0.2a] HtmlEditor does not strip out defaultValue as expected due to absolute check
  - [EXTJSIV-4174] Zooming broken in some zoom levels in Chrome, IE 8
  - [EXTJSIV-4177] FiltersFeature arrow in menu: the arrow in the filters menu is missing
  - [EXTJSIV-4180] [4.0.6] Ext.Function interceptBefore and interceptAfter - add scope param
  - [EXTJSIV-4181] Ext.form.field.Number.getSubmitValue() returns localized Value
  - [EXTJSIV-4192] Ext.container.AbstractContainer#suspendLayout is not reentrant
  - [EXTJSIV-4193] Ext JS 4: Hiding grouped headers (hideGroupedHeader = true) throws exception
  - [EXTJSIV-4212] [4.0.6] actioncolumn text/header
  - [EXTJSIV-4217] model copy() and phantom: model1.copy() returns always a non-phantom model, not taking into account whether model1 is phantom or not.
  - [EXTJSIV-4220] [4.0.2a] ComponentDragger setting positions incorrectly
  - [EXTJSIV-4221] ComboBox readOnlyCls: Read Only Class is not added to the component's main element when setting readOnly property to the combobox field
  - [EXTJSIV-4222] [4.0.4] Wrong Definition in Design _grid.scss on line 83
  - [EXTJSIV-4224] Ext.form.CheckboxGroup.validate() may return false even if disabled is true
  - [EXTJSIV-4225] After an edit is made to a record in an editable tree, the record's non-persistent fields get reset to their default values
  - [EXTJSIV-4235] QuickTip's ignoring showDelay configuration
  - [EXTJSIV-4236] 4.0.6: maxLength and enforceMaxLength on TextArea not working in IE8
  - [EXTJSIV-4244] timefield scrollbar dissappears - ExtJS 4.0.6
  - [EXTJSIV-4246] Model save: operation with no response
  - [EXTJSIV-4261] Ext4 sandbox auto generated id conflict with Ext3
  - [EXTJSIV-4263] Datefield picker ignoring control keys
  - [EXTJSIV-4266] Not able to use HTMLEditor on IE(8) when accessing over SSL - ExtJS 4.0.6
  - [EXTJSIV-4268] [4.0.6] animCollapse: false not honored
  - [EXTJSIV-4292] TimeField value not cleared from the list on form reset
  - [EXTJSIV-4293] [4.0.2a] Ajax error for non-terminating connections in IE6
  - [EXTJSIV-4294] [4.0.7] 'name' not rendered to combo's input element
  - [EXTJSIV-4297] Reloading TreeStore adds all records to store getRemovedRecords
  - [EXTJSIV-4299] Bug in Grouping Feature (and solution)
  - [EXTJSIV-4306] [4.0.7] Combo box issue in displaying value in view port layout: 2n click of combo box cause incorrect layout with values showing on top-right corner of the IE browser
  - [EXTJSIV-4308] [4.0.6] Disabled fields retain invalid field decoration
  - [EXTJSIV-4311] [4.0.7] Warning shown when a fieldset is removed
  - [EXTJSIV-4312] [4.0.7] Error on bind Store if view is not rendered
  - [EXTJSIV-4316] Store.clearFilter() remove added records
  - [EXTJSIV-4320] CellModel does not keep track of selections
  - [EXTJSIV-4324] [4.0.7] Ext.form.field.Number setMaxValue() and setMinValue() bug
  - [EXTJSIV-4327] building from SVN fails
  - [EXTJSIV-4336] 4.1: Calling element.load causes error: "this.get is not a function"
  - [EXTJSIV-4373] Multiple Sorting Example: Bug in BoxReorderer plugin
  - [EXTJSIV-4397] Drag Drop Manager doesn't select correct drop target
  - [EXTJSIV-4400] Wrong method selected when saving a record with id = null.
  - [EXTJSIV-4413] [ext-4.1-pr1] Some coding isues. - invalid CSS and code trucations in a few files
  - [EXTJSIV-4418] Infinite scrolling with JsonP proxy causes enormous memory consumption
  - [EXTJSIV-4426] Problem with column header grouping at level 3. Columns can not be hidden.
  - [EXTJSIV-4427] Ext.Function.createBuffered() ignores the caller's arguments
  - [EXTJSIV-4428] setEditor cannot work in rowEditing
  - [EXTJSIV-4443] Dragging and dropping tree nodes to reorder them changes the index field of the node that was dragged, but does not change the index field of the other sibling nodes that come after it.
  - [EXTJSIV-4444] Ext.util.Format.currency decimals ignored when set to 0
  - [EXTJSIV-4448] Drag & Drop - Custom Drag & Drop - Getting JS error while drag and drop any item to right side field.
  - [EXTJSIV-4456] [4.0.7] Ext.util.Format.number() has inconsistent behavior
  - [EXTJSIV-4473] Combo box : Basic Combo box:Tool tips are not displaying upon mouse-hover on the State.
  - [EXTJSIV-4495] Miscellaneous - Slider - By default, Sliders are overlapping each other only one slider is displaying
  - [EXTJSIV-4509] Accessibility -> Kayboard Feed Viewer: Not able to navigate to all the buttons in the Feed Viewer using Keyboard alone.
  - [EXTJSIV-4520] [4.1.0PR] RowWrap feature: error "Node was not found"
  - [EXTJSIV-4542] (new Date(year, month, 1)).getLastDateOfMonth is not a function in Ext.picker.Date
  - [EXTJSIV-4554] [BUG] Combobox picker height is not recalculated on refresh
  - [EXTJSIV-4571] CheckBoxGroup.resetOriginalValue throws an exception in Ext.Base.callParent
  - [EXTJSIV-4588] Miscellaneous -Localization (Dynamic) :The The Month of the Year menu item should be uncheck without any java script error.
  - [EXTJSIV-4592] Ext.Component#setLoading sets load mask text only on first call
  - [EXTJSIV-4626] Direct transactions not cleaned up
  - [EXTJSIV-4638] [4.0.7] TreeStore crud broken
  - [EXTJSIV-4641] Can't override singleton
  - [EXTJSIV-4644] What happened to markDirty view config?
  - [EXTJSIV-4696] BUG: Ext.Function.pass is corrupted
  - [EXTJSIV-4739] Miscellaneous - Localization(dynamic) :The Language selector field is stretched
  - [EXTJSIV-4743] hideEmptyLabel not applied (4.1.prev, 4.0.7)
  - [EXTJSIV-4744] [4.0.7] window clobbered if dynamic loading fails
  - [EXTJSIV-4746] [4.0.7] Exception inside the error handling of JSON reader
  - [EXTJSIV-4777] Initially disabled toolbar cannot be re-enabled
- Panel
  - [EXTJSIV-1652] A + cursor is shown after collapsing/expanding a panel while keeping the mouse pointer fixed in place above the collapse/expand button
  - [EXTJSIV-3038] [4.0.3] Ext.grid.Panel.destroy generates extra Ajax requests
  - [EXTJSIV-3368] The "floating" configuration property does not work corectly on Panels
  - [EXTJSIV-3410] Collapsing/expanding of flexed panels doesn't work
  - [EXTJSIV-3443] Panels sometimes disappear when their siblings are collapsed
  - [EXTJSIV-3594] [4.0.5] Panel disappears (width=0) after collapse
  - [EXTJSIV-3762] When shadowed panel is moved, its shadow is left behind.
  - [EXTJSIV-4191] Collapsible panels in vbox layout do not readjust height
  - [EXTJSIV-4194] No horizontal scrollbar for Panel with big content
  - [EXTJSIV-4302] treePanel viewConfig - corruption of class definition
  - [EXTJSIV-4338] Strange Ext.panel.Panel modal behaviour: Panel modal disappears when loadmask is active.
  - [EXTJSIV-4354] Panel collapse/expand need to notify ownerLayout after animation
  - [EXTJSIV-4408] panel.hide(true) with panel.preventHeader=true -> error: this.header is undefined
  - [EXTJSIV-4524] Duplicate state events added: in Ext.window.Window and Ext.panel.Table
  - [EXTJSIV-4654] calling setTitle() before rendering
- Tabs
  - [EXTJSIV-3719] The icon in tab is not centered vertically
  - [EXTJSIV-3773] Layout body content on tabchange TabPanel not recalculated
  - [EXTJSIV-3984] Basic Tab -Bottom border is missing in long text tab. Displaying only after closing short text tab
  - [EXTJSIV-4034] 4.0.6 breaks margins inside a tab panel
  - [EXTJSIV-4284] Tab remains hidden after focusing on it and removing it and then re-adding it
  - [EXTJSIV-4394] Tab Example: Tab problem. Button is zero width even though the text span has a width.
  - [EXTJSIV-4407] [4.0.7] Tab font variable never honoured
  - [EXTJSIV-4414] When a new tab is created the layout of the tab is not triggered - tab is not shown in tabbar.
  - [EXTJSIV-4511] Tabs -> Advanced Tab : Left side navigation arrow button is not enabled.
  - [EXTJSIV-4745] Multiple Tab Panel Instances with dockedItems
  - [EXTJSIV-4812] tabchange fires for setting initial tab
- Theme
  - [EXTJSIV-3496] The theme index example is automatically scrolled on IE.
  - [EXTJSIV-3567] Gray theme has incorrect backgroup color (showing blue)
  - [EXTJSIV-4271] Theme Viewer:Form Widgets- Check box positions are changing when unselect the "Foo" check box.
  - [EXTJSIV-4277] Theme Viewer - Horizontal scroll bar is seen only when trying to submit any data where even its not required.
  - [EXTJSIV-4530] Theme viewer :Displaying JS error upon clicking on Time field dropdown menu after entering text in the time field.
  - [EXTJSIV-4558] Theme Viewer - Calendar - Displaying JS Error When click on Month Field in the Date Picker
  - [EXTJSIV-4706] Neptune theme base variables and widgets styling need to be changed to match recent changes to ExtJS
  - [EXTJSIV-4771] Combination Examples - Theme Viewer : Displaying js error when uncheck "Foo" check box under "Form Widgets" window in Theme Viewer
- Toolbars
  - [EXTJSIV-3963] Toolbars and menus : Displaying JS error while accessing Vertical Toolbars example
  - [EXTJSIV-4163] Toolbars and Menus : Ext Toolbar Actions - "Change text" window caption is moving while entering long text in the text box.
  - [EXTJSIV-4205] PagingToolBar problem: in case of zero (0) records there is a problem on paging toolbar that show paging 1 of 0 and it also possible move to next page so 2 of 0 , 3 of 0 etc
  - [EXTJSIV-4229] In IE9 on a toolbar docked to a side of a panel, an icon showing 2 arrows is displayed on a menu item without text
  - [EXTJSIV-4231] Paging toolbar does not react on the keys PAGEUP, PAGEDOWN, Shift+UP and Shift+DOWN
  - [EXTJSIV-4318] Separator in the Vertical Toolbars example not aligning properly
  - [EXTJSIV-4384] Ext Toolbar Actions Example: Text field not sized properly. Problem with TextField layout
  - [EXTJSIV-4463] toolbar/overflow.html - overflow button is not showing
  - [EXTJSIV-4531] Toolbars and Menus : Overflow Toolbar : By default Choose button label caption is not displaying properly.
  - [EXTJSIV-4587] Tool Bars and Menus - Over Flow example :Choose a Color menu item should be displayed adjacent to the Button
- ToolTips
  - [EXTJSIV-4218] Tooltip for Tab is not shown
  - [EXTJSIV-4485] Quick Tip shows twice in IE [Thunderhead LTD]
- Tree
  - [EXTJSIV-1476] Inconsistent padding around tree elements when comparing quirks versus strict modes
  - [EXTJSIV-1954] Tree Horizontal Scrolling
  - [EXTJSIV-2202] Failed test: Verify that user can drag and drop the folders or files from one tree panel to another tree panel
  - [EXTJSIV-2539] TreeGrid + CellEditing broken
  - [EXTJSIV-3499] Ext.tree.Panel border:false still shows top border
  - [EXTJSIV-3571] [4.0.2] one Store and two tree.Panel - Expand/Collapse causes item disappearing from the 2nd tree and duplicated in the 1st tree
  - [EXTJSIV-3596] The callback function for NodeInterface#expand() gets called before the node has finished expanding
  - [EXTJSIV-3600] New nodes added to a Tree using the node interface do not show as "phantom" records
  - [EXTJSIV-3640] Adding a custom renderer increases height of unlocked grid columns but doesn't sync locked column
  - [EXTJSIV-3920] NodeInterface's "icon" config does not work as documented
  - [EXTJSIV-3954] Trees : Displaying JS error while accessing all examples in the Trees examples section
  - [EXTJSIV-4376] Tree Example, Drag and Drop Reordering: Folder nodes do not expand when clicked.
  - [EXTJSIV-4472] Trees : Check Tree :Displaying Js error upon clicking on "Get checked nodes" button .
  - [EXTJSIV-4516] TreeGrid not expandable on 3rd level
  - [EXTJSIV-4529] Trees : Tree Grid -Displaying JS error upon clicking on folders in the tree grid example
  - [EXTJSIV-4586] Trees -> Check Tree : Masking on the page is not removed after cancelling the pop-up dialog.
  - [EXTJSIV-4693] Trees - Check Tree : Not displaying Expand / Collapse (+/-) icons for parent nodes
- Window
  - [EXTJSIV-1732] Progress Dialog window locking
  - [EXTJSIV-1748] MessageBoxWindow autosizing probably needs a fudge factor to avoid unwanted word wrapping.
  - [EXTJSIV-1994] Strange Ext.window.Window rendering issue in WebKit browsers when placed over Java applet
  - [EXTJSIV-3521] Layout issue when Resizing Window
  - [EXTJSIV-3772] Mask for modal window doesn't completely cover document.body
  - [EXTJSIV-3902] Modal windows with long pages - mask not covering whole document.body
  - [EXTJSIV-3938] Windows can be resized when maximized, leading to unexpected interaction patterns
  - [EXTJSIV-3985] Windows - MessageBox : There is no gap in between custom buttons
  - [EXTJSIV-4009] Message Box - Page getting grayed out after click on Multi-line prompt,Yes/No/Cancel,icons ,Progress Dialog,Wait Dialog "show" buttons.
  - [EXTJSIV-4018] Layout Window- Displaying JS Error when click on Collapse/Expand button of Navigation window
  - [EXTJSIV-4204] Ext.window.Window : Esc problem
  - [EXTJSIV-4301] window with no header and draggable false throws error on show with animatetarget
  - [EXTJSIV-4322] [4.0.7] / [4.1] MessageBox showing with large text
  - [EXTJSIV-4460] Modal Window not modal in sandbox
  - [EXTJSIV-4471] MessageBox : Displaying JS error upon clicking on all "show" buttons in the Message box example
  - [EXTJSIV-4528] Windows - Layout Window: The navigation panel is not collapsing properly and displaying JS error upon clicking on collapse/expand button.
  - [EXTJSIV-4591] Windows - Layout Window :The Navigation panel's hide and show arrow is not appearing for the first time
  - [EXTJSIV-4670] Windows - Windows Variation - By default, constrained windows are displaying at the top of the page.

# Release Notes for Ext JS 4.0.7

Release Date: October 19, 2011
Version Number: 4.0.7

## Bugs Fixed

- Grid
  - [EXTJSIV-2023] - Failed test: Verify the data in the grid columns when user resize the columns and click on next navigation button continously
  - [EXTJSIV-2471] - "Group by this field" in Remote Summary Grid gives JS error
  - [EXTJSIV-3326] - Ext.grid.View docs for stripeRows says the default is "false" but it's really "true"
  - [EXTJSIV-3469] - Ext.grid.plugin.CellEditing beforeedit event is fired with incorrect parameters
  - [EXTJSIV-3492] - Form grid access examples has incorrect columns size on IE7 and IE6
  - [EXTJSIV-3574] - Using Ext.grid.RowNumberer's xtype incorrectly sets the columns width
  - [EXTJSIV-3588] - Vertical Scroll Bar Disappears in Locking Grid
  - [EXTJSIV-3750] - Hidden columns cause header misalignment
  - [EXTJSIV-3777] - Bottom rows missing on buffered grid when page size and record count are close in size
  - [EXTJSIV-3903] - Grid Scrolling does not work when setting the viewConfig.cls property
  - [EXTJSIV-3908] - Grid LoadMask fails to disappear after store load when there is more than 1 grid on the page
  - [EXTJSIV-3912] - AbstractView.onItemDeselect can sometimes cause an exception if the record node is no longer rendered
  - [EXTJSIV-3983] - Initially hidden columns don't work with column grouping
  - [EXTJSIV-4017] - Mouse scrolling on a grid scrolls both horizontally and vertically
  - [EXTJSIV-4041] - Locking grid doesn't substract width of hidden locked columns
  - [EXTJSIV-4044] - Instantiating grids at the wrong time causes scroll bars to silently disappear
  - [EXTJSIV-4064] - TreeViewDragDrop doesn't clean up after itself
  - [EXTJSIV-4068] - Ext.grid.column.Action doesn't prefix actionIdRe
  - [EXTJSIV-4075] - Menu icon missing in Grouping Grid
  - [EXTJSIV-4130] - LoadMask does not get removed from grid that is on inactive tab
  - [EXTJSIV-4145] - The gridscroller doesn't destroy when the grid destroyed
  - [EXTJSIV-4203] - Tree nodes disappear and can't be brought back
- Panel / Window
  - [EXTJSIV-3968] - autoDestroy parameter of Panel.removeDocked() is not optional
  - [EXTJSIV-3926] - Ext.window.Window adds close tools on each use / won't close on ESC key closable:true
  - [EXTJSIV-3498] - setting hidden configuration parameter to true while collapsed is set to true gives error on render
  - [EXTJSIV-4006] - collapsed panel will not expand
  - [EXTJSIV-4050] - Accordion fires expand/collapse events to early
  - [EXTJSIV-4051] - activeOnTop not implemented in Accordion
  - [EXTJSIV-4209] - accordion grid panels that scroll vertically have a blank space on the right
  - [EXTJSIV-4239] - initially collapsed panels without a fixed width are too wide
- Data
  - [EXTJSIV-2536] - store.removeAll() does not remove grid.verticalScroller
  - [EXTJSIV-3575] - TreeStore doesn't clear dirty flag on updated record
  - [EXTJSIV-3705] - Store#loadData modifes data array passed into the method
  - [EXTJSIV-3988] - Subtle bug in Json Reader forces server to enclose single record in array
  - [EXTJSIV-4007] - Ext-data-Store.loadData change param type: [object, object] changes to [model, model]
  - [EXTJSIV-4026] - Ext.data.Store.indexOfId does not work, it returns -1 for valid ids.
  - [EXTJSIV-4028] - Ext.util.Filter with property and value=null causes error
  - [EXTJSIV-4042] - TreeStore ignores autoLoad: false
  - [EXTJSIV-4043] - node.removeAll() leaves childnodes in the NodeHash
  - [EXTJSIV-4062] - Manipulating a new record fails
  - [EXTJSIV-4078] - Ext.data.Connection.isLoading() always returns false, with no parameter
- Forms
  - [EXTJSIV-3035] - ComboBox submit the wrong content
  - [EXTJSIV-3298] - combobox setValue doesn't as expected
  - [EXTJSIV-3314] - Hidden field is always dirty
  - [EXTJSIV-3373] - Multiple classes in field's fieldCls causes JS error
  - [EXTJSIV-3405] - getFieldValues in the compat layer is marked as deprecated but is not deprecated.
  - [EXTJSIV-3444] - KeyMap does only accept keycodes, not characters
  - [EXTJSIV-3916] - Ext.form.field.File style missing from my-ext-theme.scss
  - [EXTJSIV-3917] - RadioGroup setValue is unable to handle boolean true/false
  - [EXTJSIV-3923] - formBind no longer functions
  - [EXTJSIV-3982] - Datepicker showmonth picker problem
  - [EXTJSIV-3996] - IE8 Windowed combo field does not gain focus if tooltip is visible
  - [EXTJSIV-3997] - Upload Filefield (buttonOnly) in Toolbar: not rendered like other buttons
  - [EXTJSIV-4003] - Grid row editor shows hidden fields of grid - it should not show a hidden field
  - [EXTJSIV-4027] - Ext.picker.Time calls new Date(...) with non-standard parameter
  - [EXTJSIV-4063] - Form tries to validate field that doesn't exist
  - [EXTJSIV-4079] - Ext.form.field.Date do not send post with empty value
  - [EXTJSIV-2498] - Ext.picker.Color should allow its renderTpl to be overridden
  - [EXTJSIV-3910] - fieldset checkboxToggle - add inputValue and uncheckedValue
- Examples
  - [EXTJSIV-3745] - Theme viewer - Duplicate Check box is displayed in the Window panel (Plain Field set) when click on expand/collapse button.
  - [EXTJSIV-3692] - Displaying java script error while user trying to search with special characters in live search grid.
  - [EXTJSIV-1152] - No animation when clicking on the multi-line prompt in the Window example
  - [EXTJSIV-3890] - Charts - Complex Dashboard -Displaying JS error upon increasing the field values under the company details
  - [EXTJSIV-3891] - Drag and Drop - Displaying JS error upon drag the date field into price column
  - [EXTJSIV-3943] - Keyboard Feed Viewer - Highlighted color is not displaying correctly in IE 6
  - [EXTJSIV-3946] - Forms - Binding a grid to a form - Missing Horizontal and Vertical Scroll bars in IE 6.
  - [EXTJSIV-3978] - ComponentDragger exception when Window has nothing rendered in the header
  - [EXTJSIV-3992] - Layout Manager : VBox Layout - Displaying JS error while minimizing the browser after selecting "Flex :Even/Align :Center" button
  - [EXTJSIV-4082] - Portal Demo Displaying JS Error when click on Expand / Collapse button in Navigation / Setting accordions
  - [EXTJSIV-4083] - Direct Form - Displaying JS Error when click on Expand / Collapse button in Basic information / Phone Numbers /Location Information accordion windows
  - [EXTJSIV-4084] - Feed Viewer - Displaying JS Error when click on Cancel button in the add feed pop-up window
  - [EXTJSIV-4112] - Webdesktop : Displaying JS error upon clicking "OK" & "Cancel " buttons in change settings menu.
  - [EXTJSIV-4114] - Ajax with XML Forms : [IE 6.0] - Displaying JS error upon clicking on "Load" & "Submit" buttons in XML forms.
  - [EXTJSIV-4169] - Desktop example windows open minimized to the task bar; cannot be opened
  - [EXTJSIV-4254] - Resizable Sencha Logo - Sencha Logo is not resizing while trying to resize from any side/corner of the component in IE 8 & IE 7.
  - [EXTJSIV-4256] - Draggable Tiger Components - Draggable Tiger image is partially visible and complete image is not displaying in IE 8 & IE 7
  - [EXTJSIV-4259] - Ext JS 3 & 4 on one Page - By default four square colored small boxes are displaying in the main Page
  - [EXTJSIV-4269] - Line Chart - Chart is not displaying after disabling all the legend items and then maximizing the chart
- Tabs
  - [EXTJSIV-3748] - LoadMask on a Tab stays visible even if we switch tabs.
  - [EXTJSIV-3627] - Ext.tab.Tab setIconCls not working properly
  - [EXTJSIV-3904] - Error when closing tabs created dynamically
  - [EXTJSIV-4065] - Remove + add tabs to tabpanel only works with one tab
- MessageBox
  - [EXTJSIV-3779] - Message Box Dialog - Page is grayed out and not allowed to update the page when quickly double-clicking on Icon Show button.
  - [EXTJSIV-3560] - API Docs for Ext.window.MessageBox.show() example broken as of 4.0.2a. Should use Ext.Msg.OKCANCEL instead of Ext.window.MessageBox.OKCANCEL
  - [EXTJSIV-1159] - No animation on progress bar
  - [EXTJSIV-3909] - Ext.MessageBox has an incorrect translation
  - [EXTJSIV-4037] - ProgressBar in a toolbar does not update progress when hidden
- Charts
  - [EXTJSIV-3914] - Ext.chart.axis Title bug
  - [EXTJSIV-3915] - Pie Chart rendering bug
  - [EXTJSIV-4025] - Charting Time Axis with a Column Series is misaligned
  - [EXTJSIV-4060] - Line Chart doesn't show labels
- General
  - [EXTJSIV-3366] - The autoRender Component configuration does not work as documented.
  - [EXTJSIV-3707] - Fix issue with event bubbling
  - [EXTJSIV-3459] - Ext.fx.Anim throws 'Ext.fx.cubicBezier is not a function'
  - [EXTJSIV-3894] - Setting the Ext.BLANK_IMAGE_URL value still causes s.gif to be loaded from www.sencha.com in IE6/IE7 causing a security warning
  - [EXTJSIV-3900] - Menu uses BLANK_IMAGE_URL too early
  - [EXTJSIV-3913] - Toolbar overflow button icon
  - [EXTJSIV-3927] - Ext.Layer.setOpacity does not affect associated shadow
  - [EXTJSIV-3942] - If you do not supply a center region to a border layout, you get a cryptic error
  - [EXTJSIV-4023] - Extra and missing borders in various components
  - [EXTJSIV-4036] - Colormenu select event fires twice on click/select
  - [EXTJSIV-4049] - Regular expression references wrong class name in sandbox mode in Action.js
  - [EXTJSIV-4055] - Ext.util.HashMap add method not counting length correctly when replacing
  - [EXTJSIV-4074] - Ext.Date.defaultFormat is used at define time in Ext.grid.column.Date
  - [EXTJSIV-4200] - LoadMask with { useMsg: false } no longer suppresses message element
  - [EXTJSIV-4230] - Ext.destroyMembers is not called correctly
- Buttons
  - [EXTJSIV-3736] - In IE quirks mode, a menu containing a ButtonGroup attains an incorrect width.
  - [EXTJSIV-3720] - The button icons are not centered in quirk mode
  - [EXTJSIV-4057] - allowDepress doesn't work on splitbutton
  - [EXTJSIV-4071] - Splitbutton w/ tooltip won't open menu
  - [EXTJSIV-4072] - Open button menu suppresses the focus event of an unrelated field
  - [EXTJSIV-4272] - button[enableToggle] must NOT still be pressed after being clicked twice

# Release Notes for Ext JS 4.0.6

Release Date: August 30, 2011
Version Number: 4.0.6

## Bugs Fixed

- Grid
  - [EXTJSIV-2231] - Fixed a styling bug with grids with rowbody that would cause columns to lay out incorrectly with custom CSS
  - [EXTJSIV-3246] - Fixed a bug where specifying a single grid Feature would fail as it expects an array
  - [EXTJSIV-3415] - Fixed a bug where right clicking would incorrectly deselect all selected nodes (affects Windows machines only)
  - [EXTJSIV-3466] - Fixed a bug where selection does not work with grid row editor and Firefox 5 / IE 9
  - [EXTJSIV-3586] - Grid header drag resizes wrong header
  - [EXTJSIV-3591] - Checkbox column not re-added after grid reconfigure
  - [EXTJSIV-3605] - Fixed a JavaScript error when user mouse hover on the first column in the grid. (Grid plugins example)
  - [EXTJSIV-3642] - Scrollbars don't appear when a custom renderer increases the height of the rows in a tree
  - [EXTJSIV-3644] - Column lines are not displaying properly in the grid.
  - [EXTJSIV-3645] - Summary Grid example -Vertical scroll bar is disappearing when Toggle Summary button is clicked.
  - [EXTJSIV-3658] - Paging scroller doesn't function with up/page up
  - [EXTJSIV-3660] - hideGroupedHeader does not work
  - [EXTJSIV-3661] - Grouping doesn't remember selections
  - [EXTJSIV-3668] - Loading data doesn't invoke grid's vertical scrollbar
  - [EXTJSIV-3715] - Horizontal scrollbar doesn't show on empty grid
  - [EXTJSIV-3717] - Fixed a bad scrollbar in dd/dnd_grid_to_grid.html
  - [EXTJSIV-3725] - Grid with locked columns not syncing header heights
  - [EXTJSIV-3732] - Property Grid - Page is not loaded properly. Empty space is created in between column header and rows in the grid.
  - [EXTJSIV-3733] - Drag and Drop : Grid to From Dnd - Horizontal scroll bar is not displaying after increasing the column size in data grid.
  - [EXTJSIV-3753] - Locked grid with checkbox selection model inserts header twice
  - [EXTJSIV-3754] - Cannot create locked grid with all unlocked columns
  - [EXTJSIV-3784] - Auto height grid.Panel first header cell is blank; Fixed with doComponentLayout
  - [EXTJSIV-3785] - Fixed height grid.Panel doesn't show scrollbars when resizing the columns; Fixed with doComponentLayout
  - [EXTJSIV-3786] - Fixed height grid.Panel bottom scrollbar covers last row; cannot scroll it completely into view
  - [EXTJSIV-3514] - Failed test: Verify horizontal and Vertical scrolling in checkbox selection Grid plugin
- Form
  - [EXTJSIV-3490] - Fixed a bug where Slider width is too narrow on Safari 3.2
  - [EXTJSIV-3491] - Some form examples don't render correctly on safari 3.2
  - [EXTJSIV-3648] - FileField's reset does not reset the textual input field.
  - [EXTJSIV-3669] - Unable to reselect a combo value
  - [EXTJSIV-3673] - Fieldset title are not rendered with firefox 3.6.17
  - [EXTJSIV-3678] - Fixed a bug where Checkbox's checkChange event didn't fire using keyboard
  - [EXTJSIV-3713] - Fixed a bug where BoundList doesn't allow custom itemCls
  - [EXTJSIV-3759] - Slider destroy code incorrect
  - [EXTJSIV-3774] - Editor bug -- unconditional use of field.inputEl
  - [EXTJSIV-3597] - Can't enter spaces into fields inside menus
- Charts and Drawing
  - [EXTJSIV-933] - Axis title "Number of Hits" lacks padding with Firefox 3.5 and 3.0
  - [EXTJSIV-3647] - Mixed charts - Bar graph is crossing the maximum limit of Y -Axis (Number of Hits) when click on the reload button couple of times.
- Data
  - [EXTJSIV-3325] - Fixed a bug where the 'presence' validation would incorrectly return false for numeric zero values
  - [EXTJSIV-3522] - [4.0.2] beginEdit leads to 'update' event not fired on Store
  - [EXTJSIV-3593] - Fixed a bug with record.validate() and length validator when value is null
  - [EXTJSIV-3662] - The "isLoading()" method of Ext.data.TreeStore returns true even after loading has completed
  - [EXTJSIV-3757] - Ext.data.Store modifies the original config object passed in
- General
  - [EXTJSIV-459] - Improved docs for maskRe, stripCharsRe, regex, and regexText
  - [EXTJSIV-3037] - Fixed a bug where an error would be thrown if a Tab's width is greater than the configured maxTabWidth
  - [EXTJSIV-3460] - Checkboxes now correctly remove themselves from the CheckboxManager when destroyed
  - [EXTJSIV-3474] - Fixed sandboxing bugs where Fieldset, TriggerField and Menu would not be correctly wrapped in CSS scoping divs
  - [EXTJSIV-3537] - Ext.destroyMembers was being called incorrectly in some components
  - [EXTJSIV-3598] - Unable to select text in field in menu in FF
  - [EXTJSIV-3638] - Fixed a number of issues with Load Masks
  - [EXTJSIV-3646] - Complex Dashboard - Company Detail caption is not displaying in FF 3.6 browser.
  - [EXTJSIV-3674] - Custom Grid Filters Example was throwing a JavaScript error
  - [EXTJSIV-3718] - There is no padding between fields in statusbar/statusbar-advanced.html
  - [EXTJSIV-3724] - Accordion layout does not properly hide toolbar when button is clicked to expand/collapse its parent
  - [EXTJSIV-3726] - Ensure owning Container is laid out after an autosized Component is laid out.
  - [EXTJSIV-3740] - Portal Demo - Displaying Java script error when click on Legend items in the Stock Portlets
  - [EXTJSIV-3768] - variable $toolbar-border-color was ignored
- Sandbox
  - [EXTJSIV-3681] - Vertical panel header text color incorrect in sandbox mode
  - [EXTJSIV-3683] - Window resize not visible in sandbox mode
  - [EXTJSIV-3688] - Can't vertically resize window in sandbox mode
  - [EXTJSIV-3689] - Window constrain fails in sandbox mode
  - [EXTJSIV-3695] - Grid's AbstractSummary feature had been hard-coding base CSS prefix so sandboxing would not work
  - [EXTJSIV-3702] - Fixed a bug where the JSONP callbacks would use the normal Ext namespace instead of the sandbox namespace in sandbox mode
  - [EXTJSIV-3714] - Tooltip positioning incorrect in sandbox mode

# Release Notes for Ext JS 4.0.5

Release Date: July 24, 2011
Version Number: 4.0.5

## Bugs Fixed

- Grid
  - [EXTJSIV-2442] - Grouped Grid Header does not handle flex column show/hide well (layout issues)
  - [EXTJSIV-2464] - Not possible to access the properties of the columns (locked=true)
  - [EXTJSIV-2471] - "Group by this field" in Remote Summary Grid gives JS error
  - [EXTJSIV-2543] - Cell Editing, intra-row change of focus.
  - [EXTJSIV-2572] - Grid column header menu trigger gets stuck when there's no header menu
  - [EXTJSIV-2573] - Ext.grid.plugin.DragDrop should honor disabled flag
  - [EXTJSIV-3377] - Grid deferRowRender causes defer shim to be set on store listeners
  - [EXTJSIV-3457] - Grid needs a viewready event which fires when the DOM rows become available.
  - [EXTJSIV-3485] - Locking grid example is throwing an Hard JS error "Cannot call method 'removeCls' of undefined"
  - [EXTJSIV-3489] - Grid layout is incorrect in form dashboard example
  - [EXTJSIV-3492] - Form grid access examples has incorrect columns size on IE7 and IE6
  - [EXTJSIV-3494] - Grid mask in custom-form example size is not equal to grid body
  - [EXTJSIV-3562] - grid/form-grid.html must select the first row on page load
- Window
  - [EXTJSIV-1732] - Progress Dialog window locked up if you reopen it after closing it
  - [EXTJSIV-1994] - Strange Ext.window.Window rendering issue in WebKit browsers when placed over Java applet
  - [EXTJSIV-2511] - Ghosted windows should not be stateful
- Form
  - [EXTJSIV-2425] - HTMLEditor corrupted when changing background color of selection
  - [EXTJSIV-3035] - [4.0.1]ComboBox submit the wrong content
  - [EXTJSIV-3298] - [4.0.2] combobox setValue doesn't as expected
  - [EXTJSIV-3330] - Setting the editable combobox to a value that is not in the list results in empty val
  - [EXTJSIV-3413] - Highlight during trigger click
  - [EXTJSIV-3414] - validateedit does not have new values
  - [EXTJSIV-3418] - No way to get reference to field.Picker from BoundList
  - [EXTJSIV-3495] - The Loading Mask in custom form example is not constraint to grid body.
  - [EXTJSIV-3520] - RowExpander doesn't work on ExtJs 4.0.2 (ext-all-debug.js) but worked on (ext-all.js)
  - [EXTJSIV-3561] - form/combos.html example: combobox unobtrusive select transformation doesn't work
- Tree
  - [EXTJSIV-2197] - Failed test: Verify the tree panel when user click's on Expand All button.
  - [EXTJSIV-2200] - Failed test: Verify the panel after user click's on Tree expander button
  - [EXTJSIV-2204] - Dblclick expand/collapse in check-tree example causes JS error
  - [EXTJSIV-2276] - Collapsing a tree panel w/collapsed nodes throws JS error
  - [EXTJSIV-3362] - expandPath fails when a node is already loading
- Layouts
  - [EXTJSIV-2431] - Accordion is missing a border when collapsed
  - [EXTJSIV-2547] - Child components not rendered.sized in initially collapsed, uncontained Panel.
  - [EXTJSIV-3295] - 4.0.2 only - layout fit grid scrollbar when used does not scroll content
  - [EXTJSIV-3410] - Collapsing/expanding of flexed panels doesn't work
  - [EXTJSIV-3541] - Cannot hide collapsed regions in a border layout
- Charts and Drawing
  - [EXTJSIV-3045] - Add check in DrawComponent to ensure we have a valid surface before continuing execution
  - [EXTJSIV-3456] - Printing legends in IE causes orange rectangles appear.
- Data
  - [EXTJSIV-1897] - Ext.data.Store buffered issue - error thrown if records are not available on the server
  - [EXTJSIV-3351] - processResponse is wrong in Ext.data.proxy.Server
  - [EXTJSIV-3464] - Direct exception events don't fire on the provider.
  - [EXTJSIV-3471] - Boolean field data type is not being converted properly.
  - [EXTJSIV-3540] - indexOfTotal fails if the index is 0
- General
  - [EXTJSIV-1638] - ComboBox should select the configured value upon first load of the Store.
  - [EXTJSIV-2405] - Docked items added after render don't render correctly
  - [EXTJSIV-2434] - Infinite scrolling is buggy on safari 3.X (the grid doesn't render the first rows)
  - [EXTJSIV-2549] - Collapsed Tabpanel misses the bottom border
  - [EXTJSIV-2565] - A button with a menu defined is only showing the menu when the mouse is over the arrow but in 3.x the menu showed as soon as the mouse was anywhere over the button
  - [EXTJSIV-2577] - Class aliases that use a period as a separator break DOM/CQ selection
  - [EXTJSIV-2628] - Ext.tab.Bar - minTabWidth has no effect
  - [EXTJSIV-3284] - data-qtitle not consistently rendered.
  - [EXTJSIV-3327] - [4.0.2] Plugins instantiated too early in AbstractComponent
  - [EXTJSIV-3412] - Toolbar with overflow doesn't include menu in refItems
  - [EXTJSIV-3453] - AbstractComponent calls constructPlugins too early
  - [EXTJSIV-3470] - scrollByDeltaX() incorrectly using the vertical scroller
  - [EXTJSIV-3483] - Some examples renders a blank page
  - [EXTJSIV-3486] - Animated DataView throw and hard js error "Cannot call method animate of null"
  - [EXTJSIV-3487] - Animated DataView example throw and hard js error "Cannot call method animate of null"
  - [EXTJSIV-3488] - MultiSelect and Key-Feed-Viewer examples are throwing an hard js error 'Cannot call method addCls of null'
  - [EXTJSIV-3490] - Sliders width is too narrow on Safari 3.2
  - [EXTJSIV-3491] - Some form examples don't render correctly on safari 3.2
  - [EXTJSIV-3496] - The theme index example is automatically scrolled on IE.
  - [EXTJSIV-3539] - LoadMask beforeLoad causes a crash

## Improvements

- [EXTJSIV-1999] - Improved Themes Example Performance
- [EXTJSIV-3323] - [4.0] Ext.tab.Panel history feature missing
- [EXTJSIV-1907] - Refactored the renderSelectors functionality to use local element IDs instead of CSS selectors so that render selector performance is improved
- [EXTJSIV-2575] - Ext core class namespaces made consistent in the API docs
- [EXTJSIV-1887] - Tree now supports horizontal scrolling
- [EXTJSIV-2436] - dynamic_form field alignment

# Release Notes for Ext JS 4.0.4

Release Date: June 29, 2011
Version Number: 4.0.4

## Bugs Fixed

- Grid
  - [EXTJSIV-1032] - Grid CheckColumn 1px to left in header
  - [EXTJSIV-2122] - Cell Editing doesn't allow for custom autoSize
  - [EXTJSIV-2124] - Grid: RowExpander Plugin adds additional columns
  - [EXTJSIV-2251] - Action Column doesn't allow alt text per action
  - [EXTJSIV-2351] - Implement the more intuitive resizable: false on grid Columns. fixed is deprecated.
  - [EXTJSIV-2381] - grid/array-grid.html Actions icons should be moved up of 1 pixel
  - [EXTJSIV-2460] - Regression in Sorting buffered Grid (First row is chopped off)
  - [EXTJSIV-2428] - Unable to set cell editor dynamically
  - [EXTJSIV-2466] - Buffered scrolling broken in latest Chrome
  - [EXTJSIV-2496] - Grid crashes when removing it from a tab panel
  - [EXTJSIV-2501] - Grid applyState smashes column minWidth and has JS errors for locking grids
  - [EXTJSIV-2564] - Grid missing horizontal scrollbar
  - [EXTJSIV-2574] - $grid-row-cell-background variable unused
  - [EXTJSIV-3029] - Reconfigure fails when no columns are passed
  - [EXTJSIV-3299] - (IE7) Grid body alignement is incorrect in form-grid example
  - [EXTJSIV-3309] - Grid reconfigure breaks columns layout
  - [EXTJSIV-3363] - Grid header is too narrow on IE6/IE7/IE9
- Tree
  - [EXTJSIV-1887] - Tree does not allow horizontal scrolling
  - [EXTJSIV-2207] - Dblclick expand/collapse in XML Tree example causes JS error
  - [EXTJSIV-2276] - Collapsing a tree panel w/collapsed nodes throws JS error
  - [EXTJSIV-2517] - getNode needs a rendered check
  - [EXTJSIV-2518] - NodeInterface missing getPath
- Forms
  - [EXTJSIV-2104] - Fieldset display strange in IE
  - [EXTJSIV-2130] - Specify labelCls messes up height on TextField
  - [EXTJSIV-2165] - JS error when selecting item in combo box
  - [EXTJSIV-2167] - JS error when selecting multiple items in combo box
  - [EXTJSIV-2168] - JS error when selecting item in combo box
  - [EXTJSIV-2169] - Cannot select item in combo after entering invalid text
  - [EXTJSIV-2210] - Failed test: Verify the Submit button in the xml form
  - [EXTJSIV-2338] - Checkbox group/checkbox in fieldset too low
  - [EXTJSIV-2349] - examples/form/form-grid-access.html loses its description text
  - [EXTJSIV-2366] - ComboBox should have getStore method
  - [EXTJSIV-2380] - form/checkout.html The disabled Street Address field is lighter than other fields
  - [EXTJSIV-2459] - Checkbox select gives commitFn is not a function
  - [EXTJSIV-2470] - Combo doesn't send queryParam on page change
  - [EXTJSIV-2522] - Field crashes if destroyed when focused
  - [EXTJSIV-2523] - DatePicker has undefined var
  - [EXTJSIV-2527] - File field crashes when reset on unrendered field.
  - [EXTJSIV-2529] - Combo does not adjust list height to fit viewport
  - [EXTJSIV-2531] - Slider crashes when calling setMinValue/setMaxValue when it's not rendered
  - [EXTJSIV-2546] - TextField filterKeys not applied when using alt + gr key
  - [EXTJSIV-2553] - The "formBind" config does not work for buttons defined in a Form Panel's "buttons" config
  - [EXTJSIV-2499] - Date picker month selector animation issues (including runtime error)
  - [EXTJSIV-3028] - Combo in editor always tries to force selection
- Tabs
  - [EXTJSIV-1034] - When there's only one tab in a TabPanel, and it's active by default, the tab selector in the tab strip is not set to the active state.
  - [EXTJSIV-2542] - Ext.tab.Panel styling issues
  - [EXTJSIV-3300] - TabBar background color is incorrect (no gradients) in all browsers except chrome and firefox
- Panel
  - [EXTJSIV-2506] - Panel header should set overflow hidden for text
  - [EXTJSIV-3311] - Collapsed panel layout error inside a viewport
- Toolbars and Buttons
  - [EXTJSIV-2185] - Add textAlign cfg to Ext.button.Button
  - [EXTJSIV-2387] - toolbar/toolbars example, the title of ButtonGroup is not centered anymore
  - [EXTJSIV-2475] - Button icons are not well aligned on ie6 only
  - [EXTJSIV-2513] - Scrolling menu in Basic Toolbar example fails
  - [EXTJSIV-2544] - ButtonGroup renders blue with gray style in Ext 4.0.2
- Window
  - [EXTJSIV-1667] - Improper Resize Handles Position / Offset in IEs
  - [EXTJSIV-1732] - Progress Dialog window locking
  - [EXTJSIV-2193] - Failed test: Verify Window resize using Drag and Drop
  - [EXTJSIV-2505] - When you set modal:true on a window and renderTo it to a panel, it masks the whole body, not the panel
- Charts
  - [EXTJSIV-2508] - Chart doesn't support not being passed a config object
  - [EXTJSIV-2521] - Destroying unrendered chart causes error
- Miscellaneous
  - [EXTJSIV-1066] - Calling Container.add() with a floating component does not render that component
  - [EXTJSIV-1086] - Theme Example: Progress Bar's Right Pixel Border changes color while animating
  - [EXTJSIV-1659] - Text hidden when column is short
  - [EXTJSIV-2074] - Failed test: Verify that East panel expands when clicked on the expand button at left side of the center panel
  - [EXTJSIV-2101] - Shadows not shown on certain floating items such as Menu and ComboBox list.
  - [EXTJSIV-2132] - Expand sets height before anim on Panel using VBoxLayout
  - [EXTJSIV-2192] - Failed test: Verify pane resize using resize bar
  - [EXTJSIV-2226] - Failed test: Verify the user is able to select option from options drop down under ItemSelectorTest table
  - [EXTJSIV-2252] - Need to fix DomQuery for non document rooted queries
  - [EXTJSIV-2284] - Web Desktop, System Status Window is slow on IE (causes script warning)
  - [EXTJSIV-2332] - Fix build warning for nested-loading MVC app
  - [EXTJSIV-2391] - Ext.core.DomHelper should be aliased to Ext.DomHelper for backwards compat
  - [EXTJSIV-2394] - Center region of border layout should have overflow:auto
  - [EXTJSIV-2411] - Format.number can return -0
  - [EXTJSIV-2500] - Gray theme has not styled button group
  - [EXTJSIV-2507] - reader.Array doesn't work with a 0 mapping.
  - [EXTJSIV-2509] - Tool ignores tooltip option
  - [EXTJSIV-2510] - Button tooltipType title doesn't work
  - [EXTJSIV-2520] - Menu strict typo
  - [EXTJSIV-2519] - Store should give a warning if model isn't defined
  - [EXTJSIV-2526] - AbstractContainer, child/down selector should be optional
  - [EXTJSIV-2530] - Show event fires too early for animated component
  - [EXTJSIV-2532] - Store does not consistently pass all event parameters to beforeload event
  - [EXTJSIV-2537] - Box layout doesn't destroy innerCt
  - [EXTJSIV-2839] - Component destroy event fires too late
  - [EXTJSIV-3027] - Hidden tools get ghosted
  - [EXTJSIV-3310] - Accordion layout does not handle grid properly

# Release Notes for Ext JS 4.0.2

Release Date: June 9, 2011
Version Number: 4.0.2

## Bugs Fixed

- Grid
  - [EXTJSIV-864] - Grid filtering doesn't support specifying filters on feature
  - [EXTJSIV-1149] - Grouping Grid - text element in the group should be indented
  - [EXTJSIV-1715] - Row height gets modified while searching
  - [EXTJSIV-1720] - When rendering new buffered rows, row height changes, IE6/7
  - [EXTJSIV-1760] - Grid: enableColumnResize should prevent css indicator of showing resizable behavior
  - [EXTJSIV-1750] - PropertyGrid keyboard navigation
  - [EXTJSIV-1789] - Editing fails after reconfigure
  - [EXTJSIV-1806] - Grid with multi-select and DD deselects rows
  - [EXTJSIV-1810] - Unlocked columns don't align correctly in IE9
  - [EXTJSIV-1812] - beforeselect event not relayed to grid
  - [EXTJSIV-1874] - Grid Performance is too slow in IE
  - [EXTJSIV-1968] - Ext.table.Panel: enableColumnHide
  - [EXTJSIV-1934] - Hiding subcolumn causes width to display incorrectly
  - [EXTJSIV-1969] - IE 8 & 9: Ext.grid.plugin.RowEditing and PagingToolbar
  - [EXTJSIV-1971] - Javascript error during cell editing
  - [EXTJSIV-2061] - Grid vertical scrollbar is reset when when the grid panel is collapsed and then expanded
  - [EXTJSIV-2062] - Call to grid.reconfigure on a rendered grid that initially has no columns configured results in the first row being hidden behind the column headers if the grid does not contain enough data to require scrollbars, different behavior with larger data set
  - [EXTJSIV-1997] - Grid vertical scrollbar error
  - [EXTJSIV-2008] - Grid vscrollbar can double count height of hscrollbar
  - [EXTJSIV-2376] - Grid cells don't show modified state if initial value is falsey
  - [EXTJSIV-2379] - Property grid example is broken (no body rendered)
  - [EXTJSIV-2382] - In grid/binding example the scrollbar column has disappeared
  - [EXTJSIV-2383] - grid/grid-plugins.html throw an hard js error on ie6/7
  - [EXTJSIV-2384] - grid/group-header scrollbar is off by 4 pixels (only ie9)
  - [EXTJSIV-2372] - tree/xml-tree.html throw an hard js error
  - [EXTJSIV-2435] - Xml Tree does not show expand/collapse icons
  - [EXTJSIV-2373] - Row height is too small in direct/direct-grid.html
  - [EXTJSIV-2122] - Cell Editing doesn't allow for custom autoSize
  - [EXTJSIV-2248] - Grid Load performance
  - [EXTJSIV-2430] - RowExpander plugin unwanted padding on IE
  - [EXTJSIV-1868] - Cell Editing doesn't work on locked view
  - [EXTJSIV-2066] - Grid's horizontal scrollbar can get out of sync
  - [EXTJSIV-2244] - CheckboxModel's version of onSelectChange ignores suppressEvent parameter
  - [EXTJSIV-2131] - Can't use grouping summary indexes multiple times
  - [EXTJSIV-2466] - Buffered scrolling broken in latest Chrome
- Menu
  - [EXTJSIV-692] - Need to style menu in access theme
- Tree
  - [EXTJSIV-972] - Indentation in both upper/bottom border lines in tree beside the scrollbar
  - [EXTJSIV-1053] - IE6 tree quicktips look ugly
  - [EXTJSIV-1887] - Tree does not allow horizontal scrolling
  - [EXTJSIV-1933] - Tree crashes on expand
  - [EXTJSIV-2009] - NodeInterface should use a bool type for checked
  - [EXTJSIV-2001] - Expandable attribute ignored
  - [EXTJSIV-1883] - Need a way to veto node collapse/expand events
  - [EXTJSIV-2354] - TreePanel.selectPath does not work with custom separator
- Form
  - [EXTJSIV-1747] - IE Quirks : combo dropdown list is not aligned properly in Advanced Dataview example
  - [EXTJSIV-992] - IE9 strict vertical and horizontal scrollbar in HTMLEDITOR
  - [EXTJSIV-1073] - Date Picker styling
  - [EXTJSIV-1080] - Date Picker / Time picker
  - [EXTJSIV-1668] - TimeField should reserved custom entry on pressing Enter (after keyboard navigation)
  - [EXTJSIV-1753] - Disabled text in field labels does not display properly in IE6
  - [EXTJSIV-2010] - Combo fires change event twice when selecting a value
  - [EXTJSIV-2100] - TextArea emptyText incorrect color
  - [EXTJSIV-2436] - dynamic_form field alignment
- Container
  - [EXTJSIV-1066] - Calling Container.add() with a floating component does not render that component
- Misc
  - [EXTJSIV-1098] - Mini-collapse panel does not have a mouse over state
  - [EXTJSIV-1157] - Row editor had gradient background in 3.3, now has flat color
  - [EXTJSIV-1182] - High Contrast Theme Has Standard Contract Menus
  - [EXTJSIV-1202] - Icons of mixed sizes are unaligned
  - [EXTJSIV-1320] - Shadows in lower left/right corners, at times, looks too square.
  - [EXTJSIV-1472] - Black background in charting examples in quirks mode
  - [EXTJSIV-1473] - 2x larger font size in quirks mode versus strict for the spotlight example
  - [EXTJSIV-1553] - The qtip is clipped in the registration example
  - [EXTJSIV-1560] - Title artifact behind collapsed panel header
  - [EXTJSIV-1646] - Problem with relayout + floating
  - [EXTJSIV-1726] - Esc Key Handling is inconsistent between browsers
  - [EXTJSIV-1727] - Placing a date picker inside of a menu has a black border around the menu
  - [EXTJSIV-1734] - The background of the custom progress bar in progress bar example must be white.
  - [EXTJSIV-2055] - Compat layer throwing error with grid
  - [EXTJSIV-1729] - Tab icons cut off
  - [EXTJSIV-1746] - Restful Proxy example uses background-image w/PNG (bad for IE6) on buttons
  - [EXTJSIV-1793] - Sandboxing Ext3/Ext4 can cause id clashes
  - [EXTJSIV-1815] - Problem with discontinuous values
  - [EXTJSIV-1873] - Compat - tbar in grid appears under headers
  - [EXTJSIV-1884] - Proxy status repair goes behind window
  - [EXTJSIV-1928] - Paging toolbar in BoundList has double border
  - [EXTJSIV-1941] - body not scoped
  - [EXTJSIV-1965] - renderTpl used even when it doesn't exist
  - [EXTJSIV-1973] - HashMap keyFn not supported
  - [EXTJSIV-1990] - State doesn't allow stateId to be set in the prototype
  - [EXTJSIV-2003] - Missing btn mixin
  - [EXTJSIV-2004] - Frame ignores any ui
  - [EXTJSIV-2065] - Ext.Element#scrollTo broken when animate=true with grid view when store is reloaded
  - [EXTJSIV-2067] - DatePicker month/year selection cannot be done when showToday = false
  - [EXTJSIV-2089] - Memento class missing in built SDK
  - [EXTJSIV-2095] - 404 for tip-bg.gif file
  - [EXTJSIV-2099] - closeText not copied
  - [EXTJSIV-2129] - Set tpl config has no affect on ComboBox
  - [EXTJSIV-2249] - Ext.isObject fails with anything with a nodeType property
  - [EXTJSIV-2268] - Difficult/unintuitive to disable load mask on a grid/view
  - [EXTJSIV-2314] - selectRange doesn't cause UI to update
  - [EXTJSIV-2337] - Examples fonts and body padding are wrong in 4.0.2
  - [EXTJSIV-2349] - examples/form/form-grid-access.html loses its description text
  - [EXTJSIV-2385] - portal/portal.html throws a hard error on IE6 (only)
  - [EXTJSIV-2387] - toolbar/toolbars example, the title of ButtonGroup is not centered anymore
  - [EXTJSIV-2411] - Format.number can return -0
  - [EXTJSIV-2454] - Ext.Ajax not taking the XHR.status into consideration
- Examples
  - [EXTJSIV-1090] - Theme Example: "Display topics" only shows when hitting refresh
  - [EXTJSIV-1094] - Theme Example: Month Selectors in Date Picker do not have hover state
  - [EXTJSIV-1618] - Forum search example the combo list isn't positioned correctly with IE Quirks
  - [EXTJSIV-1168] - Status bar example - alignment of "loading" animation is not correct
  - [EXTJSIV-1313] - Forum Browser has 1px white border on inside right edge of the tree
  - [EXTJSIV-1189] - Forms example inside layout browser is inconsistent with 3.3
  - [EXTJSIV-1117] - Forum example missing search box on top right
  - [EXTJSIV-1124] - Feed viewer - cannot click on the body of left panel if it's minimized
  - [EXTJSIV-1133] - Paging grid example - text should be better spaced
  - [EXTJSIV-1137] - Paging grid example - disabled arrows on the bottom toolbar should be gray, not blue
  - [EXTJSIV-1140] - Portal example - setting icon is clipped
  - [EXTJSIV-1097] - Theme example - missing list view
  - [EXTJSIV-1099] - Theme example: Tab scroller - scroll arrows should not show active cursor if it's disabled
  - [EXTJSIV-1101] - Theme example - grid panel does not have multiple pages
  - [EXTJSIV-1107] - Theme example - text field is missing color and highlight in toolbar
  - [EXTJSIV-1114] - Theme Browser: Column When Selected doesn't have a gradient
  - [EXTJSIV-1169] - Advanced status bar example - alignment is incorrect
  - [EXTJSIV-1696] - Desktop example - In notepad, scrolling appears
  - [EXTJSIV-1707] - Desktop example - window drag/drop does not work
  - [EXTJSIV-1719] - Tab scroller menu example - garbage text on top of tab on safari 5
  - [EXTJSIV-1725] - Tips in Tips Example is Clipped
  - [EXTJSIV-2370] - The Panel "Location Information" has disappeared from direct/direct-form example
- Panel
  - [EXTJSIV-1130] - Panel body text should be 11px
  - [EXTJSIV-1956] - Panel collapse/expand breaks auto height
- Button
  - [EXTJSIV-1632] - The icon in disabled buttons does not get disabled in IE6
  - [EXTJSIV-2374] - Several buttons issues
- Window
  - [EXTJSIV-1723] - Window re-sizing incorrect
  - [EXTJSIV-1738] - Opera 10.6: Resizing windows snaps to minHeight
  - [EXTJSIV-1732] - Progress Dialog window locking
  - [EXTJSIV-1774] - Window constrained into tabpanel not re-showing after toggling between tabs
  - [EXTJSIV-1980] - Ext.Msg.show() bombs out in FF 4.01 Mac
  - [EXTJSIV-1981] - Ext.Msg.setIcon() doesn't display icon at correct location in messagebox
  - [EXTJSIV-2369] - Window title aren't aligned properly in all browsers
  - [EXTJSIV-2105] - Window title truncated
- Chart
  - [EXTJSIV-1770] - Line Chart values incorrect
  - [EXTJSIV-1951] - Charts post-processes and removes the output of a custom renderer
  - [EXTJSIV-2368] - Highlighting in the Pie chart example can 'stick' sometimes leaving slices mid animation
  - [EXTJSIV-1963] - Line drawn between two points of equal value sometimes incorrect when smooth config is set to true
  - [EXTJSIV-1964] - Line Chart with all data values set to 0 fails to render properly, error thrown
  - [EXTJSIV-1978] - Time axis configured with fromDate, toDate and constrain fails to render properly
  - [EXTJSIV-1979] - Chart Legend should use defined colorSet array, currently uses default colorArrayStyle
  - [EXTJSIV-2246] - Legend should automatically use same colors as chart series, even when the color(s) are specified via style fill config
  - [EXTJSIV-2335] - Wrong store index passed in line renderers
  - [EXTJSIV-2350] - charts/Charts.html js hard error in Safari
  - [EXTJSIV-2355] - Unable to set custom fill style on line chart
- Draw
  - [EXTJSIV-1808] - setViewBox doesn't work with VML
- Data
  - [EXTJSIV-1858] - collectData hardcodes use of the 'data' property to extract field values. Should use the 'persistanceProperty' of the Model
  - [EXTJSIV-1896] - Ext.data.Model#persistanceProperty should be spelled persistenceProperty
  - [EXTJSIV-1966] - Ext.data.Store memory leak
  - [EXTJSIV-1953] - Ext.grid.property.Store problems
  - [EXTJSIV-1975] - Generated Getter in BelongsToAssociation does not cache result
  - [EXTJSIV-2388] - writer/writer.html examples throws a hard error on ie6/ie7
- Layout
  - [EXTJSIV-2405] - Docked items added after render don't render correctly
  - [EXTJSIV-2431] - Accordion is missing a border when collapsed
  - [EXTJSIV-1900] - Accordion layout with tree initially collapsed does not layout correctly when activated
  - [EXTJSIV-1970] - Ext.layout.Table rowspan bug
  - [EXTJSIV-2098] - defaultAnchor ignored
- MVC
  - [EXTJSIV-1967] - Multiple Controllers cannot listen to same event on same Component
  - [EXTJSIV-2331] - Fix build warning for simple MVC app
  - [EXTJSIV-2332] - Fix build warning for nested-loading MVC app
- Core
  - [EXTJSIV-2000] - Ext.core.Element.boxWrap() missing CSS
  - [EXTJSIV-2006] - Ext.core.Element.frame does nothing
  - [EXTJSIV-2063] - Ext.util.Animate methods don't get copied to CompositeElement
- Menu
  - [EXTJSIV-2002] - Menu doesn't resize when text is changed
  - [EXTJSIV-2186] - Menu.alignTo is not working in some cases.
- TabPanel
  - [EXTJSIV-2386] - Close button on tabs has disappeared

## New Features

- [EXTJSIV-1936] - Make ComboBox work better with existing filters
- [EXTJSIV-2093] - Stateful Tree & Grid components do not fully restore state when in Border Layout

## General Improvements

- [EXTJSIV-141] - Fix all coding style violations
- [EXTJSIV-1321] - Feed Viewer's blogs list should be a Tree
- [EXTJSIV-1957] - Ext.resizer.Resizer widthIncrement addition
- [EXTJSIV-1999] - Themes Example Performance
- [EXTJSIV-2123] - Event options object secretly passed to every listener

## Documentation Updates

- [EXTJSIV-763] - Inadequate documentation for class AbsractPlugin
- [EXTJSIV-765] - Ext.resizer.ResizeTracker docs
- [EXTJSIV-780] - Ext.util.Grouper docs
- [EXTJSIV-781] - Ext.util.Region
- [EXTJSIV-1976] - Ext.app.Controller#control is undocumented
- [EXTJSIV-2103] - Fix missing sprite attribute property documentation
- [EXTJSIV-2134] - closeAction default is 'hide' but docs say it's 'destroy'
- [EXTJSIV-2348] - Layout Browser example API doc links are broken
- [EXTJSIV-2352] - constrainTo not documented on Ext.window.Window

# Release Notes for Ext JS 4.0.1

Release Date: May 17, 2011
Version Number: 4.0.1

## Bugs Fixed

- Charts and Drawing
  - [EXTJSIV-144] - Grouped Stacked Negative 0 point not aligned properly
  - [EXTJSIV-148] - Pie chart labels should be along the centerline of the text, not the baseline.
  - [EXTJSIV-1769] - Draggable sprite broken
  - [EXTJSIV-1811] - Problem with hiding items via legend with grouped bar chart
  - [EXTJSIV-1822] - setAttributes - scale only works on first item
  - [EXTJSIV-1878] - Line chart scaling incorrect
  - [EXTJSIV-1892] - Pie chart is not rendering it's shadow properly on initial render
- Panel
  - [EXTJSIV-237] - Vertical alignment of the Panel title is not consistent between quirks and strict HTML modes
  - [EXTJSIV-963] - Vertical headers lack proper centering
  - [EXTJSIV-1102] - When panel collapse animates, there's some flashing
  - [EXTJSIV-1814] - Panel doesn't fire close event in TabPanel
- Examples
  - [EXTJSIV-482] - Logos example has a few cosmetic issues
  - [EXTJSIV-1001] - Form is missing in Safari 3.2 with form/form-grid-access.html
  - [EXTJSIV-1083] - Themes Example: Progress bar doesn't show any text
  - [EXTJSIV-1118] - Portal Drag and Drop IE 6 & 7
  - [EXTJSIV-1121] - feed viewer - highlight on mouse over incorrect
  - [EXTJSIV-1141] - Sliding Pager Extension Example: There's no Panel Resizing at the bottom of the grid
  - [EXTJSIV-1142] - FeedViewer: apply sensible minWidth on feeds panel
  - [EXTJSIV-1165] - Summary Grid: Need an Icon in the Panel
  - [EXTJSIV-1172] - Grid Plugin Example: No Checkbox Plugin in the bottom example
  - [EXTJSIV-1173] - Grid Filtering Local: ID Column should have a smaller width
  - [EXTJSIV-1180] - Rest proxy example - notification is missing when updating
  - [EXTJSIV-1193] - Combo Box Example: State name Combo Boxes are too wide
  - [EXTJSIV-1204] - Ext.Action Example should port the existing Action Example over
  - [EXTJSIV-1211] - Double clicking in Manager Details header doesn't always open the combo box
  - [EXTJSIV-1460] - Panel resizer ux not working properly or styled correctly
  - [EXTJSIV-1474] - Black background in desktop/desktop.html example in quirks mode
  - [EXTJSIV-1481] - form/xml-form is broken in Safari 3.2 with transitional DOCTYPE
  - [EXTJSIV-1496] - Desktop cascading doesn't set correct z index
  - [EXTJSIV-1499] - Desktop example's accordion window does not react to clicking the refresh icon
  - [EXTJSIV-1535] - Array grid example advertised as stateful. But it does not remember column state
  - [EXTJSIV-1860] - Nested Loading example is using widget.header alias which is reserver for standard Panel Headers
  - [EXTJSIV-1861] - Portal example is having to synchronously load Ext.layout.component.Body.
  - [EXTJSIV-1919] - Error in charts/draw code on portal example
  - [EXTJSIV-1922] - Error in grid multiple sorting example
  - [EXTJSIV-1923] - Error on editor example
  - [EXTJSIV-1924] - FormDashboard chart example fieldset is too short
  - [EXTJSIV-1927] - Text rotation example missing text
- Toolbars
  - [EXTJSIV-939] - Artifact in search toolbar only with Chrome 5
  - [EXTJSIV-980] - Background color in bottom toolbar should be blue
  - [EXTJSIV-1109] - disabled text color in buttons is too light
  - [EXTJSIV-1865] - Toolbar with removeAll() crashes when used with overflow
- Layout
  - [EXTJSIV-1846] - Infinite loop, IE Border layout
  - [EXTJSIV-1867] - Resizers on border layout do not constrain during drag
  - [EXTJSIV-1931] - collapsedCls not applied in border layout
  - [EXTJSIV-1845] - hideCollapseTool ignored in border layout/panel
  - [EXTJSIV-1780] - Collapsing large grid in border layout fails
- Windows
  - [EXTJSIV-1708] - Desktop example - windows don't move or resize
  - [EXTJSIV-1737] - Opera 10.6: Windows cannot be moved vertically
  - [EXTJSIV-1751] - Ext.Window Maximize doesnt account for browser window resize
  - [EXTJSIV-1792] - Window fails with preventHeader: true
  - [EXTJSIV-1945] - Window doesn't constrain properly when animating
- Styling
  - [EXTJSIV-1269] - Checkbox in header does not line up with checkbox in the data rows
  - [EXTJSIV-1271] - Arrow is not vertically centered in the overflow toolbar
  - [EXTJSIV-1317] - Slightly rounded corners on menu item highlights
  - [EXTJSIV-1322] - Window header color is different to 3.x
  - [EXTJSIV-1417] - The text "Powered by" in logo is not legible
  - [EXTJSIV-1516] - Menus are not in access-theme colors for the access example
  - [EXTJSIV-1540] - Disabled buttons are really hard to read
  - [EXTJSIV-1764] - Accessibility theme missing images
  - [EXTJSIV-1841] - $panel-border-radius does not work
  - [EXTJSIV-1825] - Button mixin in SASS is inconsistant with other UI mixins - quick fix
  - [EXTJSIV-1826] - Window does not adhere to $base-color
  - [EXTJSIV-1842] - 2 issues with button variables, not working correctly.
  - [EXTJSIV-1851] - Errors when building template my-ext-theme.scss
  - [EXTJSIV-1854] - Remove breaking comments from layout/_layout.scss
  - [EXTJSIV-1862] - ui theme does not apply to window drag & drop proxy
  - [EXTJSIV-1918] - Can't set overflow hidden on component style
- Form
  - [EXTJSIV-1758] - Checkbox field does not report correct value
  - [EXTJSIV-1775] - combo box autoSelect attribute non-functional
  - [EXTJSIV-1781] - Combo Picker doesn't shift when window resizes
  - [EXTJSIV-1798] - serializeForm tries to call .format
  - [EXTJSIV-1809] - Html encoding issues on forms with standard submit
  - [EXTJSIV-1834] - Keyup doesn't fire on combo
  - [EXTJSIV-1838] - Checkbox getModelData incorrect
  - [EXTJSIV-1839] - Fieldset doesn't render items when collapsed
  - [EXTJSIV-1847] - Weird form field height display
  - [EXTJSIV-1849] - Performance issues when adding multiple items to a form
  - [EXTJSIV-1857] - Combo - Allow exclusion of queryParam
  - [EXTJSIV-1869] - DisplayField alignment incorrect
  - [EXTJSIV-1899] - field.Date refocuses on blur when picker is expanded
  - [EXTJSIV-1902] - NumberField ignores disableKeyFilter
  - [EXTJSIV-1942] - NumberField doesn't return number type when value is 0.
  - [EXTJSIV-1943] - Checkbox should check for undefined uncheckedValue
- Grid / Tree
  - [EXTJSIV-1689] - Selection model selectAll/deselectAll fire selectionchange event for every record
  - [EXTJSIV-1757] - Grid loses row striping after editing
  - [EXTJSIV-1762] - Grid: CellEditing problems destroying
  - [EXTJSIV-1767] - ActionColumn fails when creating a global handler
  - [EXTJSIV-1771] - Deselect doesnt fire in multi select mode
  - [EXTJSIV-1773] - itemmousenter/itemmouseleave fire on every mouseover/mouseout event bubbled from *within* a View item
  - [EXTJSIV-1778] - PropertyGrid crashes on destroy
  - [EXTJSIV-1782] - PropertyGrid crashes when removing from store
  - [EXTJSIV-1788] - Cell Editor doesn't update context
  - [EXTJSIV-1794] - Crash when rootVisible false
  - [EXTJSIV-1800] - RowNumberer incompatible with groupingSummary
  - [EXTJSIV-1802] - Editor doesn't hide on grid scroll - FF
  - [EXTJSIV-1819] - Grid in accordion layout doesn't show headers
  - [EXTJSIV-1824] - PropertyGrid has no alias
  - [EXTJSIV-1831] - Checkbox Selection model missing alias.
  - [EXTJSIV-1848] - Row Editor doesn't work with grid filtering
  - [EXTJSIV-1871] - PropertyGrid doesn't update source correctly
  - [EXTJSIV-1872] - PropertyStore refers to wrong object
  - [EXTJSIV-1875] - Tree doesn't allow string store id.
  - [EXTJSIV-1881] - PreviewPlugin overwrites features
  - [EXTJSIV-1926] - Safari: scrolling via wheel in grid also scrolls the page
  - [EXTJSIV-1932] - NodeInterface callback params incorrect.
  - [EXTJSIV-1939] - ProgressBar Pager fails with empty store
  - [EXTJSIV-1958] - View DD contains redundant check
- General
  - [EXTJSIV-988] - ToolTip/QuickTip steals shadow from modal window
  - [EXTJSIV-1003] - Accessibility Theme has several glitches (IE9 Quirks)
  - [EXTJSIV-1047] - Validation change steals focus in Safari (3.? and 4 at least)
  - [EXTJSIV-1217] - Localization files are missing a bunch of strings - NL, DE, etc
  - [EXTJSIV-1218] - Validation looks wrong in a frame panel with checkboxes
  - [EXTJSIV-1295] - TextField focus method does not focus, DelayedTask at fault?
  - [EXTJSIV-1510] - The close button in accordion does a refresh instead.
  - [EXTJSIV-1528] - The previous/next buttons do not always un-focus after clicking on it and moving the mouse away
  - [EXTJSIV-1562] - Collapse icon does not relocate after resizing the browser window
  - [EXTJSIV-1648] - Checkbox selection doesn't fire selection change
  - [EXTJSIV-1650] - Programmatically disabled before rendered prevents enabling
  - [EXTJSIV-1654] - Using Quicktips on Frameset only page cause hard error
  - [EXTJSIV-1736] - IE6 - Slider doesn't show up
  - [EXTJSIV-1756] - Disabled text in forms have regressed in IE 6
  - [EXTJSIV-1766] - Image Component crashes when rendered in IE
  - [EXTJSIV-1779] - beforetabchange returning false doesn't stop tab changing.
  - [EXTJSIV-1784] - Warn statements need to wrapped to check of the existence of the console
  - [EXTJSIV-1790] - Observable shouldn't fail when removing an event that doesn't exist
  - [EXTJSIV-1807] - Application fails when no controllers are specified
  - [EXTJSIV-1813] - Store Can't read grouping info when specified on the class definition
  - [EXTJSIV-1817] - Removed unused code: getSortState
  - [EXTJSIV-1818] - NodeInterface destroy shadows Model destroy
  - [EXTJSIV-1852] - JSBuilder doesn't build .jsb3 files correctly if using relative paths
  - [EXTJSIV-1853] - JSBuilder not producing build correctly.
  - [EXTJSIV-1856] - WebKit browsers lose selection in TEXTAREA elements
  - [EXTJSIV-1864] - Store cannot set filters via prototype properties
  - [EXTJSIV-1880] - Change autoCreateViewport to be false by default on Ext.app.App
  - [EXTJSIV-1888] - Ext.Error.raise embeds an alert in IE or FF w/o Firebug (not good for many uses)
  - [EXTJSIV-1889] - Splitter dragging doesn't work with iframes
  - [EXTJSIV-1890] - Record raw property set too late
  - [EXTJSIV-1895] - Ext.Array#include doesn't return anything, but docs say it does
  - [EXTJSIV-1896] - Ext.data.Model#persistanceProperty should be spelled persistenceProperty

## Documentation Improvements

- [EXTJSIV-739] - Improved Ext.fx.Animator docs
- [EXTJSIV-751] - Improved Ext.grid.GridPanel docs
- [EXTJSIV-769] - Improved Ext.tip.ToolTip docs
- [EXTJSIV-1074] - Improved Ext.app.Controller docs
- [EXTJSIV-1227] - Improved Ext.chart.Mask
- [EXTJSIV-1229] - Added docs for Ext.grid.property.Grid
- [EXTJSIV-1238] - Add documentation to tabPanel private methods
- [EXTJSIV-1293] - Documented Store.removeAll
- [EXTJSIV-1421] - Documented the Organizer example
- [EXTJSIV-1433] - Better docs for Ext.app.Application
- [EXTJSIV-1891] - documented loadMask configuration property of Ext.Component and descendants
- [EXTJSIV-1894] - Documented Ext.draw.Sprite events not documented
- [EXTJSIV-1898] - Removed Ext.getModel from data guide
- [EXTJSIV-1901] - Documented Ext.CompositeElement documents methods without names
- [EXTJSIV-1903] - Bad reference to Ext.panel.Panel#frame for more documentation
- [EXTJSIV-1904] - Added missing image: guides/tree/simple-tree.png
- [EXTJSIV-43] - Documented the fact that attributes are transformed to model fields
- [EXTJSIV-1485] - SDK Bootstrapping Guide and Build Tools for Developers
- [EXTJSIV-1248] - More docs for Surface
- [EXTJSIV-1244] - Added docs for Gauge AXIS
- [EXTJSIV-1796] - Character Encoding issues on deployed docs
- [EXTJSIV-1906] - a typo / encoding issue in the getting started guide

## General Improvements

- [EXTJSIV-1961] - Added callbackName option to Ext.data.JsonP.request
- [EXTJSIV-853] - Tooltips: Renamed initTarget to setTarget
- [EXTJSIV-1536] - Added a vertical toolbar example

# Release Notes for Ext JS 4.0 Final

Release Date: April 26, 2011
Version Number: 4.0.0

## New In This Release

- New Features
  - [EXTJSIV-919] - CheckHeader fires an additional change event
  - [EXTJSIV-1291] - Charts draw undefined values
  - [EXTJSIV-1352] - Floating should allow Component as an argument to alignTo

- Bug Fixes
  - [EXTJSIV-2] - Normalize text baseline calculation for FireFox 3.0 and 3.5
  - [EXTJSIV-495] - Forum search example - search does not work
  - [EXTJSIV-513] - DragSelector does not maintain selection in IE
  - [EXTJSIV-528] - Improve class loader performance
  - [EXTJSIV-571] - autoHeight Box layouts
  - [EXTJSIV-672] - Active tab has dark line beneath in access theme
  - [EXTJSIV-697] - Element loses event Listener
  - [EXTJSIV-788] - Grid in accordion layout displays scrollbars
  - [EXTJSIV-820] - Ext.util.Format.usMoney is not inserting commas into the returned string
  - [EXTJSIV-826] - When removing + then adding grid summary, it does not add x-grid-cell-first
  - [EXTJSIV-860] - Row editing shadow issue
  - [EXTJSIV-863] - IE Header menu issue
  - [EXTJSIV-869] - Changing Collapsed Titles in a Border Layout
  - [EXTJSIV-871] - form-grid example layout in IE6
  - [EXTJSIV-873] - menu shows a small rectangle when it has no items
  - [EXTJSIV-876] - Grid Menu allows hiding all columns
  - [EXTJSIV-901] - updateRecord w/ radio group
  - [EXTJSIV-902] - FieldContainer misses clearInvalid
  - [EXTJSIV-910] - Need to know when Surface is rendered
  - [EXTJSIV-912] - IE6 & 7, FF4: Grid Header misaligned with the gridview
  - [EXTJSIV-932] - Gauge series needs docs.
  - [EXTJSIV-936] - Trigger field is not flushed using the access theme in IE 6 and 7
  - [EXTJSIV-975] - Font styles are inconsistent across components
  - [EXTJSIV-976] - TreeSelectionModel does not use checkbox images
  - [EXTJSIV-977] - Ext.isFunction return true with a NodeList in Safari 3-4
  - [EXTJSIV-979] - CSS styling wrong after collapsing Navigation panel
  - [EXTJSIV-981] - Resizing failure with layout-browser.html --> Table
  - [EXTJSIV-983] - Border line is missing beneath the grid header row
  - [EXTJSIV-984] - Bottom scrollbar is not flushed with the right scrollbar
  - [EXTJSIV-986] - Grid state does not save column width
  - [EXTJSIV-993] - IE9 Strict Rendering issue with form.fieldset
  - [EXTJSIV-994] - IE9 Strict Border layout issue
  - [EXTJSIV-995] - IE7: Artifact in top-left corner of framed panel
  - [EXTJSIV-996] - Field/Trigger placement in top toolbar needs to move down 1 pixel
  - [EXTJSIV-999] - Both framing and flushing trigger button issues seen in IE 7
  - [EXTJSIV-1000] - DatePicker Month title color is black
  - [EXTJSIV-1002] - IE9 Strict Collapsible button in Ext.form.Fieldset aren't displayed correctly
  - [EXTJSIV-1004] - Group header grid example is broken
  - [EXTJSIV-1005] - Locking Grid Lock/Unlock throw an error
  - [EXTJSIV-1007] - IE9 Strict - RowEditor scrolls the grid view when starting an edit
  - [EXTJSIV-1008] - Splitter's calculated collapse directions are wrong. 'up' should be 'top', 'down' should be bottom.
  - [EXTJSIV-1010] - Check/Radio example, white background
  - [EXTJSIV-1011] - IE 9 Quirks Pie chart example Pie parts border issue
  - [EXTJSIV-1012] - NumberField - Bottom trigger doesn't hover
  - [EXTJSIV-1013] - IE9 Quirks Message Box Multi-line prompt: Input width is too large
  - [EXTJSIV-1014] - ItemSelector button icons missing
  - [EXTJSIV-1015] - IE9 Strict Tree Checkbox are not correctly positioned
  - [EXTJSIV-1016] - Grey background on drag drop indicator on IE6
  - [EXTJSIV-1017] - IE9 Drag and Drop in TreePanel does not work correctly
  - [EXTJSIV-1020] - Clipping of letters in vertical header titles
  - [EXTJSIV-1021] - IE9 Custom Styles progress bar doesn't show XP style
  - [EXTJSIV-1022] - Wrong font for vertical header titles with IE 9
  - [EXTJSIV-1023] - The minButtonWidth is applied to non-buttons in fbar
  - [EXTJSIV-1025] - Tree shifts after expand/collapse animation in all IEs
  - [EXTJSIV-1028] - Grid: Promote from Markup example doesn't work in IE6 &7
  - [EXTJSIV-1029] - Added an Associations example
  - [EXTJSIV-1031] - draw/Logos Example the window is too big
  - [EXTJSIV-1033] - Safari 5 Mac Tabs rendering glitch
  - [EXTJSIV-1036] - Grid Window in Desktop example permanently loses scrollbars during window resize
  - [EXTJSIV-1039] - IE 6 &7 Only: After resizing flexed column very wide
  - [EXTJSIV-1040] - statusbar/statusbar-demo.html toolbar items alignment issue
  - [EXTJSIV-1042] - Clicking constrained windows does not bring constraining window to top
  - [EXTJSIV-1044] - Gap between box elements in keynav example
  - [EXTJSIV-1045] - examples/layout/snap-windows.html throws "Attempting to extend from a class which has not been loaded on the page."
  - [EXTJSIV-1048] - Inaccurate lastComponentSize returned
  - [EXTJSIV-1049] - Grid filters are lost when clicking Add Columns in Custom Grid Filters Example (local filtering)
  - [EXTJSIV-1050] - Feedviewer "view post" has no margin/padding
  - [EXTJSIV-1051] - Stateful grid doesn't work in IE6
  - [EXTJSIV-1052] - Multi line message box doesn't show a scrollbar (IE6)
  - [EXTJSIV-1054] - Portal dragging breaks
  - [EXTJSIV-1055] - DataView dragged selection not applying in IE6
  - [EXTJSIV-1056] - Adding more rows after scrolling to the bottom of grid view causes the row editor to disappear
  - [EXTJSIV-1057] - Quickly trigger window show / hide while it's still animating screws layout / visibility checking
  - [EXTJSIV-1058] - Resizing window while it's being masked does not resize the masking layer
  - [EXTJSIV-1059] - Error using GridViewDragDrop plugin
  - [EXTJSIV-1062] - Menu items don't layout to full width
  - [EXTJSIV-1063] - Window.show() no longer does a toFront() as in 3.x
  - [EXTJSIV-1064] - Vertical toolbar separators are vertical but should be horizontal.
  - [EXTJSIV-1067] - Toolbar enableOverflow property not respected
  - [EXTJSIV-1071] - Tree getRecords doesn't work correctly
  - [EXTJSIV-1075] - collapseAll shouldn't collapse root if rootVisible is true
  - [EXTJSIV-1076] - Possible missing variables
  - [EXTJSIV-1078] - Shadows look odd on non-white backgrounds
  - [EXTJSIV-1079] - Theme example is missing some components
  - [EXTJSIV-1084] - Tab height/tabbar height is not consistent with 3.3
  - [EXTJSIV-1085] - Tab panel and panel headers need to be the same size
  - [EXTJSIV-1087] - API Change: Ext.tab.TabPanel renamed to Ext.tab.Panel
  - [EXTJSIV-1088] - Toolbar Buttons when against the Left side of the gutter need more padding
  - [EXTJSIV-1089] - In theme example, tree panel is not in the accordion panel
  - [EXTJSIV-1091] - In theme example, paging toolbar does not display default page number
  - [EXTJSIV-1092] - Grid Shifts on Header Trigger Click
  - [EXTJSIV-1093] - Theme example: scrollable tab indicator is off by a pixel
  - [EXTJSIV-1095] - Theme example - missing multi-trigger field inside GridPanel toolbar
  - [EXTJSIV-1100] - Button config renders incorrectly - "submit" seems off center
  - [EXTJSIV-1103] - Padding on toolbar buttons is two pixels at the bottom and one pixel at the top. Should be two pixels on both.
  - [EXTJSIV-1104] - Framed panel does not have bottom border when headerPosition:top
  - [EXTJSIV-1106] - iconCls not honored on Ext.grid.column.Action
  - [EXTJSIV-1108] - pressed state buttons have a background in the corners?
  - [EXTJSIV-1110] - Split button and menu button: Text and arrow have too much space in between
  - [EXTJSIV-1111] - Error when using tab in Writer Example
  - [EXTJSIV-1115] - FeedViewer Add Feed Window is too small
  - [EXTJSIV-1116] - Accordion panel - accordion titles have more padding on bottom than top
  - [EXTJSIV-1119] - In the list of examples, it's impossible to close a set of examples
  - [EXTJSIV-1120] - Border Layout collapsed vertical header has dark black bold text
  - [EXTJSIV-1122] - Feed View Looses Scroll Bar
  - [EXTJSIV-1123] - Live Grid Search Example does not have screenshot
  - [EXTJSIV-1125] - When changing feeds, tabs have the wrong size
  - [EXTJSIV-1126] - RowEditor edging for buttons in IE
  - [EXTJSIV-1128] - Feed viewer - add feed dialogue box is missing several elements
  - [EXTJSIV-1129] - TextField 1px taller than other fields
  - [EXTJSIV-1131] - Image Viewer Example: Unable to edit album names in the tree
  - [EXTJSIV-1132] - Panel header has 1 pixel white on left and right
  - [EXTJSIV-1136] - Paging Grid Example: JsonPProxy in the header isn't the name of the class in the code
  - [EXTJSIV-1138] - Paging Example: disablePagingSelection:true is not respected
  - [EXTJSIV-1139] - Portal example - if all components are in one column, cannot drag to 3rd column
  - [EXTJSIV-1143] - Property grid does not have an indicator to show it's a property grid
  - [EXTJSIV-1144] - Property Grid Example is too large -- should fit the size to make it look more like a property grid
  - [EXTJSIV-1146] - Editor Grid Example: Clicking from Common Name in an editor to Light doesn't invoke an editor
  - [EXTJSIV-1147] - Grid editing example - resizing the column while editing behaves incorrectly
  - [EXTJSIV-1148] - Custom Grid Filters: Menu is lost on refresh of view
  - [EXTJSIV-1150] - GroupTextTPL is not implemented
  - [EXTJSIV-1153] - Row Editing: When editing a row, pixels are missing from the bottom left and bottom right box
  - [EXTJSIV-1154] - Row Editing: Single click doesn't move the row editor
  - [EXTJSIV-1155] - Row Editing plugin/example needs to be more like 3.3
  - [EXTJSIV-1156] - Row Editing: Scrolling and row editor in the wrong place when clicking "Add Plant"
  - [EXTJSIV-1160] - No loading indication when you open up a node
  - [EXTJSIV-1161] - Empty Tree has +/- button
  - [EXTJSIV-1163] - Grouped Grid Example: Missing Collapsable on the Panel and Clear Grouping on the bottom
  - [EXTJSIV-1164] - Tool missing disabledCls
  - [EXTJSIV-1166] - Summary Grid Example: Button needs to be fixed
  - [EXTJSIV-1167] - Status bar example - clock shows up randomly when you start typing
  - [EXTJSIV-1174] - Need a Remote Filtering Example
  - [EXTJSIV-1175] - Grid Filtering Example: No Date Column
  - [EXTJSIV-1176] - Clean up main example page
  - [EXTJSIV-1177] - Grid Filtering Example: No Boolean Filtering
  - [EXTJSIV-1179] - Data Writer example appears to not work
  - [EXTJSIV-1181] - grouped header grid example - crash chrome when dragging a header into it's children
  - [EXTJSIV-1183] - Grid Multiple Sorting is missing a splitter after sorting order
  - [EXTJSIV-1185] - Tab Scroller Menu Plugin: Misalignment on top of overflow tabs
  - [EXTJSIV-1186] - Message Box Confirm Dialog needs more spacing between Yes/No buttons
  - [EXTJSIV-1188] - Tree Open Animation is incorrect
  - [EXTJSIV-1190] - Incorrect default body padding?
  - [EXTJSIV-1191] - Layout browser -> Center layout. Auto height not expanding to body contents
  - [EXTJSIV-1192] - Complex Layout Example: On load, property grid is selected, but "A Tab" is rendered
  - [EXTJSIV-1194] - In a combo box, hitting space inside combobox presents user with a big gray box
  - [EXTJSIV-1195] - Need an Combo Box Example with Transforms
  - [EXTJSIV-1196] - Combo with Templates and Ajax draws the searching box incorrectly on first load
  - [EXTJSIV-1197] - Need an example of a fieldset side by side
  - [EXTJSIV-1198] - Wrong Collapse Indicator in Checkbox Radio Groups
  - [EXTJSIV-1199] - Bring Back Flash Component (if necessary)
  - [EXTJSIV-1200] - Combobox in a Menu Dropdown is Flush with Left Edge
  - [EXTJSIV-1201] - Submenu is Lost when Resizing Window
  - [EXTJSIV-1203] - Ext.Action Example should port the existing Action Example over
  - [EXTJSIV-1205] - Cannot read property 'afteredit' of undefined
  - [EXTJSIV-1209] - Advanced DataView Example: Animation poofs, it doesn't zoom back to the grid when selecting an item
  - [EXTJSIV-1210] - History Example doesn't work
  - [EXTJSIV-1214] - Progress bar example needs a blue background
  - [EXTJSIV-1216] - Panel Example "Panel as Child" is missing border for header in first child
  - [EXTJSIV-1219] - Portal columns disappear when removing all portlets (regression)
  - [EXTJSIV-1220] - Numeric Axis shows extra
  - [EXTJSIV-1222] - Rename Ext.container.Viewport isViewPort property to isViewport
  - [EXTJSIV-1223] - GroupGrid does not scroll if using paginggridscroller
  - [EXTJSIV-1231] - ComboBox's bound list: Shadow persists when Store is filtered to zero matches and the list shrinks to zero height.
  - [EXTJSIV-1232] - DatePicker as dropdown from a DateField should dismiss when you press ESC
  - [EXTJSIV-1233] - API DOC Browser Class links issue
  - [EXTJSIV-1235] - Testing: Ext.tip.Tip spec fails in IE6-8
  - [EXTJSIV-1237] - Move Rob's framing command over to use jarred's new tool
  - [EXTJSIV-1239] - Need to implement .x-small-editor sizing for form fields
  - [EXTJSIV-1240] - Regression on rotated labels (check the area select example in test/ui)
  - [EXTJSIV-1243] - Fix a bug where NodeInterface decorate would always override data fields in your Model, even if they already existed.
  - [EXTJSIV-1245] - ComboBox selectOnTab does not work if the field has a value.
  - [EXTJSIV-1246] - Accordion layout fails with hidden items
  - [EXTJSIV-1247] - MessageBox doesn't work with animateTarget
  - [EXTJSIV-1249] - Grid column resize indicators don't show when used inside border layout
  - [EXTJSIV-1250] - Combo with no value returns empty array
  - [EXTJSIV-1251] - Phantom records should not be added to removed
  - [EXTJSIV-1252] - Border Layout collapseMode mini positioning incorrect
  - [EXTJSIV-1253] - Tree needs checkchange event
  - [EXTJSIV-1254] - Grouping needs to refresh the scroller on grid expand/collapse
  - [EXTJSIV-1255] - MessageBox reacts to enter keypress even when hidden
  - [EXTJSIV-1257] - Unable to control whether or not the checkbox is shown for certain rows with CheckboxModel
  - [EXTJSIV-1258] - Setting border false on grid, headerCt still keeps borders
  - [EXTJSIV-1260] - DirectProxy doesn't accept string paramOrder
  - [EXTJSIV-1261] - Reconfigure breaks when used with locked columns
  - [EXTJSIV-1263] - Window body is slightly different color than window frame
  - [EXTJSIV-1264] - The grid-plugins example takes a long time in IE 6 to display the grids and scrollbars
  - [EXTJSIV-1265] - Tabs are broken with draw/Logos.html in IE 8.0
  - [EXTJSIV-1266] - Row Editing broken when not specifying an editor
  - [EXTJSIV-1267] - Framing for the access example is broken in some browsers
  - [EXTJSIV-1268] - Grouping Feature - Events provide no context, aren't fired on the grid
  - [EXTJSIV-1272] - Add extra string methods to Ext.util.Format so they can be used with templates
  - [EXTJSIV-1273] - Dragging and Dropping Panels in the Portal Example lose Tools
  - [EXTJSIV-1274] - Identify and fix transitory Table View memory leak in IE6 &IE7
  - [EXTJSIV-1279] - Nested Windows not hiding themselves when floatParent (tab) hides.
  - [EXTJSIV-1280] - Window that is a child of TabPanel doesn't get hidden when Tab is switched, not hiding itself when its floatParent hides.
  - [EXTJSIV-1281] - DataView#ItemOver tracking does not always detect onItemMouseLeave
  - [EXTJSIV-1282] - Specifying groupable:false on a column definition has no effect
  - [EXTJSIV-1283] - Identify and Fix transient memory leak in the HtmlEditor
  - [EXTJSIV-1284] - Borders are no longer correct.
  - [EXTJSIV-1285] - Messagebox text not wrapping properly.
  - [EXTJSIV-1286] - Fieldsets too large in HBox layout in Firefox
  - [EXTJSIV-1288] - Chart axes and line not aligned
  - [EXTJSIV-1289] - RowEditor - option to prevent moving editor to new row when there are pending changes
  - [EXTJSIV-1290] - setClosable on Tab will not remove element
  - [EXTJSIV-1292] - beforeshow recursion and error
  - [EXTJSIV-1296] - Several tree examples are failing in IE (all versions)
  - [EXTJSIV-1297] - Hard Error: Not implemented error seen with IE 8
  - [EXTJSIV-1298] - ComboBox dropdown has horrible rendering artifacts in IE6
  - [EXTJSIV-1299] - ComboBox triggerAction:'all' not working after list has been filtered
  - [EXTJSIV-1301] - PropertyGrid throws error when editing
  - [EXTJSIV-1303] - Model constructor needs to support array data
  - [EXTJSIV-1304] - ButtonGroup styling is not perfect. issue with header
  - [EXTJSIV-1305] - TreePanel.selectPath fails
  - [EXTJSIV-1306] - RowEditing example - migrate 3.3 example so it is the same
  - [EXTJSIV-1307] - RowEditing - make animation speed more like 3.3 by default
  - [EXTJSIV-1308] - Sub-menu menu is not aligned properly
  - [EXTJSIV-1309] - Menus are misaligned in buttons
  - [EXTJSIV-1310] - Disabling form does not disable radios and check boxes
  - [EXTJSIV-1311] - Tab scroller arrows are not correctly aligned
  - [EXTJSIV-1312] - Central tab panel in the themes example has tabs that are too wide
  - [EXTJSIV-1314] - Forum browser has 2px blue border on left edge of grid
  - [EXTJSIV-1315] - Collapse icons disappear when moving a portlet
  - [EXTJSIV-1316] - Panel expand icon is positioned 1px/2px too low
  - [EXTJSIV-1318] - Gap between buttons in a window is too small
  - [EXTJSIV-1319] - Locking grid borders are wrong
  - [EXTJSIV-1323] - Menu Submenus can get out of alignment
  - [EXTJSIV-1324] - Status Bar breaks easily
  - [EXTJSIV-1325] - Status bar date too low
  - [EXTJSIV-1326] - QuickTips close button missing a bottom border
  - [EXTJSIV-1327] - Floater.js should not reopen a floating component based solely on its visible state prior to hiding its floatParent
  - [EXTJSIV-1329] - Vertical header text in IE9 is the wrong font
  - [EXTJSIV-1330] - RowEditor is missing panel frame corners on bottom left/right of buttons
  - [EXTJSIV-1332] - Application.getController not using Ext.Loader
  - [EXTJSIV-1333] - Locking grid doesn't get viewConfig from the GridPanel
  - [EXTJSIV-1334] - Tip + Window issues
  - [EXTJSIV-1335] - Stroke opacity in VML
  - [EXTJSIV-1336] - RowExpander removes other features
  - [EXTJSIV-1338] - Grid doesn't disable properly
  - [EXTJSIV-1339] - Store needs clear event - should be fired after a removeAll
  - [EXTJSIV-1340] - Area chart showing incorrect values
  - [EXTJSIV-1341] - TabPanel without borders has odd looking headers
  - [EXTJSIV-1342] - ColorPicker selected class not correct in CSS
  - [EXTJSIV-1344] - Grid Editing with checkbox editor shows cell contents
  - [EXTJSIV-1345] - Editor revertInvalid doesn't default to true like the docs say
  - [EXTJSIV-1346] - Bad global variable detected by test reporter in AbstractComponent
  - [EXTJSIV-1347] - Browser resizer interferes with textarea
  - [EXTJSIV-1350] - RowEditor should disable its update button when there are validation errors
  - [EXTJSIV-1353] - Desktop Example does not work with dynamic loader (only ext-all)
  - [EXTJSIV-1354] - Can't assign idProperty when creating implicit fields
  - [EXTJSIV-1355] - Can't destroy grid with DD
  - [EXTJSIV-1356] - Collapsed grid crashes when expanded
  - [EXTJSIV-1357] - Combo needs a hiddenName property
  - [EXTJSIV-1358] - RowEditor - very quick grid view scroll prior to full rendering results in an error
  - [EXTJSIV-1359] - Framed buttons (IE 6-8) lose their styles when focused or mouseovered
  - [EXTJSIV-1361] - on tree.Panel the scroller element still has a border when bodyBorder is set to 0
  - [EXTJSIV-1365] - Transparency is not working in the slicer tool
  - [EXTJSIV-1367] - There is no styling for overflowHandler Scroller for Toolbar (used by Desktop example)
  - [EXTJSIV-1371] - Radio buttons look like stars for the access theme
  - [EXTJSIV-1372] - Tooltips with more than text configuration do not work reliably on Chrome, Safari and IE
  - [EXTJSIV-1373] - Default window background is incorrect?
  - [EXTJSIV-1374] - Button group needs more right margin
  - [EXTJSIV-1376] - htmleditor font combo stays above all content in IE6 (only)
  - [EXTJSIV-1377] - Grid column dropped into wrong place when inserting into a locked area
  - [EXTJSIV-1378] - Locking grid: crashes when you drag a column to the first column index
  - [EXTJSIV-1379] - Make upgrade guide clear that form submission must now use the API
  - [EXTJSIV-1381] - Create a test for toolbars in every situation
  - [EXTJSIV-1382] - Masking behavior not correct in theme viewer example
  - [EXTJSIV-1383] - Vertical text is cut off if the panel is collapsed
  - [EXTJSIV-1385] - Icon in tree has incorrect padding
  - [EXTJSIV-1386] - Double triggers seem in example
  - [EXTJSIV-1387] - Double pixel border on the left side of the accordion panel
  - [EXTJSIV-1388] - Need to add a UI test to make sure a framed grid can have rounded corners
  - [EXTJSIV-1393] - Pie chart needs to deal with 0 values
  - [EXTJSIV-1394] - Portlet z-index issues when dragging
  - [EXTJSIV-1395] - Tree doesn't setup all dependencies
  - [EXTJSIV-1397] - Locking doesn't provide a centralized view
  - [EXTJSIV-1399] - RowEditor buttons &grid scroller have an issue in Opera 11.01 only
  - [EXTJSIV-1400] - menu.Manager::get, variable undefined
  - [EXTJSIV-1402] - Sprite doesn't clean up draggable
  - [EXTJSIV-1403] - SplitButton - overArrow flag gets stuck
  - [EXTJSIV-1404] - GridPanel should have getStore method
  - [EXTJSIV-1405] - Button onMenuTriggerOver/Out is not accurate
  - [EXTJSIV-1407] - RowNumberer - needs a better way to determine the row number
  - [EXTJSIV-1408] - Organizer example: Dropping the same image into an album twice throws a hard error
  - [EXTJSIV-1409] - RowEditor throws an error when starting a new edit after a previously failed validation
  - [EXTJSIV-1410] - RowEditor must update its error summary tooltip for changes to the same field
  - [EXTJSIV-1411] - Access theme needs image for number field trigger buttons
  - [EXTJSIV-1416] - Adding a docked:top toolbar tp a headerPosition:right panel/window causes a bug
  - [EXTJSIV-1418] - Inconsistent look for accordions header titles between browsers
  - [EXTJSIV-1419] - Inconsistent direction from dark to light for gradient colors in the Logos example
  - [EXTJSIV-1422] - TabPanel has incorrect bottom border
  - [EXTJSIV-1423] - Divider line in toolbar is not vertically centered, also doesn't look correct
  - [EXTJSIV-1426] - No gap between the accordion headers in Safari 4.0
  - [EXTJSIV-1427] - GridEditing: Column to use editor, field or some other name
  - [EXTJSIV-1429] - The >> button is not vertically centered in the overflow toolbar examples
  - [EXTJSIV-1430] - overItemCls not working
  - [EXTJSIV-1432] - Trailing comma in forum/forum.html example
  - [EXTJSIV-1436] - Grid sorting icons slightly mispositioned
  - [EXTJSIV-1438] - Grid column header text slightly mispositioned in all IEs
  - [EXTJSIV-1439] - Window buttons have an ugly border in IE6 and IE7
  - [EXTJSIV-1440] - Rest proxy doesn't respect api config
  - [EXTJSIV-1441] - Vertical toolbar separators margin is incorrect. Seems to get more on the bottom
  - [EXTJSIV-1442] - Uncaught TypeError: Cannot call method 'bringToFront' of undefined
  - [EXTJSIV-1444] - Vertical toolbars need to have no margin on the bottom, not the right
  - [EXTJSIV-1445] - li style disc not set when using styleHtmlContent
  - [EXTJSIV-1446] - /core gets doubled up in the distributed package
  - [EXTJSIV-1447] - Form DirectLoad callback fires twice
  - [EXTJSIV-1448] - Borders need help
  - [EXTJSIV-1449] - Grid Locking and Sorting not in SYNC FF4
  - [EXTJSIV-1450] - Accordion bottom border incorrect
  - [EXTJSIV-1451] - Legend renders incorrectly in Chart FF4.0
  - [EXTJSIV-1452] - Drag and Drop broken in FF4 organizer example
  - [EXTJSIV-1453] - Vertical header text in FF is the wrong font
  - [EXTJSIV-1455] - theme example doesn't select a theme on first load, it seems.
  - [EXTJSIV-1456] - ComboBox remains open after selection in grid cell editing
  - [EXTJSIV-1457] - createBuffered ignores scope
  - [EXTJSIV-1458] - File field crashes when you use disabled: true
  - [EXTJSIV-1461] - Highlight on charts uses the same window shadow?
  - [EXTJSIV-1462] - Legend doesn't renable a value FF4
  - [EXTJSIV-1463] - Menu issues on FF when messing with charts
  - [EXTJSIV-1464] - Flicker on Animation of Window Showing and incorrect initial position of windows
  - [EXTJSIV-1465] - ComboBox in a menu does not react correctly
  - [EXTJSIV-1466] - Leaves a menu up when using the color picker in an overflow
  - [EXTJSIV-1467] - Status bar too short
  - [EXTJSIV-1468] - Selection range implemented poorly
  - [EXTJSIV-1469] - ComboBox with remote search example does not act intuitively
  - [EXTJSIV-1470] - Remove Simple MVC example from examples
  - [EXTJSIV-1475] - Vertical separators in toolbars are missing in quirks mode in IE (all versions)
  - [EXTJSIV-1477] - Left border is missing in draw/Sencha.html example in strict/transitional modes in IE 6
  - [EXTJSIV-1478] - Broken form/check-radio.html example in IE 6 &7 in strict/transitional DOCTYPE modes
  - [EXTJSIV-1479] - Zero top/bottom padding in toolbar for the search field -- all browsers affected
  - [EXTJSIV-1482] - Ext.draw.CompositeSprite.setStyle problem
  - [EXTJSIV-1483] - The forum/forum.html example is broken in IE 6 with strict/transitional DOCTYPEs
  - [EXTJSIV-1486] - Tree header shows a 1px border when no column headers, works for grid
  - [EXTJSIV-1487] - Toolbar separators are not visible in quirks.
  - [EXTJSIV-1488] - Web Desktop needs to have a blue background
  - [EXTJSIV-1489] - Desktop example windows don't open smoothly, can't be closed
  - [EXTJSIV-1490] - Desktop example taskbar buttons not well aligned
  - [EXTJSIV-1491] - Remove extra bordering on the grid window on Desktop example
  - [EXTJSIV-1492] - Accordion text and border colors incorrect
  - [EXTJSIV-1493] - Remove border around desktop's example's accordion window toolbar
  - [EXTJSIV-1494] - Extra padding between cells in IE 6/7 (first grid) when using strict or transitional DOCTYPEs.
  - [EXTJSIV-1495] - Desktop example accordion breaks layout
  - [EXTJSIV-1497] - Desktop example's Notepad window has a double border
  - [EXTJSIV-1498] - Desktop example's logo has too high z-index
  - [EXTJSIV-1500] - Desktop example is not listed in the examples page
  - [EXTJSIV-1505] - Menu doesn't fire deactivate
  - [EXTJSIV-1506] - The theme viewer example is failing in Safari on Snow Leopard
  - [EXTJSIV-1507] - Menu Checkbox hideOnClick
  - [EXTJSIV-1508] - Accordion is broken in desktop example
  - [EXTJSIV-1509] - Resizing the portal example fails in Safari on Snow Leopard
  - [EXTJSIV-1512] - Drag &Drop broken with the organizer example
  - [EXTJSIV-1513] - Tabs are broken with Webkit in the key feed viewer example
  - [EXTJSIV-1514] - Clicking on tabs creates a big dark-blue border box around it in Safari on Snow Leopard
  - [EXTJSIV-1515] - Border line is missing for content area in new tabs
  - [EXTJSIV-1517] - Scrollbar does not reappear after expanding a collapsed grid in example
  - [EXTJSIV-1518] - Combo-box in Cell Editing Grid Example is Failing with Safari on Snow Leopard
  - [EXTJSIV-1519] - Scrollbar disappears after unchecking "Show in Groups" and checking again "Show in Groups"
  - [EXTJSIV-1520] - ZIndexManager: Dynamic Load depends on Ext.window.Window
  - [EXTJSIV-1521] - Collapsing invisible root node of tree w/vertical scrollbar throws null reference exception
  - [EXTJSIV-1525] - Previous pull-down menus do not unhighlight when clicking on the next one
  - [EXTJSIV-1526] - Custom Grid Filters: Object doesn't support this property or method
  - [EXTJSIV-1527] - The bottom toolbar in the Calendar component just doesn't look right
  - [EXTJSIV-1529] - Height in toolbar is not tall enough to clearly show the icon after searching
  - [EXTJSIV-1530] - Last row in charting tooltip is clipped
  - [EXTJSIV-1531] - Blank spot seen in examples page with IE 8.0
  - [EXTJSIV-1532] - Vertical header SVG element too small, clips text
  - [EXTJSIV-1534] - x-column-header-open class not being removed from column header when column menu hides.
  - [EXTJSIV-1538] - Scrollbar is missing when loading 20 items -- all items are clipped
  - [EXTJSIV-1539] - Transparency is not working for panels on a gray background
  - [EXTJSIV-1541] - Patient data is lost after drag &drop and sorting on a grid column
  - [EXTJSIV-1542] - Sencha icon on Desktop example has black underline (the shadow) in IE6-8
  - [EXTJSIV-1543] - Panel acts like it has a X+Y value set when rendered in a autoScroll div
  - [EXTJSIV-1547] - Buttons in DatePicker are not vertically centered -- has zero padding below the buttons
  - [EXTJSIV-1548] - Custom Layout under Checkbox Groups is blank
  - [EXTJSIV-1549] - Buttons do not unhighlight after clicking on them and moving the mouse away from it
  - [EXTJSIV-1550] - Nested Panels not laying out child grids until resize occurs
  - [EXTJSIV-1554] - The header looks bad after collapsing the window
  - [EXTJSIV-1555] - Last column header needs right border
  - [EXTJSIV-1556] - Remove Associations example from examples
  - [EXTJSIV-1559] - Need to include appropriate video in Desktop example
  - [EXTJSIV-1561] - Double borders initially, then single border when clicking on the next header
  - [EXTJSIV-1562] - Collapse icon does not relocate after resizing the browser window
  - [EXTJSIV-1563] - onReady Handling is Different than in 3.3
  - [EXTJSIV-1565] - Tooltip is clipped for the Toolbar with Menus example
  - [EXTJSIV-1566] - The close button has no effect on the panel
  - [EXTJSIV-1571] - JS error in when deleting a row in restful example
  - [EXTJSIV-1572] - Split buttons stay highlighted after clicking and moving the mouse away from it
  - [EXTJSIV-1573] - Several border lines are missing in the feed-viewer example
  - [EXTJSIV-1574] - emptyText in the fields are not vertically centered in IE 6/7/8
  - [EXTJSIV-1575] - Right side of tab bar is not flushed in IE 7 &IE 6
  - [EXTJSIV-1576] - The grid header in the 2nd grid is taller than the header in the first grid
  - [EXTJSIV-1578] - Double border-lines around frame
  - [EXTJSIV-1579] - Double border-lines around bottom toolbar
  - [EXTJSIV-1581] - Grid editor's input fields now have incorrect padding since a recent change to grid cell padding style.
  - [EXTJSIV-1582] - Last grid in grid-plugins example should enable remove button if a row is selected.
  - [EXTJSIV-1583] - Framed Panel's body border color wrong.
  - [EXTJSIV-1584] - Horizontal splitter too tall in IE6
  - [EXTJSIV-1585] - htmleditor body stays visible when containing window is minimized in IE6-8
  - [EXTJSIV-1586] - Border line is missing beneath the panel header -- all browsers
  - [EXTJSIV-1587] - Border line is missing above all three panel headers including sides -- all browsers
  - [EXTJSIV-1588] - Tree in accordion window of desktop example has double border
  - [EXTJSIV-1590] - Scatter chart doesn't render with a Time axis
  - [EXTJSIV-1591] - IE6 tooltip width aren't calculated properly on ie6
  - [EXTJSIV-1592] - Accordion items bottom border doesn't fit the accordion width (IE6)
  - [EXTJSIV-1594] - Scrollers at any level under a panel with no borders has no borders.
  - [EXTJSIV-1596] - Organizer Example: the left tree panel must be scrollable
  - [EXTJSIV-1597] - Modal layer does not block access to select elements on page n IE6
  - [EXTJSIV-1598] - Ext.core.Element needs to be aliased to Ext.Element for backwards compability
  - [EXTJSIV-1599] - MsgBox prompt right margin is almost nothing in IE6
  - [EXTJSIV-1600] - Window always tries to call toFront on mousedown, even with floating:false
  - [EXTJSIV-1602] - Link to new vertical toolbar example is broken in examples page
  - [EXTJSIV-1604] - Row expander doesn't work with IE Quirk
  - [EXTJSIV-1605] - Menu with single item has way too much bottom padding in IE6 and a little too much in IE8
  - [EXTJSIV-1606] - Inaccurate Ext.Loader error message thrown when files have been loaded but the corresponding classes are not defined
  - [EXTJSIV-1607] - StatusBar example clips iconCls in IE (all versions)
  - [EXTJSIV-1608] - Mouse wheel scroll through expanded combo generates JS error in IE6 and IE7
  - [EXTJSIV-1609] - Cell editing: When you move a column while you're editing an error is thrown and field is still visible
  - [EXTJSIV-1610] - Grouping Header: Columns with flex 1 move bug
  - [EXTJSIV-1611] - Header/Column alignment issue
  - [EXTJSIV-1612] - Clicking in htmleditor of Notepad window in desktop example does not raise the window to the top
  - [EXTJSIV-1613] - Bar Chart in Chrome renders bars below the axis
  - [EXTJSIV-1614] - Double click on a bar chart keep it highlighted in Form Dashboard example
  - [EXTJSIV-1616] - Body mask does not mask select input in IE6
  - [EXTJSIV-1617] - IE6 resizable west handler height change only after resizing
  - [EXTJSIV-1619] - Slider shows duplicate tooltip
  - [EXTJSIV-1620] - Items don't re-layout when expanded
  - [EXTJSIV-1621] - Fix SVG and VML classes to match our naming conventions
  - [EXTJSIV-1624] - Stack overflow (out of memory) reported by IE 6/7/8 with the portal example
  - [EXTJSIV-1625] - Garbage Collector wrongly removes listeners for iframe document
  - [EXTJSIV-1627] - Hard Error: Object has no method 'getField'
  - [EXTJSIV-1628] - Support dynamic framing on IE.
  - [EXTJSIV-1629] - disabled text in toolbar buttons don't look disabled in modern browsers (non-IE)
  - [EXTJSIV-1633] - No padding (left/right) for text in document body
  - [EXTJSIV-1636] - View source links get mixed when classes have same name
  - [EXTJSIV-1639] - Statusbar steals focus
  - [EXTJSIV-1642] - Boxreorderer crashes when mousing down on the toolbar
  - [EXTJSIV-1644] - examples/app/simple/simple.html Editing window always stretch its width to 100% of the viewport in all IEs, but not other browsers.
  - [EXTJSIV-1645] - Can't save a second time in writer example
  - [EXTJSIV-1653] - Loader paths incorrect
  - [EXTJSIV-1655] - Component animation not working
  - [EXTJSIV-1661] - The Card (TabPanel)'s bar is shown having a white background. Normally is blue in this example
  - [EXTJSIV-1662] - A borderline is shown falsely in the fit layout inside the layout-browser example
  - [EXTJSIV-1663] - Ext.grid.Section not used
  - [EXTJSIV-1664] - Grid sorting menus are grayed out -- doesn't look right
  - [EXTJSIV-1670] - TemplateColumn doesn't use associated data
  - [EXTJSIV-1671] - Listeners not cleared when setting null target
  - [EXTJSIV-1673] - Grid window vscroll border off by 1 on right and bottom
  - [EXTJSIV-1675] - Border line is seen in panels -- was never there before -- first time
  - [EXTJSIV-1678] - Component animation, when animating only one size dimension throws "Warning, size detected as NaN on Element.addUnits."
  - [EXTJSIV-1683] - Border lines are missing top and sides with examples/state/state.html
  - [EXTJSIV-1684] - Field widths were the same before, not now with statusbar/statusbar-advanced.html
  - [EXTJSIV-1685] - Form validation super slow
  - [EXTJSIV-1687] - The supplied RowExpander's event are not very useful.
  - [EXTJSIV-1688] - idProperty not working on ArrayReader
  - [EXTJSIV-1690] - Grid scrollbars have double border
  - [EXTJSIV-1691] - Configuring tooltips on line chart with trackMouse: false throws error
  - [EXTJSIV-1692] - Hard Error: New desktop example. Click on About Ext JS in start menu in IE 8 and then close the video window
  - [EXTJSIV-1693] - Main example pointer page needs to be updated
  - [EXTJSIV-1695] - Desktop example - accordion widow hit the refresh while collapsed
  - [EXTJSIV-1697] - Desktop example - in notepad, increase/decrease font only works 1 time
  - [EXTJSIV-1698] - Desktop example - in notepad, font color/background doesn't work
  - [EXTJSIV-1699] - Theme example - toggle enable button doesn't look disabled
  - [EXTJSIV-1700] - About window - open more than one time
  - [EXTJSIV-1701] - Mask should not displayed in collapsed panel
  - [EXTJSIV-1702] - Theme viewer needs to reload when changing to access theme
  - [EXTJSIV-1704] - Selecting a tree node throws an error
  - [EXTJSIV-1705] - Dragging multiple elements in organizer example does not work in IE7
  - [EXTJSIV-1706] - Portal example - moving the portlet is really slow
  - [EXTJSIV-1710] - Fix accessibility theme
  - [EXTJSIV-1714] - Grid row editing is completely broken
  - [EXTJSIV-1718] - RowEditor display broken
  - [EXTJSIV-1721] - Grid plugin example - select all, down arrow, throws exception
  - [EXTJSIV-1722] - Date picker - typing text into date field throws exception
  - [EXTJSIV-1724] - Key feed viewer throws exception at loading. IE6 only
  - [EXTJSIV-1728] - Ext Toolbar Action Example - Change Text throws exception
  - [EXTJSIV-1731] - Window drag/drop leaks iframe shim in IE 6.0
  - [EXTJSIV-1741] - Sliding pager does not display in IE6
  - [EXTJSIV-1742] - Missing "-debug" in regex check of ext-debug.js
  - [EXTJSIV-1744] - ZINdexManager: unregister this.list is null
  - [EXTJSIV-1748] - MessageBoxWindow autosizing probably needs a fudge factor to avoid unwanted word wrapping.

- Enhancements
  - [EXTJSIV-174] - Implement getChecked on TreeView and TreePanel as soon as Tree filtering is implemented.
  - [EXTJSIV-854] - Improve chart renderer API
  - [EXTJSIV-904] - Optimization to make Component tpls not be compiled until needed
  - [EXTJSIV-1112] - Consider cleaning up the panel/panel example, bad examples
  - [EXTJSIV-1256] - Improve performance of loading big trees. Support appending and inserting parents with inline children.
  - [EXTJSIV-1262] - Rename insert to insertChild on NodeInterface for consistency.
  - [EXTJSIV-1351] - Initial hidden config doesn't hide tab
  - [EXTJSIV-1364] - Support folderSort on TreePanel. Support passing a store configuration.
  - [EXTJSIV-1380] - When extending, the requires config doesn't accept wildcards.
  - [EXTJSIV-1412] - Add beforedestroy and destroy events to Sprites
  - [EXTJSIV-1413] - Document remove/removeAll methods in Surface. Add optional boolean to destroy sprites upon removal.
  - [EXTJSIV-1414] - draggable option on a Sprite will now call initDraggable when it is added to a surface.
  - [EXTJSIV-105] - Added Bubble Panel Example
  - [EXTJSIV-117] - Added Web Desktop Example
  - [EXTJSIV-218] - Theme Builder / Page Slicer - Packaged for Windows, OS X, and Linux
  - [EXTJSIV-221] - Fixed transitory XHR memory leak in IE6 & IE7
  - [EXTJSIV-839] - Created App Builder script
  - [EXTJSIV-875] - JSON.decode "safe" mode implemented
  - [EXTJSIV-1234] - Panel implements iconchange event
  - [EXTJSIV-1275] - Ext.tab.TabBar renamed to Ext.tab.Bar
  - [EXTJSIV-1276] - Ext.AbstractDataView renamed to Ext.view.AbstractView and Ext.DataView renamed to Ext.view.View
  - [EXTJSIV-1277] - Ext.AbstractContainer renamed to Ext.container.AbstractContainer and Ext.AbstractPanel renamed to Ext.panel.AbstractPanel
  - [EXTJSIV-1363] - Package EXT JS 4 SDK Tools download for all OSes
  - [EXTJSIV-1389] - Generated distributable binaries for PhantomJS that work cross-platform
  - [EXTJSIV-1415] - The remove method on a sprite will now only remove it from a surface. The destroy method will no longer remove and destroy the sprite.
  - [EXTJSIV-1603] - New thumbnail for the Tree Selections example

- Documentation Improvements
  - [EXTJSIV-724] - Ext.data.NodeStore docs
  - [EXTJSIV-729] - Ext.direct.Event docs
  - [EXTJSIV-730] - Ext.direct.ExceptionEvent docs
  - [EXTJSIV-731] - Ext.direct.JsonProvider docs
  - [EXTJSIV-732] - Ext.direct.RemotingEvent docs
  - [EXTJSIV-733] - Ext.direct.RemotingMethod docs
  - [EXTJSIV-734] - Ext.draw.Component docs
  - [EXTJSIV-735] - Ext.draw.Sprite docs
  - [EXTJSIV-736] - Ext.draw.SpriteGroup docs
  - [EXTJSIV-737] - Ext.draw.Surface docs
  - [EXTJSIV-738] - Ext.fx.Anim docs
  - [EXTJSIV-740] - Ext.fx.Easing docs
  - [EXTJSIV-741] - Ext.grid.column.Column docs
  - [EXTJSIV-742] - Ext.grid.column.Template docs
  - [EXTJSIV-744] - Ext.grid.feature.Feature docs
  - [EXTJSIV-745] - Ext.grid.feature.Grouping docs
  - [EXTJSIV-746] - Ext.grid.feature.GroupingSummary docs
  - [EXTJSIV-747] - Ext.grid.feature.Summary docs
  - [EXTJSIV-749] - Ext.grid.ColumnLayout docs
  - [EXTJSIV-752] - Ext.grid.GridView docs
  - [EXTJSIV-756] - There is no class documentation for "version".
  - [EXTJSIV-757] - Inadequate documentation for ModelMgr
  - [EXTJSIV-758] - Ext.layout.container.Anchor docs
  - [EXTJSIV-759] - Inadequate documentation for ComponentLoader
  - [EXTJSIV-764] - Ext.panel.Tool docs
  - [EXTJSIV-770] - Inadequate documentation in util.route
  - [EXTJSIV-776] - Ext.util.Cookies docs
  - [EXTJSIV-779] - Ext.util.Format docs
  - [EXTJSIV-782] - Ext.util.Stateful docs
  - [EXTJSIV-783] - Ext.view.TableView docs
  - [EXTJSIV-1068] - Links in the tree link to 404 pages
  - [EXTJSIV-1069] - Link back to doc index
  - [EXTJSIV-1070] - Ext.app.Application.autoCreateViewport type
  - [EXTJSIV-1077] - Link bad in Ext.grid.feature.GroupingSummary
  - [EXTJSIV-1221] - Error in example in Ext.grid.RowNumberer Doc
  - [EXTJSIV-1224] - Architecture & MVC Guide, links are not created
  - [EXTJSIV-1225] - Class System Guide has PI wrong
  - [EXTJSIV-1226] - Class tree not loading
  - [EXTJSIV-1228] - Search for Panel does not show Ext.grid.Panel
  - [EXTJSIV-1230] - Search for 'quick' results in old Ext.tip.QuickTips also
  - [EXTJSIV-1241] - Fix misc documentation issues

# Release Notes for Ext JS 4 Beta 3

Release Date: April 14, 2011
Version Number: 4.0.0beta3

## New In This Release

- New Examples
  - MVC Feed Viewer
  - MVC Nested Data
  - Lazy Loading Data Associations
  - Property Grid
  - HTML Table to ExtJS Grid

- Bug Fixes
  - [EXTJSIV-664][EXTJSIV-645] Fix Organizer and GroupTabs examples
  - Header icon and vertical title text should no longer be focusable
  - [EXTJSIV-550] Fix Column layout to accurately arrange columns, taking scrollbars into account
  - Fixed inheritableStatics for full inheritance tree
  - Removed focus line from buttons in IE
  - [EXTJSIV-177] Fixed disabled toolbar buttons
  - [EXTJSIV-676] Removed icon cls's from buttons in themes examples
  - Add additional CSS class when border is set to false for the HeaderContainer
  - [EXTJSIV-650] Fix double border issue with tree items
  - [EXTJSIV-696] TreeStore nodes no longer use a fixed id
  - [EXTJSIV-688] Fixed focus issue with datepicker
  - [EXTJSIV-683] Fixed collapsed vertical panel header image
  - [EXTJSIV-678] Fixed css issue with the history example
  - [EXTJSIV-603] Work around the brutal IE9 Strict mode subpixel rounding bug which can cause wrapping issues (similar to https://bugzilla.mozilla.org/show_bug.cgi?id=458617)
  - [EXTJSIV-700] XTemplate should now handle dot (.) syntax for date objects as well. Since a date will yield a typeof of "object", we can't distinguish it from other "object" types; so we use the object prototype toString, in Ext.isDate
  - [EXTJSIV-671] TablePanel will not stop the mousewheel browser event when its reached the end of the scroll height/width. Also, the grid will only scroll when scrolling above the scroller and the view (not the headers, panel header, etc.)
  - [EXTJSIV-677] Editor shouldn't be hiding/showing its field, merely itself. This fixes positioning issues as well as the editor being still visible and floating over content, making it impossible to click to the things underneath of it
  - [EXTJSIV-702] RowEditor should vertically align itself to a row based on its y offset to its top-most static parent, not just its immediate parent (table)
  - [EXTJSIV-704] Prevent duplicate tabchange events from firing
  - [EXTJSIV-705] Fix problem with Shadow class calculations
  - [EXTJSIV-706] Fix issue when destroying a grid
  - [EXTJSIV-698] Prevent error in WebKit when destroying a HtmlEditor if its iframe has already been removed from the document
  - [EXTJSIV-713] TableView now only makes the table unselectable, not the entire gridview element
  - [EXTJSIV-442] Allow scrolling of the locked section of locked Grids/Trees
  - [EXTJSIV-720] Series now follows the standard Observable mixin pattern
  - [EXTJSIV-603] Fix Ext.core.Element createChild to support table first child insertion in IE
  - [EXTJSIV-789] Fix issue with window hide callback scope
  - [EXTJSIV-790] Fix an issue with not being able to specify a cls on a tree
  - Fixed the checkChangeEvents in IE6
  - [EXTJSIV-682] Remove a Gecko 3 hack that is no longer necessary
  - [EXTJSIV-689] Fix bug in OS X where grid/tree scrollers would stop responding.
  - [EXTJSIV-648][EXTJSIV-684] Auto-width fields must set the width of their outer element to match the total width of their internal contents, to prevent wrapping of the pieces during layout operations which would cause calculated heights to be too tall. Re-added the getBodyNaturalWidth method to support this, and changed the implementations where possible to avoid querying element sizes for optimum speed
  - [EXTJSIV-709] Grid row height will be preserved even if the row is empty
  - [EXTJSIV-804] Fix cycle button initial positioning in example
  - [EXTJSIV-710] Fix ItemSelector button behaviours
  - [EXTJSIV-797] Handle forceSelection in multiSelect ComboBoxes
  - [EXTJSIV-675] Grid and Tree will now remove/add the scrollOffset spacing when it is necessary
  - [EXTJSIV-817] Fix TablePanel applyState to not setWidth on an unrendered component
  - [EXTJSIV-192] Allow button layout to run when its text has changed; this allows min/maxWidth to be applied based on the new text length
  - [EXTJSIV-553] Fix dragging out of group header
  - [EXTJSIV-275] Fixed position of monthpicker on datepicker
  - [EXTJSIV-802] Fix Summary Grid Example padding
  - [EXTJSIV-826] Ensure that x-grid-cell-first and x-grid-cell-last css classes are added to the TableView markup at creation time
  - [EXTJSIV-590] Infinite Scrolling can now scroll all the way to the bottom in IE9 strict mode
  - [EXTJSIV-822] Support unstyled configuration on Panel
  - [EXTJSIV-833] Fix bug where old selection would jump into focus when performing a multi select on a dataview/grid/tree that was out of view
  - [EXTJSIV-808] Increase default css button padding (6px)
  - [EXTJSIV-809] Add Ext.ns() to the Ext.direct remoting echo
  - [EXTJSIV-828] Fix issue when dragging/dropping onto the same grid
  - [EXTJSIV-841] Fix duplicate method name in plugin
  - [EXTJSIV-842] When show is called on the tab, set it to active. Also ensure listeners are cleaned up when the tab is removed
  - [EXTJSIV-850] Fix issue when using treenode with leaf: false and children
  - [EXTJSIV-635] Prevent two LoadMask indicators showing up when using the Locking plugin and dynamic loading
  - Fix a bug in ComponentQuery.query.is method where it would start searching within a root for a query that contained the root itself
  - [EXTJSIV-801] Fixed issue with rotated axis text
  - [EXTJSIV-11] Made vertical heights and spacing of form fields consistent in all browsers
  - [EXTJSIV-846] Fix combineErrors option in FieldContainer, and prevent prepending of colon to errors for fields without a fieldLabel
  - [EXTJSIV-825] Fix issue with grouptabs titles seen with IE 7
  - [EXTJSIV-819] Fixed auto-height sizing in Body component layout
  - [EXTJSIV-820] Fix issue with Ext.util.Format.usMoney not inserting commas into the returned string
  - [EXTJSIV-862] Fix up shadow/positioning issues in the data view editor example
  - [EXTJSIV-876] Fix an issue where all grid columns can be hidden via the menu
  - [EXTJSIV-879] Move sync to be the last operation for add/remove methods on the store
  - [EXTJSIV-640] Ensure we keep track of the number of fields in the reader. Since the tree decorates the model, it can cause problems when running the extractor functions
  - [EXTJSIV-857] Fix Window autoShow
  - [EXTJSIV-577] Fix up styling to prevent unneeded scrollbar
  - [EXTJSIV-234] Fix up margins on DatView example
  - Fix issues with the file upload example
  - [EXTJSIV-649] Work around quirks mode inability to display margins
  - [EXTJSIV-837] Fixed Tab Scroller Menu Plugin improper access to class prototype from an instance
  - [EXTJSIV-883] Fix all examples which references setIconClass to setIconCls
  - [EXTJSIV-639] Workaround for IE's inability to size position:absolute elements to their content width
  - [EXTJSIV-849] Fixes for editable:false state on ComboBox and other Picker fields
  - [EXTJSIV-890] Fix toolbar separator in Direct example
  - [EXTJSIV-796] Dock layouts within a fit layout will now properly layout
  - [EXTJSIV-867] Fix bug where injected grouping menu would be lost after a refresh of the Grid
  - [EXTJSIV-1] Fix SVG rendering bug in Safari 3.2
  - [EXTJSIV-914] Fix bug where attempting to sort a header with no dataIndex would throw an error
  - [EXTJSIV-871] Fix GridPanel to only add its View after the Grid has achieved its final laid out size
  - [EXTJSIV-892] Added workaround for persistent button element padding in Windows Safari
  - [EXTJSIV-905] Fixed handling of file upload fields to allow uploads across multiple submits
  - [EXTJSIV-843] Fix masking on containers with layout auto
  - [EXTJSIV-906] Ensure the snapshot is kept up to date when receiving a response from the server
  - [EXTJSIV-908] Ensure filtering is set when there's at least one filter
  - [EXTJSIV-371] Fix CellEditing tab navigation in WebKit
  - [EXTJSIV-639] Take frame size into account when sizing vertical docks according to content
  - [EXTJSIV-921] Fix vertical centering of multi-line button text
  - [EXTJSIV-930] Fix validation of Number field when changing from an invalid string to an empty string
  - [EXTJSIV-902] Add markInvalid and clearInvalid methods to Ext.form.Field mixin interface; implement them in CheckboxGroup to prevent errors when Ext.form.Basic tries to call them
  - [EXTJSIV-909] Fix marker strokes disappearing on highlight
  - [EXTJSIV-954] Fixed issue when using disabled: true in a Slider config
  - [EXTJSIV-870] Fixed forceSelection so that it re-selects the last selection rather than clearing the value when the entered value does not match. Fixed remote stores so that the combobox's value is not cleared when the store loads.
  - [EXTJSIV-931] The findRecord method now does an exact search rather than substring search
  - [EXTJSIV-962] Ext.Direct grid money column align: 'right'.
  - [EXTJSIV-940] Make the button layout's test for html tags in button text a little smarter. Fixes error in LiveSearchGridPanel in IE6
  - [EXTJSIV-639] Fix for panel collapse left/right when frame is true
  - [EXTJSIV-872] MessageBox Window prompt now processes the "OK" button when you press return in the prompt field
  - The setSrc now correctly changes the src attribute of the dom property of the Et.core.Element
  - [EXTJSIV-918] RowExpander will not select rows when expanding via the icon by default. This is configurable via the selectRowOnExpand configuration. Fixed a bug with expandOnDblClick configuration
  - [EXTJSIV-964] Resizable Panels are no longer resizable when they are collapsed
  - [EXTJSIV-144] Fix issue with stacked negative bar/column chart axis
  - [EXTJSIV-948] Disable rendering of sprites into the surface if they are not attached to a surface yet
  - [EXTJSIV-969] roundToDecimal has to be explicitly set to false in order to render non numbers in a Numeric axis
  - Decouple Ext.Function.createBuffered from Ext.util.DelayedTask
  - [EXTJSIV-946] Fix an issue where cursors where still being displayed on resizable handles, even if they were disabled
  - [EXTJSIV-965] Fixed Gauge align axis bug
  - [EXTJSIV-912] Resolve misalignment of headers and gridview in IE 6, 7 and 9.
  - [EXTJSIV-973] Fix bug that occurred when there were less records in total than the pageSize when using a PagingScroller

- Performance Changes
  - Optimized Class, ClassManager, and Loader for better performance
  - Optimized Class preprocessors
  - Optimized Array for better performance
  - Optimized Object for better performance
  - Optimized Base for better performance
  - Optimized Ext (core methods) for better performance
  - EventObject's pageX/pageY now performs its calculations only when needed
  - Remove unnecessary closure and callback from Model
  - Removed onpropertychange listener from the input before layout and restore it after, to prevent excessive firing due to attribute/style changes during layout. The was causing a large performance issue IE fields (~300% faster rendering, ~3000% faster resizing).
  - Fixed an issue in the detection of improper native array sorting (bugs in Chrome 5 and Safari 3) which caused the framework to always use a non-native sort. Resulting in a ~500% improvement when sorting (drastic improvement with large data sets such as those used in the BufferedGrid example)
  - Optimized XTemplate compilation to occur at render time
  - Fix an issue with framing templates not being put onto the prototype after compilation and being compiled for every component instance

- Enhancements
  - MVC examples added (feed viewer and nested data), new application architecture guide added
  - [EXTJSIV-661] Ported FeedViewer example to the new MVC structure
  - [EXTJSIV-72] Implemented PropertyGrid as Ext.grid.property.Grid and associated classes in Ext.grid.property
  - Replaced Javascript 'new' with Ext.create throughout library and examples
  - Added onClassExtended callback for the extend pre-processor
  - Update Model class to use onClassExtended and onAfterClass extended instead of postprocessors
  - [EXTJSIV-669] Reinstate the validateOnBlur config option for form fields
  - Added alternateClassName for Ext.form.action.Action
  - Added minor tick example for lines and minor ticks capability for chart axes
  - [EXTJSIV-407] Added basic drag and drop capabilities to sprites
  - [EXTJSIV-685] Added an 'uncheckedValue' config to Ext.form.Checkbox, which allows specifying a value to be submitted in the form when the checkbox is unchecked
  - [EXTJSIV-42] Added href/hrefTarget support for tree nodes
  - [EXTJSIV-644] Remove duplicate code in ElementLoader
  - [EXTJSIV-691] Lockable is now a mixin for any grid
  - Model can now be defined on the store prototype
  - [EXTJSIV-655] RowEditing will work with fields/editors that are object configs with no xtype specified (defaults to textfield), or straight xtype strings (wraps into an object config accordingly)
  - [EXTJSIV-175] Implement expandAll/collapseAll/selectPath/expandPath on tree
  - Cell editing now works with Trees
  - Implement configuration option to disable dblclick toggling on Tree nodes
  - Add standard Ext.Error class to handle error messages
  - [EXTJSIV-711] Add 'scrollToLoadBuffer' configuration to PagingScrollbar. This is the time in milliseconds to buffer load requests when scrolling the PagingScrollbar
  - Element getWidth and getHeight now allows the return of precise measurements (subpixel) for browsers which support subpixels
  - [EXTJSIV-646] Add getHeader method to Panel
  - [EXTJSIV-794] Fix tree destroy issue
  - Updated Ext.Version with extra value checking and docs
  - [EXTJSIV-791] Allow Component.setLoading method to accept a message String as its first argument
  - [EXTJSIV-708] Fix issue when showing tooltips on a scrolled document
  - [EXTJSIV-805] Fix up unstyled css prefix. Also move setting the baseCls before calling the superclass method
  - [EXTJSIV-803] HeaderContainer ColumnLayout fixes for resetting scrollLeft/scrollTop
  - Added beforeComponentLayout template method to Component
  - Ext.DomHelper insertHtml now supports TextNodes properly
  - [EXTJSIV-792] TabPanel will now activate the firstTab by default if no activeTab property is passed
  - [EXTJSIV-690] Set the default minButtonWidth for all Panels to 75 to match Ext3; made minButtonWidth apply as defaults for buttons added via 'fbar' and 'buttons' configs only; updated docs to make minButtonWidth clearer
  - [EXTJSIV-553] Make Header resizing work with flexed Headers, minWidth and forceFit
  - RowEditor is no longer a floating component managed by the zindex manager
  - Chart's factory method for axes is now implemented the same as the series factory method. In addition series and axis types are no longer case sensitive
  - [EXTJSIV-799] Create a processView method in axes that perform aggregation and filtering operations on stores to return a substore to be rendered by the axes
  - Move fadeIn, fadeOut, scale, shift, and pause back into Element. Mark methods for deprecation where appropriate
  - [EXTJSIV-357] Implement support for Drag and Drop of Headers between Locked and Unlocked sections in Grids and Trees
  - [EXTJSIV-844] Allow template to accept member functions/properties when passing an array
  - Add a static create method to Base.js so that you can do Class.create() on any class
  - [EXTJSIV-553] Group headers must have their minWidths synched when child headers are hidden or shown
  - Support inline data on Model definition
  - [EXTJSIV-814] Add setTitle methods to chart axes and series to allow changing titles programmatically
  - Support delayed binding of Stores to DataViews
  - [EXTJSIV-534] PagingScroller will now track the virtualScrollTop and is able to restore it when synchronizing views
  - TreePanel and GridPanel now relay events from their underlying View such as itemclick, itemcontextmenu, etc
  - [EXTJSIV-834] Ext.grid.feature.Grouping tracks expanded/collapsed state after refreshing the view
  - [EXTJSIV-866] Animations will default to 'px' if no units are specified for height, width, top, and left
  - [EXTJSIV-807] Add dynamic grouping to Stores
  - [EXTJSIV-827][EXTJSIV-861] VML now supports image type
  - [EXTJSIV-819] Fix double-margin bug in IE6 for items floated by Column layout
  - [EXTJSIV-793] Fix collapsed Panel still being visible in Accordion layout
  - [EXTJSIV-703] Fix Collapsible border layout not auto collapsing when focus
  - [EXTJSIV-877] Default column.Action to sortable: false
  - [EXTJSIV-174] Implemented getChecked on TreeView and TreePanel
  - [EXTJSIV-878] Fixed an issue when maximizing containers in an ownerCt
  - [EXTJSIV-848] Added a `decimals` option in the Numeric axis that will round to the specified decimals the values in the axis
  - [EXTJSIV-832][EXTJSIV-472] Buttons and tabs: add a span inside the button element to receive the icon styling; prevents the icon from shifting to the northwest when the button is in active state in IE. Other buttons/tabs CSS cleanup as required
  - [EXTJSIV-855] Automatically create an expanded root node if rootVisible is set to false and no root node has been defined
  - [EXTJSIV-816] Added an insert method on NodeInterface
  - [EXTJSIV-869] Added an onRegionTitleChange method to BorderLayout which will update the a header's text whenever a titlechange event is fired
  - [EXTJSIV-829] Support sending back expanded true in Node data. If no children are specified on that node, automatically load the node. Also fixed some bugs related to quickly expanding and collapsing
  - [EXTJSIV-728] Allow the tree to use a proxy as specified on the Model
  - [EXTJSIV-695] Add JsonP class and hook up ScriptTagProxy to use it
  - [EXTJSIV-873] Menu will not show itself if there are no items
  - [EXTJSIV-920] Ext.grid.feature.Grouping disabled configuration will now uncheck the grouping menu item
  - [EXTJSIV-928] Implement qtips on Tree Nodes. Change QuickTips to use the data-qtip attribute instead of ext:qtip. This allows DomQuery to target elements with qtips. This allows us to set qtips on any element on the page instead of just the front most elements
  - Added Ext.Base.borrow method to Borrow another class' members to the prototype of this class
  - [EXTJSIV-967] Remove layout.Manager and override the static create method on Ext.layout.Layout to be like a factory method for any type of layout
  - [EXTJSIV-875] Ext.JSON now supports a 'safe' mode

- API Changes
  - Aliased Ext.value to Ext.valueOf and deprecate the old one
  - isLoading method hoisted to AbstractStore so that it is available on TreeStore and Store
  - Rename DragDropMgr -> DragDropManager
  - Rename ModelMgr -> ModelManager
  - Rename TaskMgr -> TaskManager
  - Rename ComponentMgr -> ComponentManager
  - Rename PluginMgr -> PluginManager
  - Rename StoreMgr -> StoreManager
  - Rename FocusMgr -> FocusManager
  - Rename WindowMgr -> WindowManager
  - Rename themeMgr -> themeManager
  - Rename ButtonToggleMgr -> ButtonToggleManager
  - Rename Ext.menu.MenuMgr -> Ext.menu.manager
  - Remove ReaderMgr
  - Remove WriterMgr
  - In all documentation and examples, Ext.define is now used to define Models, not Ext.regModel
  - Move field implementation classes into Ext.form.field.* namespace
  - Animate mixin's hasActiveFx renamed to getActiveAnimation and stopFx renamed to stopAnimation
  - Removed 'tip' and 'quicktip' xtypes as they should not be added as widgets. QuickTipManager is a singleton. and 'tooltip' is a widget
  - Replaced all superclass syntax with callParent where possible throughout library and examples
  - [EXTJSIV-853] Rename ToolTip initTarget to setTarget
  - Ext.data.JsonReader -> Ext.data.reader.Json
  - Ext.data.ArrayReader -> Ext.data.reader.Array
  - Ext.data.Reader -> Ext.data.reader.Reader
  - Ext.data.XmlReader -> Ext.data.reader.Xml
  - Ext.data.AjaxProxy -> Ext.data.proxy.Ajax
  - Ext.data.ClientProxy -> Ext.data.proxy.Client
  - Ext.data.DirectProxy -> Ext.data.proxy.Direct
  - Ext.data.LocalStorageProxy -> Ext.data.proxy.LocalStorage
  - Ext.data.RestProxy -> Ext.data.proxy.Rest
  - Ext.data.ScriptTagProxy -> Ext.data.proxy.ScriptTag
  - Ext.data.ServerProxy -> Ext.data.proxy.Server
  - Ext.data.SessionStorageProxy -> Ext.data.proxy.SessionStorage
  - Ext.data.WebStorageProxy -> Ext.data.proxy.WebStorage
  - Ext.data.XmlWriter -> Ext.data.writer.Xml
  - Ext.data.Writer -> Ext.data.writer.Writer
  - Ext.chart.Callouts -> Ext.chart.Callout
  - Ext.chart.Labels -> Ext.chart.Label
  - Ext.chart.Highlights -> Ext.chart.Highlight
  - Ext.chart.Tips -> Ext.chart.Tip
  - Ext.chart.Shapes -> Ext.chart.Shape
  - Ext.data.Proxy -> Ext.data.proxy.Proxy
  - Ext.draw.SpriteGroup -> Ext.draw.SpriteComposite
  - Ext.fx.PropHandler -> Ext.fx.PropertyHandler
  - Ext.fx.target.SpriteGroup -> Ext.fx.target.CompositeSprite
  - Ext.data.proxy.ScriptTag -> Ext.data.proxy.JsonP
  - Ext.grid.HeaderContainer -> Ext.grid.header.Container
  - Ext.grid.HeaderDragZone -> Ext.grid.header.DragZone
  - Ext.grid.HeaderDropZone -> Ext.grid.header.DropZone
  - Ext.grid.HeaderReorderer -> Ext.grid.header.Reorderer
  - Ext.grid.GridPanel -> Ext.grid.Panel
  - Ext.menu.DateMenu -> Ext.menu.DatePicker
  - Ext.menu.ColorMenu -> Ext.menu.ColorPicker
  - Ext.menu.MenuManager -> Ext.menu.Manager
  - Ext.panel.TablePanel -> Ext.panel.Table
  - Ext.resizer.ResizeHandle -> Ext.resizer.Handle
  - Ext.grid.CellEditing -> Ext.grid.plugin.CellEditing
  - Ext.grid.Editing -> Ext.grid.plugin.Editing
  - Ext.grid.GridView -> Ext.grid.View
  - Ext.grid.GridViewDropZone -> Ext.grid.ViewDropZone
  - Ext.grid.GridPanel -> Ext.grid.Panel
  - Ext.grid.RowEditing -> Ext.grid.plugin.RowEditing
  - Ext.grid.HeaderReorderer -> Ext.grid.plugin.HeaderReorderer
  - Ext.grid.HeaderResizer -> Ext.grid.plugin.HeaderResizer
  - Ext.grid.GridViewDragDrop -> Ext.grid.plugin.DragDrop
  - Ext.ImageComponent -> Ext.Img
  - Ext.layout.Container -> Ext.layout.container.Container
  - Ext.layout.AbstractContainer -> Ext.layout.container.AbstractContainer
  - Ext.layout.Component -> Ext.layout.component.Component
  - Ext.layout.component.SliderField -> Ext.layout.component.field.Slider
  - Ext.layout.component.form.Field -> Ext.layout.component.field.Field
  - Ext.layout.component.form.File -> Ext.layout.component.field.File
  - Ext.layout.component.form.HtmlEditor -> Ext.layout.component.field.HtmlEditor
  - Ext.layout.component.form.Text -> Ext.layout.component.field.Text
  - Ext.layout.component.form.TextArea -> Ext.layout.component.field.TextArea
  - Ext.layout.component.form.Trigger -> Ext.layout.component.field.Trigger
  - Ext.tip.QuickTips -> Ext.tip.QuickTipManager
  - Ext.toolbar.PagingToolbar -> Ext.toolbar.Paging
  - Ext.tree.SelectionModel -> Ext.selection.TreeModel
  - Ext.tree.TreeColumn -> Ext.tree.Column
  - Ext.tree.TreePanel -> Ext.tree.Panel
  - Ext.tree.TreeView -> Ext.tree.View
  - Ext.tree.TreeViewDragZone -> Ext.tree.ViewDragZone
  - Ext.tree.TreeViewDropZone -> Ext.tree.ViewDropZone
  - Ext.view.TableView -> Ext.view.Table
  - Ext.Container.getIndexOfHeader -> Ext.Container.getHeaderIndex
  - Ext.Container.getHeaderByIndex -> Ext.Contrainer.getHeaderAtIndex
  - Ext,grid.feature.Feature.getTplFragments -> Ext.grid.feature.Feature.getFragmentTpl
  - Ext.grid.feature.Grouping.getTplFragments -> Ext.grid.feature.Grouping.getFragmentTpl
  - Ext,grid.feature.GroupingSummary.getTplFragments -> Ext.grid.feature.GroupingSummary.getFragmentTpl
  - Ext,grid.feature.Summary.getTplFragments -> Ext.grid.feature.Summary.getFragmentTpl
  - Ext,grid.header.Container.getTplFragments -> Ext.grid.header.Container.getFragmentTpl
  - Ext.layout.container.Border.getPlaceHolder -> Ext.layout.container.Border.getPlaceholder
  - Ext.version.getSimplified -> Ext.version.getShortVersion
  - Ext.version.simplified -> Ext.version.shortVersion
  - Ext.Object.keyOf -> Ext.Object.getKey
  - Ext.String.parseQueryString -> Ext.Object.fromQueryString
  - Ext.Version.isSmallerThan -> Ext.Version.isLessThan
  - Ext.draw.Surface.newInstance -> Ext.draw.Surface.create
  - Ext.util.Inflector.isUncountable -> Ext.util.Inflector.isTransnumeral
  - Ext.draw.Surface.positionSpriteInList -> Ext.draw.Surface.normalizeSpriteCollection
  - Ext.util.AbstractMixedCollection.removeByKey -> Ext.util.AbstractMixedCollection.removeAtKey
  - Ext.util.HashMap.removeByKey -> Ext.util.HashMap.RemoveAtKey
  - Ext.FocusManager.removeWhitelistXType -> Ext.FocusManager.removeWhitelistByXType
  - Ext.data.Connection.setupOptions -> Ext.data.Connection.setOptions
  - Ext.FocusManager.removeWhitelistXType -> Ext.FocusManager.removeXTypeFromWhitelist
  - Ext.FocusManager.addWhitelistXtype -> Ext.FocusManager.addXTypeToWhitelist
  - Ext.form.Labelable.applyFieldDefaults -> Ext.form.Lableable.setFieldDefaults
  - Ext.form.field.areValuesEqual -> Ext.form.field.isEqual
  - Ext.ClassManager.assignNamespace -> Ext.ClassManager.setNamespace
  - Ext.menu.Menu.canActivateItem -> Ext.menu.Menu.isActivatable
  - Ext.form.Panel.checkChanges -> Ext.form.Panel.checkChange
  - Ext.form.Basic.checkDirtyChange -> Ext.form.Basic.checkDirty
  - Ext.form.FormPanel -> Ext.form.Panel
  - Ext.chart.LegendItem.createSprites -> Ext.chart.LegendItem.createLegend
  - Ext.chart.axis.Axis.drawLabels -> Ext.chart.axis.Axis.drawLabel
  - Ext.Loader.exist -> Ext.Loader.isCreated
  - Ext.grid.header.Container.getColumnsMenu -> Ext.grid.header.Container.getColumnMenu
  - Ext.form.field.File.buttonCfg -> Ext.form.field.File.buttonConfig
  - Ext.data.proxy.Server.dirParam -> Ext.data.proxy.Server.directionParam
  - Ext.grid.feature.Grouping.groupHdTpl -> Ext.grid.feature.Grouping.groupHeaderTpl
  - Ext.draw.Surface.implOrder -> Ext.draw.Surface.enginePriority
  - Ext.draw.Component.implOrder -> Ext.draw.Component.enginePriority
  - Ext.charts.Series.markerCfg -> Ext.chart.Series.markerConfig
  - FocusManager.placeHolder -> FocusManager.placeholder
  - Panel.placeHolder -> Panel.placeholder
  - Border.placeHolder -> Border.placeholder
  - Ext.chart.series.Bar.xpadding -> Ext.chart.series.Bar.xPadding
  - Ext.chart.series.Bar.ypadding -> Ext.chart.series.Bar.yPadding

- Documentation Changes
  - Added many guides, screenshots, and videos from the Sencha Blog and other sources to the documentation application
  - API documentation screenshots and example updates for (Ext.window.Window, Ext.window.MessageBox, Ext.toolbar.Toolbar, Ext.toolbar.TextItem, Ext.toolbar.Spacer, Ext.toolbar.Separator, Ext.toolbar.Fill, Ext.tab.Panel, Ext.slider.Tip, Ext.slider.Single,Ext.slider.Multi, Ext.resizer.Resizer, Ext.layout.container.Table, Ext.layout.container.Fit, Ext.layout.container.Column, Ext.layout.container.Card, Ext.layout.container.Border, Ext.layout.container.Accordion, Ext.layout.container.Absolute, Ext.form.FormPanel, Ext.form.BaseField, Ext.form.Checkbox, Ext.form.CheckboxGroup, Ext.form.ComboBox, Ext.form.Date, Ext.form.Display, Ext.form.FieldContainer, Ext.form.FieldSet, Ext.form.File, Ext.form.FormPanel, Ext.form.HtmlEditor, Ext.form.Label, Ext.form.Number, Ext.form.Radio, Ext.form.RadioGroup, Ext.form.Text, Ext.form.TextArea, Ext.form.Time
  - Updated AbstractComponent
  - [EXTJSIV-806] Updated AbstractDataView
  - Updated AbstractMixedCollection
  - Updated AbstractPanel
  - Added Application
  - Updated Array
  - Update Axis
  - Update Base
  - Update Cartesian
  - [EXTJSIV-748] Add CellEditing
  - Update Chart Labels
  - Update Chart LineSeries
  - Update Class
  - Update ClassManager
  - Added Controller
  - Update Direct
  - [EXTJSIV-721] Update Direct proxy
  - [EXTJSIV-734] Add DrawComponent
  - Update Ext
  - Added EventBus
  - Added Gauge Chart
  - Added Grid Panel
  - Added Grid Scroller
  - [EXTJSIV-644] Updated Loader
  - [EXTJSIV-723] Update NodeInterface
  - Updated Object
  - Updated Observable
  - Added PropertyGrid
  - Updated field.Number
  - [EXTJSIV-754] Add RowEditing
  - Added RowNumberer
  - Added Sortable
  - Added Sprite
  - [EXTJSIV-726] Add Tree
  - [EXTJSIV-727] Update TreeStore

- Known Issues / Upcoming Changes
  - Desktop Example to be re-implemented
  - Ext.data.BufferStore will be removed and its methods moved up into Ext.data.Store
  - Grid promote from markup script sometimes fails in IE6 and IE7
  - TreePanel has some DnD issues in IE9
  - Several classes missing adequate documentation
  - Small rendering glitches on tabs in Mac Safari 5
  - Buttons can be cropped when sizing a Window to a very small width (e.g. under 150px)
  - Grids can sometimes lose scrollbars when their container is resized
  - Vertical panel headers use the wrong font in IE9
  - Grid state does not save column widths
  - TriggerFields are not aligned flushed to the edge in IE6 and IE7
  - Grid filtering feature doesn't support setting filters via config
  - TreePanel is missing documentation. A guide will be release separately before GA
  - Menu styling in access theme has some imperfections
  - Simple Tasks example is missing
  - Calendar components have not been fully ported yet
  - Tree Filtering will be implemented before GA
  - KeyNav example has inconsistent spacing in some IE versions
  - Tab is not marked selected if it is the only tab in a TabPanel and is set active by default
  - Hovering over the bottom spinner of a NumberField does not highlight it
  - Several small IE9 rendering issues
  - Some slight font inconsistencies between components

# Release Notes for Ext JS 4 Beta 2

Release Date: April 6, 2011
Version Number: 4.0.0beta2

## New In This Release

- New Examples
  - Gauge Chart example
  - Buffered Grid example
  - Theme example

- Bug Fixes
  - Fix tabs mouseover in GroupTabPanel examples
  - Fix double rendering when quickly expanding / collapsing tree nodes
  - [EXTJSIV-466] Ensure cls config is applied to MessageBoxWindow
  - Fix issue where box layout margins could be improperly calculated
  - [EXTJSIV-470] Remove the permanent CheckHeader editor and place it only on the row editing example
  - Fix Tree keyboard navigation
  - Don't show loading indicator when trying to expand an already expanded tree node
  - [EXTJSIV-504] Fix alignment of fieldset legend checkbox
  - [EXTJSIV-502] Remove persistent scrollbar from Ext.form.Textarea and Ext.form.HtmlEditor source editor
  - [EXTJSIV-213] Fix BoxReorderer issues
  - [EXTJSIV-537] Fix an issue that allows multiple selection on the chart
  - [EXTJSIV-529] Element.highlight() fx function will now function properly, and can handle Anim callbacks
  - [EXTJSIV-539] We no longer allow the tb text field to be orderable in the multisort example
  - [EXTJSIV-540] Buttons will no longer show mouseover effects when disabled
  - [EXTJSIV-545] Fix duplicate id bug in grid -> grid DD example
  - [EXTJSIV-417] Fixed issue with field heights
  - [EXTJSIV-492] Fix application of overCls when the delegate option is used
  - [EXTJSIV-513] Ensure that mouseup when dragging the drag selector, and the subsequent click event does not clear selections in the DataView
  - [EXTJSIV-474] Fix ghosting of Windows during drag on IE < 9
  - [EXTJSIV-213] Fix multiple-sorting issue with BoxReorderer, ensure smooth component reordering, Improve reorderable-tabs examples
  - [EXTJSIV-501] Fix the ability to update floating Components while hidden, and have them run their ComponentLayout upon show
  - [EXTJSIV-530] Fixed bootstrap-release.js to test window.location.hostname instead of window.location.host
  - [EXTJSIV-540] Always attempt to remove the overCls when the mouse leaves the component. If a component is disabled while the mouse is still over it, then the overCls will be stuck on until the component is re-enabled
  - Grid DD Example update so columns aren't crammed together
  - [EXTJSIV-531] Fix MessageBox progress bar display
  - [EXTJSIV-434] Prevent IE6-7 from giving focus to the HtmlEditor iframe when setting its contentEditable=true
  - [EXTJSIV-464] Menu should pass its minWidth down to its child components so it is accounted for in the Box layout. This visually affects all examples that use menus which were only as wide as they needed to be
  - [EXTJSIV-138] Fix no borders on forum search example
  - Fixed column headers in IE
  - [EXTJSIV-561] Fix an issue when creating a tab panel with no items
  - Fix Loader's path resolution
  - [EXTJSIV-557] Locking grid resize indicator shows up regardless of which section you drag from
  - [EXTJSIV-507] Fix gecko3 issue with the first tab in a tabbar
  - [EXTJSIV-356] Prevent selection from scrolling into view when the selection model is refreshed
  - [EXTJSIV-568] RowEditor disables the view's keynav so that editors will get full default key events
  - [EXTJSIV-339] Fixed problematic curly braces in nestedIdRe in AbstractSummaryFeature
  - [EXTJSIV-375] Complete syncing of row heights, after sorting make sure that the scrollTop is synchronized
  - Correct syncRowHeight default config
  - [EXTJSIV-568] Don't allow RowEditor to hijack space
  - [EXTJSIV-409] Add extra path parameter to ensure cookie clearing works
  - [EXTJSIV-7] Fixed shift that appears in IE with large number scaling when you specify viewPort in a Draw Component
  - [EXTJSIV-558] Fixed an issue where setting a date in a model caused the record to become dirty
  - [EXTJSIV-575] Fix Uncaught TypeError: Cannot call method 'apply' of undefined, due to previous onDisable/onEnable changes
  - [EXTJSIV-449] TableView should not steal the focus when a header is resized. The header layouts occurred when a scrollbar was being added and removed by the TablePanel, causing any previously focused item to lose focus, with focusing going to the TableView. So, a "search filter text box", for example, would lose focus at random points
  - [EXTJSIV-167] Fix IE9 Center Layout
  - Fix Ext.form.Combobox select event firing
  - [EXTJSIV-546] Dont allow a parent folder to be dropped on a folder inside itself
  - [EXTJSIV-524] Make sure you can extend Ext.TreePanel and create an instance without passing a configuration
  - Properly relay View events on the TreePanel
  - [EXTJSIV-190] Fix Ext.ux.TabCloseMenu event monitoring
  - [EXTJSIV-535] Fix Multi sorting grid column reorder indicator
  - [EXTJSIV-537] Fix issue where FormDashboard allows multiple chart selection
  - [EXTJSIV-162] Fix TableView/Features collectData implementation
  - [EXTJSIV-544] Fix Bar display when data is of the same value for more than one record
  - [EXTJSIV-515] Clear groupers when disabling the Grouping Feature
  - [EXTJSIV-565] Fix radial axis labels problem
  - [EXTJSIV-469] Correct layout recursion back into an already-running ComponentLayout
  - [EXTJSIV-565] Fix maxValue in drawSeries
  - [EXTJSIV-590] The PagingScroller now calculates rowHeight based off of markup
  - [EXTJSIV-241] Fix bug in event wrapper ordering which meant that delayed or buffered single:true events threw errors
  - [EXTJSIV-583] Fix sorting padding issue with grid headers
  - [EXTJSIV-510] Added grid headers and special cell backgrounds
  - [EXTJSIV-597] Fix issue where Ext.tab.Panel wouldn't enable tabs
  - [EXTJSIV-588] Fix an issue when using scripts: true when loading a component
  - [EXTJSIV-321] Record associated data now also handles parent models
  - [EXTJSIV-566] Fix issues with returning exceptions from DirectProxy
  - [EXTJSIV-585] Fix an issue where Ext.MessgaeBox was dependent on having a title
  - [EXTJSIV-586] Fix an issue when using reset and formBind, the bound item will now be updated correctly
  - [EXTJSIV-591] Fix warning when destroying border layout
  - Fix detection of changes to form fields in IE9 standards mode by making it use the modern events set
  - Fix vertical alignment of checkbox/radio buttons in IE9 standards mode
  - Fix errors when expand/collapse methods are called after a Picker component is destroyed
  - [EXTJSIV-605] Fix an issue where undefined will be set on the editor when resetting
  - [EXTJSIV-569] Fix bug with nodes being inserted in the wrong location in the NodeStore
  - [EXTJSIV-607] Fix z-index of border floated region
  - [EXTJSIV-372] Fix an issue with flickering when using cell editing in FF on Linux
  - [EXTJSIV-608] Fix issue when creating records at a remote source
  - [EXTJSIV-450] FocusManager will only add tabIndex to DOM nodes that really need them for programmatic focusing. This will ensure default tabIndicies will remain in tact
  - [EXTJSIV-589] CellEditing now fires beforeedit, validateedit and afteredit appropriately
  - [EXTJSIV-610] CellModel will now call its base Model's doSelect and doDeselect functions so it is maintaining the selected record along with the selected position (row/column)
  - [EXTJSIV-418] CheckColumn now will handle the Enter/Space keys for toggling its select state
  - [EXTJSIV-609] CellModel fires its select/deselect events now
  - [EXTJSIV-560] Remove focused cls on items in a TableView when deselecting them
  - [EXTJSIV-614] Prevent combobox dropdown from getting closed before the selectOnTab handler has a chance to fire in WebKit
  - [EXTJSIV-622] When IE9 positions an element offscreen via offsets, the offsetWidth is inaccurately reported. For IE9 only, we render on screen before removing. Fixes an issue with Ext.getScrollBarWidth
  - [EXTJSIV-439] Changed images for the DataView examples to gif for IE6
  - [EXTJSIV-615] Fix an issue when using an idProperty other than "id"
  - RowEditor will handle resize, move, show, and hide of columns properly before the editor is brought up for the first time
  - [EXTJSIV-480] Table layout: added work around for a bug in Opera 10.5 where it makes table cells wider than they should be if their child element has border-box sizing and horizontal padding
  - [EXTJSIV-641] Fix an issue with creating items into a local storage object
  - [EXTJSIV-440][EXTJSIV-633] Fix Ext.ux.AnimatedDataView cross-browser issue
  - CellEditing will complete an edit before grabbing critical information about the next edit, since the view is refreshed upon edit completion
  - [EXTJSIV-371] CellEditing and CellModel will continue cell editing on tabs even across cells with no editor, and stop when the editing ends via a non-tab exit point such as blurring the field
  - [EXTJSIV-606] Constrained Windows no longer lose their center positioning
  - [EXTJSIV-508] Give a visual indication of a selected/focused tree node in the check-tree example
  - [EXTJSIV-508] Tree selection model handles enter/space to check any checkbox tree nodes
  - [EXTJSIV-663] Ensure ServerProxy checks if the value is defined as opposed to just truthy
  - [EXTJSIV-593] Numeric axis is now aware of chart substores, that way it can update when grouping/ungrouping time axis
  - [EXTJSIV-401][EXTJSIV-496] Rework active/inactive tab styling to be consistent across all browsers and avoid the floating border strip
- Enhancements
  - [EXTJSIV-73] Optimized class system performance - round 1
  - Added a simple Gauge Chart
  - Add Ext.Array.sort which is a guaranteed stable sort
  - [EXTJSIV-556] Implement a buffered grid example loading thousands records and buffering the rendering. Required minor changes to PagingScroller, BufferStore and related classes
  - [EXTJSIV-193] Put iconCls and tools into ghosted windows
  - [EXTJSIV-471] RowEditing will now scroll the buttons into view when they are out of sight due to being near the bottom. Also will enforce row selection and keeping a row in view when starting an edit for smoother animations
  - [EXTJSIV-426] Remove redundant validation for allowBlank in Ext.form.Text
  - [EXTJSIV-427] Date and Time would always return null from getValue if the raw value could not be parsed as a date; this was resulting in such values being treated as valid during validation and not being seen as dirty. Changed so that getValue will return the raw value if it cannot be parsed. Also added logic to attempt parsing of the 'value' config during init so that originalValue is a valid Date object for dirty comparison
  - [EXTJSIV-448] Implement readOnly and setReadOnly for Checkbox and Radio fields
  - [EXTJSIV-416] Give fields within fieldset an anchor so they get a width in IE6
  - [EXTJSIV-530] Added port number support to localhost detection
  - Add required classes to Chart LiveUpdate example
  - Increase LiveSearchGridPanel reactiveness
  - [EXTJSIV-529] Element.getColor() will properly accept an empty string as a prefix, which is needed for color animations
  - [EXTJSIV-529] Enable afterRepair fx on dd.DragZone and TreeViewDragZone
  - [EXTJSIV-38] TreeViewDropZone will now highlight successfully dropped nodes
  - [EXTJSIV-38] Use the selectedItemCls setting on TableView prototype to handle the quick remove/add of that cls when highlighting a repair
  - [EXTJSIV-38] TreeViewDragZone will highlight all records that were dragged, for the case of multiselect tree sel model
  - [EXTJSIV-185] Removed .png slicer images + changing to gif (we <3 IE6)
  - [EXTJSIV-346] adding gif versions of icons for treegrid example
  - [EXTJSIV-475] LoadMask may now be configured with a Component to mask as an alternative to just an element. If configured with a Component, it masks the Component's contentTarget. If the Component changes size during loading, the mask's message is recentered. DataView configures its LoadMask by passing itself if it is standalone, or its owning Container if it is inside a Container
  - [EXTJSIV-478] Added the empty cls to all browsers, not just browsers that do not support `placeholder`. this is because of a styling issue in webkit
  - [EXTJSIV-540] Button over when disabled will not apply the hover background linear gradient anymore. disabled classes now get cascaded priority over background-image
  - [EXTJSIV-457] The DragZone was triggering a selection change on mousedown, which was resulting in duplicate selection calls when the DataView was configured to select on click. Moved the former from the mousedown handler to the start of the drag to avoid duplicate selection
  - Improved some Loader's alias functions for performance
  - [EXTJSIV-258][EXTJSIV-259]Refactor Shadow for floating Components
  - [EXTJSIV-551] Menu should not fire click, mouseover, or mouseleave events when its disabled. Menu items will not get any interaction when the menu is disabled
  - Menu will only activate items that can be activated, however, always deactivate the active item when applicable
  - [EXTJSIV-502] Add comment in HtmlEditor explaining how forcing documentMode in the Web Developer Tools will override the mode used by the iframe, causing scrollbars in IE8
  - [EXTJSIV-543] Horizontal scrolling does not rely on having records within the body of the grid. It is calculated off of the headercontainer instead
  - [EXTJSIV-547] Added in browser check for Opera for Mousewheel. Found additional information about Opera and its' mousewheel implementation here: http://www.switchonthecode.com/tutorials/javascript-tutorial-the-scroll-wheel To quote the important parts... "The weirdness comes in because IE and Firefox have very different names for the scroll event. In Internet Explorer, the event is called onmousewheel, while in Firefox the event is called DOMMouseScroll. To make it even worse, Opera uses the Internet Explorer event name (without the 'on' part, so just mousewheel), but Opera needs to use the Firefox way of attaching event listeners."
  - [EXTJSIV-564] Implement index support in selectRange rather than requiring the developer to pass a record instance
  - Updated grid row selection stuff to support IE better
  - [EXTJSIV-447] Add fieldStyle config and setFieldStyle method to Ext.form.BaseField, to allow direct manipulation of the inputEl CSS style
  - Legacy code in the widgets directory removed
  - RowEditor offsets itself by using bottom instead of top, in case of tall rows
  - [EXTJSIV-567] Table State implementation now restores width and visibility
  - [EXTJSIV-532] Add tooltip support on Radar series
  - [EXTJSIV-559][EXTJSIV-373]Provide accurate repair position for Header Drag Zones
  - [EXTJSIV-358] HeaderContainer will disable checkbox in column menu when there is only a single header
  - [EXTJSIV-582] Add Ext.Error custom error reporting class
  - [EXTJSIV-574] Add an alias for all series and handle custom series creation and adding them in an imperative way
  - [EXTJSIV-514] Reimplement rendering of Checkbox and Radio to use a custom image rather than native controls, for greater styling control and consistency across browsers
  - [EXTJSIV-241] Lots of cleanup on Component destroy method
  - [EXTJSIV-599] Make node loaded a field in NodeInterface. When appending a child to a node, mark it as loaded
  - Add the ability to pass a url to the load method on a Store with a ServerProxy defined on it
  - [EXTJSIV-394] Added itemTpl support for DataView
  - Add method to allow destroying the field layout's singleton QuickTip instance
  - [EXTJSIV-604] Allow height to be set on text fields
  - The footer toolbar's (fbar/buttons cfg) spacer shouldn't be focusable anymore
  - Button now has a visual state when focused, which currently mirrors the mouseover state. Also removed a focus/blur method in Button that was unnecessary
  - [EXTJSIV-450] FormPanel will provide default tab stops for its fields and buttons, so that all fields are tabbed through first, and then buttons second
  - [EXTJSIV-450] AbstractPanel and AbstractDock will return/render docked items in their visual representative order, respectively. Docked items have a default weighting, so that they are returned/rendered in (t,l,r,b) order. In the case of a Dock layout, the top/left items are rendered before any existing DOM nodes in the render target (body el, in the case of a Panel), and right/bottom items are rendered after the existing DOM nodes. This keeps our DOM nodes in order of their visual representation to support tab stops, ARIA readers, etc. Also, getDockedItems/getRefItems of AbstractPanel will return the same type of ordering by default to support logical ordering of ComponentQuery's and FocusManager navigation
  - Move FocusManager's tabIndex whitelist to the prototype so it's not defined over and over again for each call to setFocus
  - [EXTJSIV-418] Added keydown event handling to DataView
  - [EXTJSIV-600] Allow form fields to display all errors returned from getErrors at once, rather than only displaying the first
  - [EXTJSIV-304] Grid reconfigure method implemented
  - [EXTJSIV-498] Changed DataView to store the internal record IDs on the view DOM nodes for lookup by record and vice versa. This matters since blockRefresh's can happen and the store becomes out of sync with the DOM nodes, such as was the case with the Animated DataView plugin
  - [EXTJSIV-483] Implement expanded cls for rows inside collectData instead of getRowClass. This allows the user to override getRowClass without them having to worry about expanded state
  - [EXTJSIV-628] Added remove and destroy methods in Sprite.
  - [EXTJSIV-55] Add boxLabelAlign config to allow the user to place the boxLabel before or after the checkbox/radio
  - [EXTJSIV-517] Optimized buffering of requests in PagingScroller
  - [EXTJSIV-596] border:false on a Window removes borders from the body. The Window itself remains framed
  - [EXTJSIV-523] Use the verticalScrollers calculated height when available rather than the raw dom
  - [EXTJSIV-315] Updated access theme to have better styling across all components
  - [EXTJSIV-613] Move extraParams onto the object instead of being per request
  - RowEditor now transitions the error summary tip properly on back-to-back invalid records
  - Remove the inline unselectable cls, and instead call unselectable() on the table view's el after it's been rendered. This fixes a selection problem in Chrome when double clicking in a grid
  - [EXTJSIV-527] Add a workaround for the WebKit MarginRight bug with Anchor Layouts to make them much faster
  - [EXTJSIV-527] Componentlayout.afterLayout will now only be called when a ComponentLayout occurs
  - [EXTJSIV-527] Ensure Card.setActiveItem calls onLayout properly
  - Moved all locking behavior out of the LockingGridPanel subclass
  - [EXTJSIV-660] Add startDay to Date Field
  - [EXTJSIV-653] Added DirectStore shortcut
- API Changes
  - [EXTJSIV-276] The "headers" config in GridPanel has been renamed to the 3.x compatible "columns". All supporting classes are now named XxxxxColumn and are in the Ext.grid.column package. Column xtypes are the same as they were in 3.x
  - [EXTJSIV-562] Added hideEmptyLabel config which automatically collapses the label space when fieldLabel is empty. Made this the default behavior everywhere; this is a slight change from the old form layout which defaulted to maintaining the space unless hideLabel=false
  - [EXTJSIV-59] Rename some methods in Menu to be consistent with framework standards
  - Modified field layout to avoid setting styles when not needed. The fieldLabel element's styles are now applied during render in the template and not in the layout. Fields whose size are not managed by a container no longer set their internal element sizes during layout this can result in wrapping since fields are floated
  - Add inverse iteration support to Ext.Array.each
  - Rename hlColor to repairHighlightColor for Tree DragSource
  - [EXTJSIV-38] TreeViewDDPlugin now has "nodeHighlightColor" which is used on repairs and drops, if applicable. Passing it as the "repairHighlightColor" to the drag zone in this commit. Will be passed to drop zone as "dropHighlightColor"
  - [EXTJSIV-38] Renamed hlDrop to nodeHighlightOnDrop and nodeHighlightOnRepair on the TreeViewDDPlugin class. They are routed to the TreeViewDragZone and TreeViewDropZone as repairHighlight and dropHighlight respectively
  - [EXTJSIV-552] Rename MessageBoxWindow to MessageBox
  - Move all locales package from core to extjs
  - [EXTJSIV-548] Add allowDrag config option on NodeInterface. Set it to false by default for root nodes
  - [EXTJSIV-549] Change the names for the relayed events from TreeStore to TreePanel so that they don't collide with Panel's events
  - [EXTJSIV-602] Put GridViewDDPlugin and TreeViewDDPlugin into proper namespaces (Ext.grid.plugin)
  - [EXTJSIV-269] Renamed enableCacheBuster to disableCaching, added disableCachingParam config
  - [EXTJSIV-581] Fixed up the API for TreeStore, TreeView and TreePanel. Also fixed some bugs related to changing the root node dynamically, loading data after TreePanel has already been created and expanding a node while its loading
  - [EXTJSIV-598] We no longer use the global QuickTips singleton for form error tips. We now create a QuickTip singleton just for the field layout, with the proper baseCls for framing, and register it to respond to an 'errorqtip' property
  - [EXTJSIV-534] Refactor Lockable into mixin
  - AbstractSummaryFeature, ChunkingFeature, GroupingFeature, RowSummaryFeature, RowBodyFeature, RowWrapFeature, and SummaryFeature moved to the Ext.grid.feature namespace
  - Rename locked from Header/Column to ddLock so that it doesnt conflict with the new locking functionality
- Compatibility Changes
  - Removed compat reversing of El.down/El.child - There are too many places in Ext itself that use these calls, and reversing them in the compat layer to match 3.x behavior breaks some Ext 4 code. This will have to remain a documented breaking change in the migration guide
  - Set up compat code for TreePanel, AsyncTreeNode, TreeLoader and TreeSorter
  - Moved deprecated TreePanel members to the compat file
- Documentation Changes
  - Guide section added to documentation. Class System and Drawing/Charting Guides added
  - File field updated
  - Model.fields updated
  - Component updated
  - FocusManager updated
  - Viewport updated
  - FormPanel updated
  - ActionHeader updated
  - GridViewDDPlugin updated
  - ColumnLayout updated
  - DateMenu updated
  - Panel updated
  - TabPanel updated
  - TreeViewDDPlugin updated
  - Animate updated
  - ClassLoader updated
  - Animator updated
  - BsicForm updated
  - Label field updated
  - Labelable updated
  - Text field updated
  - ElementLoader updated
  - Sortable updated
  - AbstractComponent updated
  - Locales updated
  - Ext.Number updated
  - Tab updated
  - TabPanel updated
  - StateProvider updated
  - Editing updated
  - Panel updated
  - CheckboxModel (selection) updated
  - TreePanel updated
  - Ext updated
  - Class updated
  - ClassManager updated
  - Array updated
  - Anim updated
  - FieldSet updated
  - Grid Column updated
  - Application updated
  - Controller updated
  - ControllerManager updated
  - ModelManager updated
  - Router updated
  - BufferStore updated
  - JSON Writer updated
  - Charts updated
  - DrawComponent updated
  - Toolbar updated
  - DataView updated
  - Floating updated
  - Resizer updated
  - Store updated
  - ComponentDragger updated
- Known Issues / Upcoming Changes
  - MVC Example applications and guide
  - Collapsed vertical headers need to be restyled in IE
  - Toolips in IE8 have too much padding on the header which can cause it to clip text
  - Tab Scroller is not working properly in FF < 4
  - GridFilter example is not laying out properly on first render
  - Deprecated (methods slated for deprecation) and Since (what version methods were introduced) implemented within the documentation
  - Column Layout has some performance issues which will be addressed in the next release
  - API naming consistency implementation
  - Field Layout performance has improved, but is not where it should be for IE
  - IE9 Strict mode subpixel rounding can cause wrapping issues (similar to https://bugzilla.mozilla.org/show_bug.cgi?id=458617)

# Release Notes for Ext JS 4 Beta 1

Release Date: March 30, 2011
Version Number: 4.0.0beta1

## New In This Release

- New Examples
  - Spotlight example
  - Ext.Direct Grid Integration
  - Binding a Grid to a Form
  - Grid Cell Editing
  - Grid Grouping
  - Grid Grouping with Summaries
  - Grid 'Infinite' Scrolling
  - Live Search Grid
  - Grid Locking
  - Grid Remote Group Summary
  - Grid Row Editing
  - Column Layout
  - Actions
  - Overflow Tabs to a Menu
  - Tree with CheckBox selection
  - Drag and Drop between Trees
  - Animated DataView
  - MultiSort DataView
  - Locally Filtered Grid
  - RESTful Store with GridPanel and RowEditor
  - Localization (static)
  - Localization (dynamic)
  - Browser State
  - Data.writer
- Bug Fixes
  - Fixed an issue where menu items would not respect the cls property
  - Fixed improper variable in RemotingProvider
  - Fixed param logic in DirectProxy
  - Fixed an issue when reloading stores with different data sets
  - Added a finite check for a DrawComponent's bounding box
  - Pass the correct parameter to ServerProxy.afterRequest
  - Fix indexOf reference in ListMenu
  - When a date is chosen for a date filter, hide its parent menu
  - Add autocomplete="off" to Button template to prevent Firefox from remembering its disabled state between page reloads
  - Prevent NumericFilter's menu fields from getting focused when mousing over them
  - Fix form submission when using direct
  - Fixed an issue where phantom records were being duplicated in the store when returned from a remote data source
  - Fixed an issue when clearing a client data proxy
  - Fixed Model dependencies
  - Removed redundant requires in Component
  - Fix to make sure initExtCss always executes after Ext.supports.init
  - Fix an issues where the expander icons are hidden when lines: false is used
  - Ensure that the grid doesn't trigger a sort on the store when it renders
  - Fix setValue method and initial value config on HtmlEditor
  - Fixed recursive cloning of a non "plain" object (the constructor of which is !== Object)
  - Ensure a layout isn't triggered if the container is destroying
  - Fixed the styling of forms in a toolbar
  - Fixed Window restore issue
  - Fixed Grid dependencies
  - Fix Accordion layout when initially layed out with no child items
  - Updating $font-size dynamic variable's to use ceil to fix sub-pixel (ex: 10.4px) font-sizes
  - Fixed multiple issues with rotated labels on category axis
  - Fix TabPanel dependencies
  - Fix typo in alternateClassName definitions
  - If the panel has a re-expander, make sure the title is set when setTitle is called
  - Fix an issue where panels would not be collapsed initially when not in a container
  - Allow the combo store to be bound using a single flat array
  - Fix autoCreated Store setup in StoreManager
  - Fix unreachable code in Ext.getDom
  - Properly clear managedListeners array in Observable
  - Fix problem with the animate config option replacing the animate method
  - Fixed grid scroll options 'horizontal' and 'none'
  - Fix problem with autoHeighting TabPanels by their child items
  - Fix menu box overflow handler on IE
  - Fixed stacked bar chart axis calculation issue
  - Fix scaling re-calculation issue for Bar, Line, Scatter series
  - Fire change event when ComboBox value is changed
  - Update alignment of ComboBox dropdown when its content changes, so it can flip from below to above or vice versa as the user types
  - Clear selection in ComboBox.BoundList if it no longer matches the value in the field, so that the old value can be re-selected
  - Fix bug with ComboBox where the value in the field would be blanked out while the user was typing with typeAhead:true
  - Fix ComboBox scrolling selected item into view when list is expanded
  - Set ComboBox selection in list when it is first created, if the ComboBox has an initial 'value' config
  - Fix Scatter series shadow issue
  - Don't reinsert a node into the NodeStore if its new parent is not part of the NodeStore
  - Fixed issue with Element.destroy not being properly called resulting in memory problems for IE
  - Fixed Ext.require() not firing callbacks after a failure
  - Fixed Ext.Loader.getPath() not returning properly value for unknown namespace
  - Forced setting the Axis minimum and maximum values specified by the configuration
  - Fixed cropped window titles in various browsers
  - Firefox fix for getNextId method in WebStorageProxy
  - Fixed an issue with the id not being sent when calling load directly on the model
  - Fixed a bug in previousNode and nextNode. They were not being checked before walking up the hierarchy and therefore triggered a cousin to always be returned
  - Fixed discontinuous tree selection
  - Field component onLayout was being run while the field was hidden but not after, so trigger width was always calcualted as zero. Changed order so layout occurs after show
  - Fix reset method on sliders
  - Fix application of emptyText in IE when ComboBox value is set
  - Fix the setTitle text in windows with vertical headers
  - Make empty ComboBox list item hoverable/clickable in IE quirks mode
  - Fixes Sprite item Bounding Box offset in Opera
  - Fix "Member not found" error in IE by preventing native event object from getting passed and used across the specialkey buffered listener
  - Fix individual record update in Ext.grid.GroupingFeature
  - Surface has now the ability to add in instances of Sprite and configuration objects
  - Ensure datachanged event is fired when filtering the Store without sorters
  - Adjust alignment styles for checkboxes and radios to match Ext3
  - Fixed checkbox spacing + positioning in IE
  - Fixed a bug in DataView Draggable where items in the ghost dataview would not be correctly removed
  - Fix vertical clipping of CheckboxGroup columns without fixed widths in IE quirks mode
  - Fix bug with Radial Axis scaling
  - Fix an issue when retrieving the previous sibling of a component
  - Fix sorter issue with DirectProxy
  - Fix setReadOnly method in HtmlEditor
  - Fix issue with looking up a store by id
  - Fix problem hiding modal mask after modal window hide
  - Fix support for passing a dom element as a target to an animation
- Enhancements
  - Locking GridPanel implemtented
  - Accessibility theme added
  - Numeric Axis majorTickSteps added to set the number of major ticks between a `maximum` and a `minimum` value
  - Implement the animate configuration option on TreePanel
  - Implement singleExpand on TreePanel
  - Store aggregation functions moved to the prototype
  - Implemented checked field in NodeInterface. Have renderer add a checkbox if a value other then null is set in checked
  - Implemented state support as a mixin
  - Added html to each tab in the history example to make it clearer which tab is currently activated
  - Refactored the GridFilters plugin UX as FiltersFeature, a Ext.grid.Feature subclass, and ported it to work with the new Ext4 grid architecture. Reworked the grid-filters example to match
  - Inject the TableView instance into each grid filter, even if it is an already instantiated Filter rather than a filter config object
  - Allow month picker items to wrap properly when inside components with white-space:nowrap like menus
  - Refactoring a Theming so it is easier to customize
  - Updated the themes example to include more components
  - Added HTTP error info to the data operation when a request fails
  - Added load event in preference of read event on TreeStore
  - Grid headers now support grouping in which a header may be configured with a nested headers config object as well as a text/header string
  - The Ext 3.x class ActionColumn has been implemented in 4.x as ActionHeader
  - Cleaned all locale packages files
  - Introduced a new getAssociatedData method on Model to make it easier to aggregate model data
  - Added window state management
  - Added state support for border layout
  - Removed extraneous layout in Card.setActiveItem
  - Made Ext.override proxy to Ext.Base.override if the class was created with Ext.define
  - added Ext.Base.getName method
  - Add animateTarget to show/hide of floating Components (such as Windows and Tooltips, or anything else that floats
  - Allow the aggregation function to be called with the grouped parameter for consistency
  - Added total summary and group summary support for the grid
  - Fix combos example to make getInnerTpl work properly - now must be part of listConfig
  - Implemented Ext.form.File, a custom field widget for file uploads
  - Properly set class on field error quicktips
  - Added grid state support
  - Relay view and tree events to the TreePanel and TreeStore
  - Added a new LocalStorage state provider
  - Allow the model to be defined in the store prototype
  - Implemented Sutherlandâ€“Hodgman algorithm and use it for our render label axis implementation
  - Implemented animate config option
  - Styled invalid form qtips
  - Implemented Tree sorting
  - Add additional check in setStyle to ensure the dom node still exists before setting style on it
  - FocusManager enhancements to support Containers being able to subscribe for keyboard navigation
  - Implemented Ext.menu.DatePicker class
  - Implemented Ext.menu.ColorPicker class
  - Cleanup FocusManager's handling of component add/destroy when enabled
  - Convert TabBar to use FocusManager.subscribe instead of its own KeyNav
  - Grid Header needs to give visual indication when it is focused, which will show the menu trigger. This supports key navigation on grid headers and the ability to press down to open the header menu. The menu needs the trigger to be shown since it aligns itself to the trigger
  - Add deep copy operation to NodeInterface
  - Allow Ext.form.Basic#markInvalid to accept a Ext.data.Errors object
  - Added logic to reduce/increase the number of columns in the shadowCt to match the number of items if columns:'auto'
  - Updated MVC to work with dynamic loading
  - Implemented CheckBox selection for Trees
  - Prevent ComboBox from querying and expanding list on keyup if readOnly=true.
  - HeaderDropZone will intelligently move a Header within the same container rather than add/remove, which will perform better as well as prevent add/remove events from firing unnecessarily on the HeaderContainer
  - Trigger fields no longer reserve space for trigger when it is hidden due to readOnly=true
  - Number field value can no longer be modified by up/down arrows or mousewheel when readOnly=true
  - Implemented scrolling while dragging
  - Implemented Grid Editing support as a plugin
  - Clean html entities when setting text to an Surface Sprite
  - Enhanced htmlDecode and htmlEncode methods in Ext.String
  - Scatter and Line series now skip records with undefined yValues
  - ComboBox now automatically set queryMode='local' for auto-generated array stores
  - Ext.form.BaseField now rewraps the browser event object when firing the specialkey event, to prevent issues with buffered specialkey listeners
  - Extended the useNull option to apply to boolean/string types for data stores
  - Added deferredRender back to Card Layout (currently defaulted to true for TabPanel)
  - Updated FeedViewer to be smarter about how it opened many tabs at once
  - Modify Proxy so batching is configurable
  - Allow a store configuration to be passed to data bound objects
  - Add beginEdit/cancelEdit/endEdit functionality to Model
  - Added isValid to Model for a shortcut
  - Added autoSave support for Data writers
  - Ensure writer always passes the id if we have a non phantom
  - Made Tips constrain within their zIndexManager's client element. Change the constrain default to true
  - Button will now use an anchor element when configured with an href
  - Make Ext.form.Field.resetOriginalValue update the field's dirty state to match
  - Automatically convert objects into records with NodeInterface
  - Make ComboBox.getValue return the raw text field value if it does not match the display value from the last list selection or setValue call. Allows submitting values that do not appear in the store
  - Enhance the appendChild, removeChild, insertBefore code on the NodeInterface with suppressEvents capabilities. This optimizes the performance of the initial Tree rendering drastically
  - Implemented Grid RowEditing
  - Basic.updateRecord() will now use the actual field data for updating the Model fields rather than the submit-friendly string equivalent of the form field data. Certain string encodings are not compatible with Model field covert methods if they are not in the exact/proper format, e.g. Date fields
  - Remove Canvas support as it is not ready for release. SVG/VML still covers all desktop platforms.
- API Changes
  - Moved methods slated for deprecation to the compat layer
  - Added a new ElementLoader class that is the superclass of ComponentLoader. The purpose of this class is to replace Ext.Updater. Updater is removed and the load method now points to the new loader
  - Move model creation into the model itself, essentially deprecates regModel
  - Time axis now works with Dates and not formatted strings
  - Move Ext.util.Date methods over to Ext.Date. Changed all references to Ext.Date in code, examples and tests
  - Add workaround to Ext.core.Element#getWidth to avoid Gecko bug where it returns an offsetWidth that rounds down the actual width due to subpixel font rendering. This logic was previously in a couple of components, this commit moves that up to Element.getWidth
  - Fix AbstractPanel.bodyCls to also support array values
  - Created an AbstractMixedCollection which MixedCollection extends from
  - Sortable refactored as a mixin
  - Refactored Sorting on MixedCollection, TreeStore, and TreePanel to use the new Sortable mixin
  - Absolute Layout will now always use setItemSize even if an anchor property isn't specified
  - Ensure the page parameter gets sent on remote data loading
  - Remove any trace of applyTo throughout the framework
  - Updating the BoundList selection on setValue for ComboBox is now the default behavior
  - Selection models are now consistent: Moved grid/CellSelectionModel.js to selection/CellModel.js, grid/RowSelectionModel.js to selection/RowModel.js, and grid/CheckBoxSelectionModel to selection/CheckBoxModel.js. Namespace moved to Ext.selection as well
  - Set AjaxProxy as the default proxy
  - Normalize store aliases to be store.name. Added the ability to specify a store configuration when creating a data bound class. Note that this requires all of the stores to be looked up using StoreManager.lookup so that we can determine whether we have received an id, a config or an instance
  - Enhance DataView UI event handling
  - Remove dependency of CellEditing on CellSelectionModel
- Compatibility Changes
  - Implemented compat layer for PagingToolbar and MemoryProxy
  - Significant update to AbstractStore compat layer to handle different store/proxy/reader config setups
  - Updates to compat layer for AbstractStore and MemoryProxy to support filtering correctly
  - Aliased row[de]select to [de]select
  - Tweaked message formatting in compat layer for deprecating events
  - The bodyStyle config types from 3.x are all now fully supported on Panel
  - Compat code was using Array.indexOf, which did not agree with IE6. Switched to use Ext.Array.indexOf
  - Alias Panel.bodyCssClass config to bodyCls
  - Added Slider compat override to convert the SliderTip plugin to tipText config
- Documentation Changes
  - Updated Ext.Date
  - Fix the link to Ext Direct specification
  - Correct spelling of 'resizable' and not 'resizeable'
  - Updated Controller
  - Updated Advanced DataView
  - Update Ext.Window
  - Added ActionHeader
  - Added Ext.Base.override
  - Updated AbstractDataView
  - Updated Draw.Component
  - Fix ComboBox docs error
- Known Issues
  - Various styling fixes are ongoing
  - Buttons are not part of the focusable items in a form
  - Shadows to be implemented in the next release
  - Tree Filtering and Editing to be implemented in the next release
  - Performance and memory optimizations to be implemented in the next release
  - Cleanup of API naming conventions to be implemented in the next release
  - IE9 is not detected as supporting CSS3BorderRadius, which it only does in strict mode.

# Release Notes for Ext JS 4 PR5

Release Date: March 18, 2011
Version Number: 4.0.0pr5

## New In This Release

- New Examples
  - Ext.Direct Named Arguments
  - Registration Form
  - StatusBar
  - Advanced StatusBar
  - Tree Reporder
  - XML Tree
  - TreeGrid
- Bug Fixes
  - Fix bug on FF for Mac where an initial layout of boxes causes the innerCt to scroll, and it becomes stuck at the scrollPosition. Manifesting in layout-browser example
  - Fix the problem in IE where the margin-bottom of the last item was not being included in the "auto" height of its Container
  - Fix issue where dragging a child to become the last child in a folder would insert it in the wrong position
  - Fix an issue where the sortType was not being honored when local sorting in a grid
  - Fix issue when calling setProxy on a model subclass
  - Fix Ext.panel.Table hideHeaders configuration option
  - Fix button layout in IE7 when minWidth is set
  - Fix minButtonWidth in FormPanels
  - Fix bug where StoreManager would not be able to create a Store from a store config object
  - Fix layout/alignment issues in fieldset legends with IE
  - Fix for IE6 repaint bug on right edge of framed panel
  - Fix display of tooltip anchor arrow
  - Fix scope for custom validator method
  - Fix icon position of grid header when align:right
  - Fix issue with dateRenderer when dealing with null values
  - Fix issue with masking in IE6-9 Quirks and IE6 strict
  - Fix problem with Panel's initial collapse state setting, and subsequent expansion by the Accordion layout
  - Fix ComboBox setValue to handle empty values
  - Fix issue with Line Series shadows which weren't refreshed when animations were not enabled on
- Enhancements
  - Refactored the Tree code. Working features as of this point are Tree rendering, expanding & collapsing, drag and drop, loading a tree from memory, have multiple columns, keyboard navigation and selection model
  - Added support for named arguments in Ext.Direct methods
  - Every Record registers itself with the ModelManager
  - Implemented Tree collapse and expand animations
  - Implement loading nodes in a sorted TreeStore
  - Added a lastframe event to the animation that only fires when the animation actually reaches its end
  - Define getters for getting the computed height and width from an animations target to use as the from values
  - Refactor Tree collapse and expand animations. This fixes quickly collapsing and expanding nodes
  - Added a new transform option for Sorter
  - Panel's getDockedItems now accepts a ComponentQuery selector string
  - Add setSrc method to ImageComponent for changing the image src after initialization
  - Added 'none' as a possible value for msgTarget, to prevent all error message rendering. Only fire errorchange event when the error message actually changes
  - Add hideGroupedHeader support to Ext.grid.GroupingFeature
  - FormPanel and FieldContainer both contained logic to handle the addition and removal of Labelable and Field instances within their items subtree; factored that common logic out into a FieldAncestor mixin for both to use. The new mixin also adds new events 'fieldvaliditychange' and 'fielderrorchange' that allow listening for changes at the parent container level
  - Allow checkbox fields to display errors
  - All the old config properties that controlled the dropdown list have been removed in favor of a single listConfig object, which gets passed along to the BoundList's config. This is much simpler and provides total control over all aspects of the list
  - Implemented valueNotFoundText
  - Enhanced BoundList layout to handle min/max for both width and height
  - Implement ComboBox pageSize option
  - elasticOut and bounceIn easing added for animations
  - Added support for rootVisible. Also moved the creation of the NodeStore from TreeStore to the TreeView
  - Added support for the 'root' configuration option on TreeStore. It supports the 3.3 way of specifying root and children. Automatically figures out whether to load children on expand from the server or memory. Also removed requirement to specify a proxy on a TreeStore. Removed requirement to specify store on TreePanel and support the 'root' config option on TreePanel automatically creating a TreeStore
  - Modified TreeView so that it expands the root node if it's not visible
  - Modified getSourceFiles to include support for writing XML documents
  - Moved additional class for VML from javascript into the stylesheet
  - Add in support for icon and iconCls on tree nodes
  - Support loading flat json data while still loading children from the root property
- API Changes
  - Refactored Tree to be able to decorate records with a Node API
  - Reimplemented TreeStore and created new class called NodeStore
  - Border layout is now responsible for performing a mini-collapse of a child Panel
  - Panel now performs a collapse to leave its header (or a newly generated, injected header) visible. It does not perform a mini-collapse
  - Renamed FlatTreeView to TreeView
  - Correct getRefItems implementation in light of ComponentQuery selector being available in getDockedItems
  - Add boxLabelEl as render selector for checkbox fields
  - Ext.data.Model.id now assigns the new id to the record
- Compatibility Changes
  - Added an alias for Ext.data.Field
  - Added an alert when there are compat errors and no console
  - Added compat code for GridView & JsonStore
  - Modified paging example to switch getRowClass to PreviewPlugin
  - Added internal Ext 3 > 4 class mapping utility
- Documentation Refactors
  - Charting overview document
  - Ext3 Legacy
  - Ext.form.TextArea
  - Ext.form.Checkbox
  - Ext.form.Radio
  - Ext.form.Field
  - Ext.form.FieldContainer
  - Ext.form.FieldSet
  - Ext.form.Panel
  - Ext.form.Labelable
  - Ext.Base
  - Ext.Button
  - Ext.Component#draggable
  - Ext.ComponentDragger
  - Ext.Loader
  - Ext.Array
  - Ext.TabPanel
  - Ext.TabPanel
  - Ext.form.BaseField
  - Ext.form.ComboBox
  - Ext.form.Text
  - Ext.form.Basic
  - Ext.Toolbar
  - Ext.data.SortTypes
  - Ext.data.StoreManager
  - Ext.state.Manager
  - Ext.util.Animate
  - Ext.form.Date
  - Ext.form.Label
  - Ext.form.Number
  - Ext.Viewport
  - Ext.Window
  - Ext.ComponentQuery
  - Ext.Panel
  - Ext.form.FieldAncestor
  - Ext.Container
  - Ext.Component
  - Ext.grid.ViewDDPlugin
- Known Issues
  - Portal example not correct in IE6
  - Toolbar menu overflow not styled in IE6
  - Charts do not render properly in Safari 3.2
  - Menu links (anchor tags) need styling
  - Minor clipping of panel header text in Opera and IE6/7

# Release Notes for Ext JS 4 Preview Release 4

Release Date: March 15, 2011
Version Number: 4.0.0pr4

## New In This Release

- New Examples
  - Miscellaneous
    - Grid/Form/Chart Combo
    - Rich tooltips (Chart/Grid)
    - Accessible Feed Viewer using keyboard navigation
    - Key Nav
  - Drag and Drop
    - Grid to form DnD
    - Field to grid cell DnD
    - Grid to Grid DnD
    - DataView to grid DnD
  - Forms
    - A common "contact us" popup form
    - A shopping cart checkout form
    - Advanced validations
  - Toolbars
    - Simple toolbar with menus
    - Reorderable toolbar items
  - Layouts
    - Accordion layout example
    - VBox layout manager examples
  - Ext.Direct
    - Simple generic Direct example
    - Form submission using Direct
- Bug Fixes
  - Fix error in slideIn/slideOut when optional duration is not specified
  - Fix and issue that can happen if only a single axis point is used in a bar chart
  - Ensure lastFocused is reset when refreshing the selection model
  - Fix EventManager issues with mouseenter/mouseleave events
  - Fix {memberExpression} selector parsing
  - Fix up alias for ArrayStore
  - Fix currency function to accept and convert a numeric String input value
  - Fix an issue where legend items don't remember their state between reload
  - Fix up allowEl option for within, it should be used as a fallback if the element isn't contained within the parent
  - Fix a highlighting issues with Pie
  - Correct use of "float" keyword as object property name
  - Fix buttons with noLinearGradients
  - Change how field layout handles horizontal sizing when no set width is specified It now uses the shrink-wrapped natural size of its body content plus label, rather than the width of the outermost element. This fixes layout issues when fields are used as hbox items, since the outer element has zero width during initial layout. It also prevents fields from expanding to the full width of their container by default, which is more consistent with the Ext3 behavior
  - Fix Box layout for when margins are specified in object for, but without all 4 properties. Default to zero
  - Remove extraneous quote in GroupingFeature template
  - Fix an issue when using autoHide and delegate with ToolTip
  - Fix Combo hiding when using the scroller in FireFox
  - Fix specificity of .x-form-invalid-field selector for textareas so the proper styling is shown
  - Fixed width of slider tips, and tips in general, in IE quirks mode. Switches tips to use the table framing so they don't expand to full viewport width. Removes the bad width-setting logic from Ext.slider.Tip so it is properly handled by the layout class
  - Fix box layout to correctly calculate middle alignment
  - Correctly autosize the innerCt according to max component size (now takes innerCt's borders into account)
  - Fix an issue when using a defaultValue with Boolean fields
  - Fix an issue when saving/loading a model and the request fails
  - Fix for improper font measurement in VML. Vertical header text should display more reliably. Still some work to do on adjusting for the font baseline.
  - Ensure button does not show mouseover when disabled
  - Fix call to cloneNode so it happens on the raw HTMLELement
  - Fix up a typo in the RemotingProvider
  - Fix an issue with form submissions with uploads
  - Fix typo that caused file uploads to fail
  - An autosized Panel which has been collapsed should now expand back properly
  - Fix an issue where the store would not reload when filters are cleared while using remoteFilter
  - Fix an issue where Model.setProxy would not accept a Proxy instance
  - Fix a problem in the ZIndexManager where if a modal Window showed another floating Component (such as the BoundList of a Picker Field), the modal mask is hidden during the period that the Window is not at the topmost position in the z-index stack. Now the modal mask is only hidden when there are no Modal floating Components (usually modal Windows) displayed
  - Fixed some IE 6/7/8 styles in Menu. IE6 had a "slit" in the item separator that is no longer there. Browsers without linear gradient support now use a nice looking background image for active items
  - Fix for Menu in Opera 10, which does not report an element's width if it is not a part of a render box. We have to temporarily add it to the body to perform a measurement
  - Change ReloadChart example to bind to the correct (left) axis
  - Fix issue where the bounding box cache in VML was not getting cleared when it's path changes
  - Fix toolbar button spacing in IE7 strict mode
  - Fix an issue with split buttons where the arrow wasn't completely clickable
  - Fix some issues with state track in Model
  - Fix Box Layout calculation effecting margins
  - Fix endDrag call to afterBoxReflow
  - Fix an issue rendering bar chart categories in the wrong order
  - Fix an issue when trying to position a floating component at 0,0
  - Fix a chart display issue when using a single series in a vertical legend
  - Fix an issue where the chart legend would move on redraw when using position: float
  - Ensure hidden fields don't have any effect on form display
  - Fix vertical alignment of paging toolbar number field
  - Fix a problem where Windows do no display an icon when configured with a valid iconCls
  - Fix bug in ComponentQuery, when using {expression} matching. Only the first {expression} used would ever be matched resulting in incorrect results.
  - Fix styling of fieldset legends
  - Fix height of text/trigger fields in IE quirks mode
  - Fix spinner button sprite states when field is focused
  - Fix an issue where viewports in IE6/7 would show a scrollbar by default
  - Fix dependencies for Border Layout and Splitter classes
  - Fix an issue when using non-string values in combo
  - Fix an issue when using a belongsTo association and loading the parent object
  - Fix an issue where RestProxy requests were being batched
  - Fix sizes of Buttons in ButtonGroup
  - Fix an issue when using an itemId in a border layout region
  - Fix an issue where space was being reserved in IE7 for side error icon when there is no error
  - Fix typo in throw error message in initframe

- Enhancements
  - Introduced a TreePanel capable of supporting multiple headers. Abstracted shared logic between the Tree and Grid into a TablePanel class.
  - Tab overflow implemented
  - Menu overflow implemented
  - Drag and Drop for Dataviews implemented
  - Implemented Tree and Grid drag and drop
  - FocusManager implemented (Jarred ELABORATE)
  - HTMLEditor implemented
  - Ext Direct implemented, with a new DirectProxy
  - Add support to ComponentQuery to accept member expression selectors in pseudo-class selectors
  - Support member expression selectors for ComponentQuery in the same way as attribute selectors, by allowing them to occur anywhere within a single selector chain to further filter the working group of items
  - Added inheritable statics for Classes
  - Refactor cleanup for Scatter Series
  - Ensure doLayout doesn't run a layout that is already in progress
  - Implement pruneRemoved for Ext.selection.Model
  - Ensure selection model is refreshed when DataView is refreshed or records are added
  - Create a reference to the Ext sandbox instance in generated functions
  - Increment snap ends `to` argument properly
  - Add feed viewer icon
  - Box layout. Correct allocation of spare space to non-flexed items after a shortfall has caused a reduction to minSize
  - Button layout: Now sets the outer element width if a numeric width passed
  - Added "focusable: false" to menu & toolbar separators so they are not candidates for gaining focus
  - Updated Ext.menu.* to play nicely with Ext.FocusManager when enabled
  - Menu: Constrain to within browser viewport and use box layout scroll overflow handler
  - Implement disabled style for horizontal scroller
  - Implement Ext.selection.TreeModel handling for left/right in the flattreeview. Turn it on in the TreePanel
  - Enforce that user clicks expander to toggle a record
  - Ensure that collapsed region placeholders are z-indexed above slide-ins
  - Border layout now honors the floatable: false config
  - Menus no longer access elements that are not rendered
  - MenuManager now uses Ext.Array.remove instead of calling remove on the Array instance
  - Ensure a region isn't floated if floatable: false is specified.
  - DataView now ensures the selections get refreshed when the view does
  - Implemented button as a link when an href/url is configured
  - Implementes initial collapse state to collapse when the outermost Container (usually a Viewport) has been layed out, or, if no Container, on first component layout
  - Removed legacy images file
  - The framing method for non-CSS3 browsers which uses a table is necessary for proper width of floated components in IE quirks mode. Some floated components, such as Tip, have Dock layout which requires being able to insert docked items directly into the outermost element; this was failing when the outermost element was the table element. Changed to have a div as the outermost element with the table as an immediate child
  - Prevent validation when initializing the field value, rather than validating but then clearing errors
  - Apply correct CSS classes to Panel headers within collapsed Panels so that bordering can be kept consistent
  - Add rule for column layout child items. They must float:left
  - Implement 3.x style Column layout where child items float across the Container (Note this API is not finalized and may change)
  - Labels for vertical axis are now hidden when they're too close to each other (or overlapping)
  - Implemented weighting on docked items by returning a sorted array based on a weight property in AbstractPanel's getDockedItems method. Default weight is 0
  - Addition code to ensure the data proxy gets its params correctly
  - A parent menu's hide timer (on mouse leave) will be cancelled when hovering over a submenu
  - Add x-quirks to when we're in quirks mode (!Ext.isStrict), useful for CSS that must know whether or not in quirks mode, as x-border-box is applied on all browsers that aren't IE6/7 in both quirks and strict modes
  - Implemented hideHeaders and provide backwards compat layer for preventHeaders
  - Implement fill:false in Accordion layout which means that expanded child Panels are not fitted within the accordion Container, but assume their natural height. Implement multi:true which allows multiple items to be opened at once when using fill:true. The opened Panels share available space by using the Box layout flex config
  - Implement a Component click event in Header. This is for use by Panel's titleCollapse configuration
  - Accordion layout now propagates its Panel-specific configurations to child Panels
  - Implement titleCollapse for Panel
  - Added writeAllFields method to the data writers
  - Add beforeselect event to DataViewModel
  - Restored original fonts and font-weights in the default theme to be the same as of 3.3
  - Class.override now adds an owner reference to methods that didn't exist in the superclass yet
  - Users can now override the sortParam used when sorting a particular Header
  - Ensure we use the browser normalized array methods for DataView
  - Add a findLayoutController method which goes up the ownerCt chain to find the highest currently active layout so that afterlayout events may be tracked to fire when a final size has been arrived at
  - Card layout now calls afterLayout on the card Container after card activation
  - Refactor getWidth, getHeight, and getViewSize to account for IE quirks mode measurement issues when a container is overflowed
  - TabBar now scrolls the active tab into view upon set of active tab
  - Added new isIEQuirks flag
  - Tweak bar/column chart starting points so they don't overlap the axis
  - Ensure box layout takes border space of the innerCt into account when centering
  - Tooltips no longer get focus when they call toFront()
  - Users may now provide their own CSS rules for enabling overflow on other box layout Containers. Currently we support Menu, Toolbar and TabBar overflowing.
  - Window will now force the header creation if draggable is set to true
  - Added a new Body Component layout for Components which maintain an inner body element which must synchronize its size with the encapsulating element
  - FieldSet now uses a Component layout to synchronize the size of its body element with the size available within its main, encapsulating element
  - Due to the use of the descendant selector for setting float/etc on field labels, fields nested within a FieldContainer would always get the styles corresponding to the container's labelAlign, even if their own labelAlign was different. Changed it so the label alignment className is now given directly to the label element rather than the parent, so the CSS no longer has to use descendant selectors
  - The Trigger component layout was setting the height of the input field based on the incoming requested height; single-line input fields should always get their height from the CSS and ignore the layout's height
  - Made AbstractDataView less strict in the type of parameter it accepts as a target for getRecord. It may now be an HtmlElement or an Ext.Element
  - Added a frameHeader config which turns on/off framing on the Panel Header
  - Added a ComponentLayout for Editor
  - Ensure formBind is updated when the form is first created & when items are added/removed
  - Added the ability to assign a custom reader for reading associations
- API Changes
  - Added destroy method to Model
  - Move getItemForPoint up to Series and implement isItemInPoint in each series
  - Added static methods for DataView
  - Containers calls to doLayout will call ComponentLayout instead of ContainerLayout when they don't have dimensions (autosized)
  - Change ComponentQuery's member expression filter function to use an "items" argument rather then accessing arguments.callee.caller.arguments, to be ES5/strict compliant and more straightforward
  - Remove the use of arguments.callee from EventManager.createListenerWrap, and instead give a named reference to the return function. ES5/strict compliant, and works in all browsers
  - Ensure DataView uses getItemSelector() when firing events
  - Changed $prefix in scss to include `x-` not just `x`
  - Remove box scroller subclasses. There's only one now which handles perpendicular/parallel
  - Box layouts: new properties for use by box layout overflow handlers
  - All box layout overflow scrolling is handled by a single class: Scroller
  - TabBar now removes header text item and tool spacer. Use scroller overflow handler
  - Added a new preventDefault option to button
  - Remove HorizontalMenu class. There is only one Menu overflow handler
  - Move scroll-specific methods out of overflow handler base class into the Scroll handler
  - Added extra menu-active cls with btn.ui into menuShow
  - Added menu-active cls to css
  - Add slider layout class as dependency
  - Not all floating components should be automatically focused when they are brought to the front; this adds a focusOnToFront config to control that behavior on a class or instance basis. Defaults to true, but is overridden to false in Tip and in the BoundList instances created by ComboBox and Time fields, to prevent losing field focus
  - Ext.grid.View renamed to Ext.view.Table
  - Throw an error message when trying to bind to an event handler that doesn't exist
  - Add a border to collapsed panel headers depending on their docked position
  - Renamed the legacySortMode config to simpleSortMode
  - Added new API config for Server proxy and subclasses
  - Removed Class.extend method (not to be confused with Ext.extend)
  - Removed unused getHead method from Ext.data
  - Ext.Date.parseDate changed to Ext.Date.parse. Add deprecaton for the older parseDate API.
  - Unified Element and Element.static addUnits method which checks for a valid number or unitized String and throws a wraning message if a NaN is passed
  - Changed "operation-complete" event in Batch to "operationcomplete"
- Compatibility Changes
  - Added Ext.lib.Ajax compat
  - Added Ext.reg / ComponentManager.regiserType aliases
  - Fixed editor example's Panel.header reference
  - Include css for message box example
  - Alias Ext.lib.Dom.* to Element
  - Fixed registerType/reg aliases, added registerPlugin/preg
  - Moved legacy-only fx methods to compat file
  - Moved Component overrides from core-compat to compat
  - Added console msg about setting showErrors flag
  - Compat fix for loading stores with an inline data object
  - Moved xtype aliases from core-compat to compat
  - Added additional non-Core JS object prototype aliases
  - Ext.Date compat overrides
  - Additional msg for instance methods becoming statics
  - Added Ext.extend to the compat file, fixed a null error if members arg is not passed
  - Added Store.setDefaultSort compat override
  - Added GridPanel and Model compat overrides
  - Added applyTo message to Ext.Component
  - Added Ext.Compat.breaking() to show breaking changes
  - Added appropriate messaging for most of the compat configs
  - Moved compat items from combobox into the compat file
  - Renamed Ext.Base.extend -> Ext.Base.addStatics, deprecated Ext.Base.implement for Ext.Base.extend. In short, from now on, use MyClass.addStatics for statics members, MyClass.extend for prototype members
  - Fixed tpl alias to implement the getInnerTpl method correctly
  - Added isDef checks where needed to log messages only for defined configs
  - Add compatibility for overriding Ext.form.Field.prototype.msgTarget
  - Add compatibility handler for old implicit column containers in the CheckboxGroup/RadioGroup items
  - AbstractStore and Store overrides for reconfiguring reader/proxy config if needed
  - Aliased store.url support
  - Reader support for optional recordType 2nd arg to constructor
  - XmlReader constructor override to alias configs
- Known Issues
  - Portal example not correct in IE6
  - Toolbar menu overflow not styled in IE6
  - Charts do not render properly in Safari 3.2
  - Minor styling issues with forms/tabs/buttons (primarily in IE6/7)
  - Menu links still need styling
  - Minor clipping of panel header text in Opera and IE6/7

# Release Notes for Ext JS 4 PR3

Release Date: March 3, 2011
Version Number: 4.0.0pr3

## New In This Release

- Bug Fixes
  - Across the board documentation updates and fixes
  - Fix and implement CycleButton
  - Detect that getAttributeNS is only available in IE9 when it is in IE9 standards mode
  - Fix type in formatContainsHourInfo
  - Fix shrinking problem on the y axis with line charts
  - Fixed sandboxing for EventManager createListenerWrap, reported from
  - Replaced all "new Function(...)" with Ext.functionFactory(...), which solves the sandboxing issues
  - Fix reload of legends and hiding of pie slices shadows when changing the number of pie slices
  - Fix bug in stateful where changes were not being tracked
  - Fixed up slideIn and slideOut animation
  - The code to get viewport width had been changed incorrectly while looking at another layout issue. It's been reverted to how it was before
  - Various fixes for synchronous dynamic loading
  - For data validations, fix inclusion and exclusion method by replacing array indexOf method that is not supported in IE by Ext.Array.indexOf
  - Fix that allow to run Dispatcher spec without context, more precisely without Ext.History object
  - IE fix for Ext.data.store, use Ext.Array.indexOf instead of indexOf native Array method which is not supported by IE
  - IE fix for Ext.Number.toFixed
  - Fix mouseenter and mouseleave events for SVG
  - Specialized IE removeNode now specific to IE6 and IE7
  - Fixed the zero gap issue for barchart as well as a anti-aliasing in the legend
  - Fix framing for components with no bottom or top corners
  - Improved Ext.extend backwards compatibility
  - Fix XHR bug with timeout requests
  - Fix a bug that only allows string values to be used with the {.} operator
  - Fixed a bug with onAvailable in AbstractManager
  - Fixed a bug in HashMap detecting an existing key when adding a new item
  - Ext.Array.merge now properly acts like a true union set operation
  - Fix padding on toolbar-text
  - Fix css issues with tabs
  - Fix css issues with grid
  - Fix accordion header styling to match 3.x
  - Fix portal example to use recently implemented accordion layout
  - Set the collapsed flag before re-layouting the fieldset, so it can be used in isVisible calculations
  - Fix date picker when using dynamic loading
  - Fix welcome html files
  - Fix border styling for DatePicker
  - Fix class definition to set prototype properties when the Ext.Date class has been loaded in DatePicker
  - Fix tag error in the RotateText example
  - Fix styling of MenuItems' icons, checked/unchecked style rules target the *icon*, not the element
  - Fix defaultFocus config when a number
  - Fix incorrect expand icon in header of collapsed Panel in Accordion layout
  - Fix bug in Time field's parsing
  - Fix ComponentQuery member expression feature (e.g. '{isHidden()}' ) so it works as expected
  - Fix framed panels header when collapsed
  - Fix bottom tabsplit height with IE browsers
  - Fix button padding when the icon is to the right
  - Fix the width of grid sort indicators so they don't wrap as easily
  - Fix arrow bottom buttons
  - Fix form and triggerfield styling
  - Fix styling issues with form/checkboxgroup
  - Fix a bug with button, now using neutral color and not base
  - Fix differently scaled buttons in a toolbar
  - Fix cross browser issues with paging toolbar
  - Fix for IE Ext.Array.toArray
  - Fix Component.animate to ensure the component is returned and optimize when not animating height or width
  - Fix styling for bottom tabs
  - Fix tips so they no longer focus themselves when shown. In IE, it was taking focus from form fields
  - Fix stroke widths in VML
- Enhancements
  - A plethora of updates to the backward compatibility legacy files and guide
  - Implemented combineErrors and combineLabels features in FieldContainer
  - Added server-side usage support for Ext4: hammerJS and nodeJS tested
  - Selection Model will now maintain last focused element in the View
  - Add the ability to be able to load a single record with data reader
  - Change shortcut easing functions to match CSS ones and added easeInOut. Benchmarked to be 300% faster at a minimum
  - Add setItemSize method for Containers as a central method for all child item sizing
  - Implement framing using background-position instead of background-image. This resolves the issue with the browser making a request to a 404 page for each framed component that doesn't have any generated framing css
  - Preliminary support for onClick added for charts
  - Implement Chart Mask mixin. Allows for selection of an area of a chart. This will be mixed into Axes as well for the next release.
  - Add a new parseStyles method to transform a css string to an object with a bunch of properties. Use this new method in applyStyles in DomHelper and also in AbstractComponent
  - Add new function to check if the format contains date/day info (ie. not time) - used in TimeField
  - Add withinBox method to Draw
  - Ext.Array.intersect method added
  - Ext.Array.difference method added
  - Ext.Array.union shortcut method for merge
  - Begin clip-rect support in SVG and VML (incomplete)
  - Change HashMap to no longer throw error when adding an existing key. Warn instead
  - Added a cls into the rowexpander header cell and row cell for the first cell
  - Added x-hidden cls for backward compatibility
  - Update css for grids so it now uses css3 throughout
  - Added images for special cells in grid
  - All tabs have a font-weight of bold
  - Move caching logic out of Anchor layout's anchorSpec functions to the base layout engine
  - Add floor argument for example-data generator
  - Removed deprecated layouts
  - Accordion layout only animates during expand/collapse of child Panels
  - Button layout caches measured styles for efficiency
  - Feed Viewer uses CycleButton to cycle through the preview pane options
  - Bringing a floating Component (such as a Window) to the front of its ZIndex stack now focuses it on a 10ms delay. Focusing several Windows in succession results in only the last Window actually receiving focus
  - Refactor Border layout to use new Element effects methods to slide regions in and out
  - TabBar now overrides the layout align option set by the Header superclass
  - Changed tabs to use the base-color and not hard coded colors
  - Changed button to no longer use hardcoded variables
  - Make TabPanel dock the TabBar according to the tabPosition config
  - SVG text is now unselectable
  - A new 'errorchange' event has been added to Ext.form.Labelable, fired whenever set/unsetActiveError is called. This is similar to the 'validitychange' event on Ext.form.Field but is fired by Labelable components which are not Fields, such as FieldContainer. It also fires when the validity is staying invalid but the message changes, which is more useful in some cases
  - BaseField now adds a .x-form-field-invalid class to the inputEl, and this is used in the CSS rather than using the outer .x-form-invalid and a descendant selector; this allows proper styling of child fields of a FieldContainer when the container has an error message displayed
  - ComboBox clearValue method added back in
  - Toolbar now uses the base-color
  - Add extra checks to figure out whether we need to do DST parsing or not for Date function
  - Add triggerNCls-over and triggerNCls-click classes to individual trigger buttons, so each one can be given interaction styling independently rather than requiring compound class selectors. Fixes spinner button states in IE
  - FeedViewer example: Button icon CSS rules should only override the background image. Otherwise Ext-specific styling rules will not apply
  - Group class attached to the icon element for style targeting in CheckItem
  - ComponentQuery can now accept back-to-back pseudo-class selectors, like :not():not():custom
  - Move back to setInterval instead of setTimer as a base for animation timing.
  - Allow for binding of multiple axes to a series via an array
- API Changes
  - AbstractLayout removed, Layout remains the base class now all AbstractLayout dependencies to Layout
  - AbstractDataView has new getter method getItemSelector
  - afteranimate event now fired as the last operation of the Anim.end method (instead of the beginning of the end)
  - layoutItem moved to ContainerLayout from Layout
  - Move resizeHandles config out of Window to Component
  - Box will no longer use CSS margins. It reads CSS margins and adds them to the configured margins, and clears CSS margins. This allows for more accurate positioning
  - Ext.form.CompositeField has been deprecated, as FieldContainer is now at feature parity. Alias has been added to compat file
  - Ext.form.Field#checkValidityChange has been removed, its logic has been moved into the validate method so it gets run when validate is called directly
  - Chart zoom functionality being changed to zoom the appropriate portions of the chart instead of everything

# Release Notes for Ext JS 4 PR2

Release Date: February 23, 2011
Version Number: 4.0.0pr2

## New In This Release

- Bug Fixes
  - Across the board documentation updates and fixes
  - Fixed a bug that caused an error when hovering over a SplitButton
  - Fixed a bug with setting Proxies on Models
  - Slider movement no longer lags behind the mouse
  - Search now works on the generated documentation
  - Fixed issues regarding date formatting
  - Fixed chart destroy code
  - Fixed an issue when entering a value into the PagingToolbar field
  - Fixed positioning of the editor in the editor sample
  - Change the order and ActiveX Objects that we use. This fixes XML Parsing via DomQuery in IE
  - The last frame of an animation will account for any rounding issues
  - Fix various Slider Tip issues
  - Fix various Slider Field issues
  - Border layout now calls setCalculatedSize when sliding in a hidden Component so that the Component's size does not get fixed and the "other" dimension that is not being set is not to auto by the ComponentLayout
  - Fix preserving ratio to ensure that the largest minSize is honored.
  - Fixed dependency issue with DatePicker
  - Fix removing of current active tab
  - Fix Ext.tab.Bar css sizing issue when the TabPanel has no items
  - Ensure that there is at least one active tab if the tabpanel has items
  - Fix issue with maintaining the constrain parameters in stretch and stretchmax
  - Fix Firefox Ext.tab.Bar css sizing issue
  - Remove tab focus outline on tabpanel tabs
  - Fix icon rendering issue of TabPanel items
  - Corrected styling of toolbar spacers
  - Correct vertical alignment of text on most browsers
  - Fix bug when entering a number into the PagingToolbar
  - Fix MessageBoxWindow's initial laying out problem on FF
  - Ensure RowSelectionModel fires select/deselect events.
  - Fix issue where the parentMenu isn't set correctly if you pass an xtype
  - Fix styling in resizer example
  - Fix up the expand/collapse tool on FieldSet, it wasn't being toggled.
  - Fix initially collapsed Panels in a border layout
  - Border correctly hides hidden floated Panel after it's moved out of view
  - Sandbox chart example now scopes all it's css, no more broken menus
  - Set the background position correctly for progress bar background image
  - Fix text alignment issue in progressbar.
  - Fix element size issue for ie6 and ie7 in strict mode
  - Resolved fighting of drag and drop resizing vs reordering
  - Fixed an issue when submitting combo values
  - Remove default minimum width on BoundList
  - fix IE 7 icon separator zindex issue for Menu
  - Fix problem where grids would incorrectly calculate the width of columns when they were not currently visible due to a layout. Like when they were in a TabPanel
- Enhancements
  - All animations now support WC3 Timing control for script-based animations. When available, else fall back to standard javascript timers.
  - Implement optional scoping for border box CSS rules
  - Implement optional scoping for reset CSS
  - Tabs are now closable
  - Basic form's getValues now handle fields whose getSubmitValue method returns an array of multiple values
  - Several animation examples updated
  - Fixed links on the welcome page
  - Several updates to class documentation
  - Menus now have full keyboard navigation support
  - Menus now extend Panel to support docked items
  - Menu SCSS improved by moving hardcoded theme variables to the variables SCSS file
  - Ext.util.KeyNav can accept space key input
  - HashMap.add may now take a single argument similar to MixedCollection.add
  - Fx queue methods are now handled in the Fx.Queue mixin.
  - fxStack removed from Element.cache, this is now maintained within Fx.Manager.
  - Animate methods (animate, stopAnimation, syncFx, sequenceFx, and getActiveAnimation) now applied via a mixin to Element/CompositeElement/Component/Sprite/SpriteGroup
  - Chart Series.js changed to use animate API. Rest of charts to follow
  - Element translatePoints method refactored to handle undefined passed sizes gracefully
  - EventManager preventDefault fix for IE Link
  - Fix observable so it normalizes the event name in hasListener
  - Ensure component cls and style properties are maintained on framed components
  - Animator (keyframes) now fully support the iterations property
  - Animator now properly supports stopping if beforeanimate returns false
  - Normalize API differences between Element's addCls and removeCls. Both now allow space separated strings
  - Implement endDrag method in DragTracker
  - Handle mouse entering and leaving the arrow area of the Button
  - Button now has a overMenuTrigger flag
  - Split Button now uses the menuTriggerOver flag
  - BorderLayout destroys its embedded Container upon destroy
  - Allow setPagePosition to be passed one or other coordinates as undefined
  - Border layout now implements parameter indices for setting size arguments in VBox and HBox
  - Changing an error message will now be accounted for when errors are re-displayed
  - Improved Grid CSS3 usage when available
  - Component.setPosition method now uses component.animate
  - Cleanup setPagePosition logic and account for NaN issues
  - Rename string vars in Box to be more descriptive
  - Add Toggle buttons to the chart examples
  - Percentage width/height now supported in Border layout
  - ZIndexManager now tracks browser resizes when the modal mask visible
  - Border layout uses Component's animate method
  - Border layout now correctly syncs size of hidden Components before sliding them into view
  - Increase minWidth/minHeight of Resizer to 20
  - Remove charts.swf as it is not needed anymore for the new Charts
  - Added ResizeTracker: A multi-corner, constraining, aspect ratio preserving resize algorithm
  - DragTracker will now process mouseout events correctly: Defer until mouseup if they happen during a drag
  - Ensure RowSelectionModel select/deselect events are fired
  - Fix bug where the parent menu wasn't getting assigned properly when specifying an xtype
  - Adjust grid scrolling speed to be more consistent with the browser scroll speed
  - Fix an issue with using initially collapsed regions in a border layout
  - The Ext.JSON.encode method will now gracefully handle object types that it does not recognize by returning undefined as the value of unknown properties
  - Sprite methods will all return the sprite upon completion
  - Added backwards compatible Ext.extend that delegates to Ext.Class
  - Keyframed animation's (Animator.js) start method is now controlled by fx.Manager
  - Keyframed animations can now be properly queued and integrated with the Animate mixin
  - Adjust the scroll delay algorithm to make the scrollbar more like the normal browser scrollbar
  - Menu now extends Panel to support docking
  - Grid now supports expand to fit
  - Eliminate need for grid reorderer and resizer to be order dependent
  - Added a submitFormat option for Date Field
  - Cleaned up some undefined variables
  - Charts now check for empty stores properly
  - Element.addCls now more intelligent about adding a preceding space
  - CheckboxGroup and RadioGroup implemented
  - Add 'widget.grid' as a second alias
  - Added private CheckboxManager class for managing checkboxes grouped by name, just like RadioManager
  - BoxLayout now uses component.animate instead of Anim directly
  - Add dirtyCls (defined in BaseField) to a field's outer element when it has a dirty value. CSS to display a marker not yet implemented

## API Changes

- All top level CSS classes are now prefixed with 'x-' by default instead of 'ext-' and can now be scoped. This is now consistent with all other Ext CSS classes.
- HashMap.add may now take a single argument similar to MixedCollection.add
- Animate methods (animate, stopAnimation, syncFx, sequenceFx, and getActiveAnimation) now applied via a mixin to Element/CompositeElement/Component/Sprite/SpriteGroup
- Keyframed animations (Animator.js) now fully support the iterations property
- Normalized API differences between Element's addCls and removeCls. Both now allow space separated strings
- Implement endDrag method in DragTracker
- Button now has a overMenuTrigger flag
- Rename pressClass to pressedCls and add check before cls removal in ClickRepeater
- Remove unecessary onDisable/onEnable override in menu.Item and Button
- Rename disabledClass to disableCls in Component
- Removed the positionAnimation property since it is no longer necessary with the Component.animate API
- Removed reverse parameter from keyframed animations
- The pause and running flags now maintained within keyframed animations (Animator.js)
- Update the RowSelectionModel constructor so we can add more useful contextual information to the event
- Menu now extends Panel to support docking
- Add isOnLeftEdge and isOnRightEdge for Grid Header events
- Grid HeaderContainer dragging property now defaults to false
- Animate's getActiveAnimation will now return the current fx.Anim object if there is one or return false if none are active
- Renamed tab reorderer plugin to TabReorderer
- Renamed MenuManager to MenuManager
- Remove Ext.isForcedBorderBox property
- Remove the experimental enableForcedBoxModel property
- Ext.isBorderBox logic now reflects the use of css box model
- CheckboxGroup/RadioGroup setValue method has been simplified; it now only accepts a single format of an object of name-value mappings. The old additional formats will be added to the legacy compatibility layer as an override
- CheckboxGroup/RadioGroup getValue method has been changed to return an object of similar format to what is accepted by setValue for internal consistency. The old behavior has been moved to a new getChecked() method
- The methods setRawValue, getRawValue, valueToRaw, and rawToValue have been moved out of Field and into BaseField; this is to make the main Field interface simpler and more easily implemented on components which do not have the concept of an underlying "raw value" like CheckboxGroup
- Field now has a isEqual method which compares values returned from getValue() for logical equality, and is used anywhere a comparison is necessary such as checkChange() and isDirty(). The base implementation is a simple string comparison, but can be overridden by fields with more complex values
- Field now has a resetOriginalValue method which is called by the form when trackResetOnLoad=true instead of setting originalValue directly, this allows the behavior to be overridden by field subclasses
- Field's getSubmitValue method has been changed to a more powerful getSubmitData method, which returns a mapping object of name-value pairs; this allows single fields to return multiple values under different names rather than being limited to a single name per field. The getSubmitValue method has been retained as a helper but moved down to BaseField
- Introduced a batchChanges method on field as a utility for preventing excessive firing of change events in fields such as CheckboxGroup that have many sub-fields who may be updated as a batch
- Basic's isValid method has been changed back to its old behavior where it iterates through all fields in the form and triggers error markings. A new hasInvalidField method has been added to retain the more efficient short-circuited validity checking and preventing error markings

## Known Issues

- Tab heights not consistent across all browsers

# Release Notes for Ext JS 4 PR1

Release Date: February 16, 2011
Version Number: 4.0.0pr1

## New In This Release

This is the first public release of Ext JS 4 (preview). We've prepared a full release overview guide to explore all of the changes made so far.